<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Markeninformationen abrufen
$stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
$stmt->execute();
$brand = $stmt->fetch();

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $currentImage = $brand['image_path'] ?? '';
    $uploadedImage = false;
    
    // Überprüfen, ob ein Bild hochgeladen wurde
    if (isset($_FILES['image']) && $_FILES['image']['error'] !== UPLOAD_ERR_NO_FILE) {
        $uploadDir = '../uploads/brand/';
        
        // Überprüfen, ob der Upload-Ordner existiert, sonst erstellen
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0755, true);
        }
        
        $fileExtension = pathinfo($_FILES['image']['name'], PATHINFO_EXTENSION);
        $fileName = 'brand_' . time() . '.' . $fileExtension;
        $targetFilePath = $uploadDir . $fileName;
        
        // Erlaubte Dateitypen
        $allowedTypes = ['jpg', 'jpeg', 'png', 'gif'];
        
        if (in_array(strtolower($fileExtension), $allowedTypes)) {
            if (move_uploaded_file($_FILES['image']['tmp_name'], $targetFilePath)) {
                $imagePath = $targetFilePath;
                $uploadedImage = true;
                
                // Altes Bild löschen, wenn ein neues hochgeladen wurde
                if (!empty($currentImage) && file_exists($currentImage)) {
                    unlink($currentImage);
                }
            } else {
                $_SESSION['error_message'] = "Fehler beim Hochladen des Bildes.";
            }
        } else {
            $_SESSION['error_message'] = "Nur JPG, JPEG, PNG und GIF Dateien sind erlaubt.";
        }
    } else {
        $imagePath = $currentImage;
    }
    
    // Markeninformationen aktualisieren
    try {
        if ($brand) {
            // Update bestehender Eintrag
            $stmt = $conn->prepare("UPDATE brand_info SET title = ?, description = ?, image_path = ?, updated_at = CURRENT_TIMESTAMP WHERE id = 1");
        } else {
            // Neuen Eintrag erstellen
            $stmt = $conn->prepare("INSERT INTO brand_info (title, description, image_path) VALUES (?, ?, ?)");
        }
        
        $stmt->execute([$title, $description, $uploadedImage ? $imagePath : $currentImage]);
        $_SESSION['success_message'] = "Markeninformationen wurden erfolgreich aktualisiert.";
        
        // Seite neu laden, um aktuelle Daten anzuzeigen
        header('Location: brand.php');
        exit;
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
}

// Seitentitel setzen und Header einfügen
$pageTitle = "Markeninformationen";
include('includes/header.php');
?>

<div class="form-card">
    <h3>Markeninformationen bearbeiten</h3>
    
    <form action="brand.php" method="post" enctype="multipart/form-data">
        <div class="form-group">
            <label for="title">Titel</label>
            <input type="text" id="title" name="title" class="form-control" value="<?php echo htmlspecialchars($brand['title'] ?? ''); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="description">Beschreibung</label>
            <textarea id="description" name="description" class="form-control" rows="6"><?php echo htmlspecialchars($brand['description'] ?? ''); ?></textarea>
        </div>
        
        <div class="form-group">
            <label for="image">Bild</label>
            <div class="custom-file">
                <input type="file" id="image" name="image" class="custom-file-input" accept="image/*">
                <label for="image" class="custom-file-label">Datei auswählen</label>
            </div>
            
            <?php if (!empty($brand['image_path']) && file_exists($brand['image_path'])): ?>
                <div class="image-preview" style="display: block; margin-top: 10px;">
                    <img src="<?php echo htmlspecialchars($brand['image_path']); ?>" alt="Marken-Bild" style="max-width: 200px;">
                </div>
            <?php endif; ?>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
        </div>
    </form>
</div>

<?php include('includes/footer.php'); ?> 