<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

$action = isset($_POST['action']) ? $_POST['action'] : '';

switch ($action) {
    case 'optimize':
        try {
            // MySQL Optimierungsbefehle
            $conn->exec('OPTIMIZE TABLE admin_users, brand_info, products, product_images, shops, testimonials, contact_info, site_settings, section_visibility, hero_content, order_forms, form_fields, order_submissions');
            $_SESSION['success_message'] = "Datenbank wurde erfolgreich optimiert.";
        } catch (PDOException $e) {
            $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
        }
        break;
        
    case 'backup':
        try {
            // Backup-Datei erstellen mit mysqldump via PHP
            $backupDir = __DIR__ . '/../backups';
            if (!file_exists($backupDir)) {
                mkdir($backupDir, 0755, true);
            }
            
            $backupFile = $backupDir . '/jb_kerzen_mysql_backup_' . date('Y-m-d_H-i-s') . '.sql';
            
            // Temporäre Funktion für MySQL-Backup über PHP
            createMySQLBackup($backupFile);
            
            // Zum Download anbieten
            header('Content-Description: File Transfer');
            header('Content-Type: application/octet-stream');
            header('Content-Disposition: attachment; filename="' . basename($backupFile) . '"');
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header('Content-Length: ' . filesize($backupFile));
            readfile($backupFile);
            exit;
        } catch (Exception $e) {
            $_SESSION['error_message'] = "Fehler beim Backup: " . $e->getMessage();
        }
        break;
        
    default:
        $_SESSION['error_message'] = "Ungültige Aktion angegeben.";
        break;
}

/**
 * Erstellt ein MySQL-Datenbank-Backup über PHP
 * 
 * @param string $outputFile Der Pfad zur Ausgabedatei
 * @return bool true bei Erfolg, false bei Fehler
 */
function createMySQLBackup($outputFile) {
    global $conn;
    
    try {
        $output = "-- JB Kerzen MySQL Backup\n";
        $output .= "-- Erstellt: " . date('Y-m-d H:i:s') . "\n\n";
        
        // Tabellen auflisten
        $tables = [];
        $result = $conn->query("SHOW TABLES");
        while ($row = $result->fetch(PDO::FETCH_NUM)) {
            $tables[] = $row[0];
        }
        
        foreach ($tables as $table) {
            $output .= "-- Tabelle: $table\n";
            $output .= "DROP TABLE IF EXISTS `$table`;\n";
            
            // Tabellenstruktur erstellen
            $result = $conn->query("SHOW CREATE TABLE `$table`");
            $row = $result->fetch(PDO::FETCH_NUM);
            $output .= $row[1] . ";\n\n";
            
            // Daten auslesen
            $result = $conn->query("SELECT * FROM `$table`");
            $rows = $result->fetchAll(PDO::FETCH_ASSOC);
            
            if (count($rows) > 0) {
                $output .= "-- Daten für Tabelle $table\n";
                $columns = array_keys($rows[0]);
                $columnList = "`" . implode("`, `", $columns) . "`";
                
                $output .= "INSERT INTO `$table` ($columnList) VALUES\n";
                
                $insertValues = [];
                foreach ($rows as $row) {
                    $values = [];
                    foreach ($row as $value) {
                        if ($value === null) {
                            $values[] = "NULL";
                        } else {
                            $values[] = "'" . addslashes($value) . "'";
                        }
                    }
                    $insertValues[] = "(" . implode(", ", $values) . ")";
                }
                
                $output .= implode(",\n", $insertValues) . ";\n\n";
            }
        }
        
        // Backup in Datei schreiben
        file_put_contents($outputFile, $output);
        return true;
    } catch (Exception $e) {
        error_log("Backup-Fehler: " . $e->getMessage());
        return false;
    }
}

// Zurück zur Einstellungsseite leiten
header('Location: settings.php');
exit; 