<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once('includes/db_connect.php');

echo "<h1>Datenbank-Strukturprüfung</h1>";

// Prüfen, ob Tabellen existieren
$requiredTables = [
    'products', 
    'order_forms', 
    'order_submissions',
    'site_settings',
    'brand_info'
];

echo "<h2>Tabellen-Prüfung</h2>";
echo "<ul>";
foreach ($requiredTables as $table) {
    $exists = tableExists($table);
    $status = $exists ? "✅ vorhanden" : "❌ FEHLT";
    echo "<li><strong>{$table}</strong>: {$status}</li>";
    
    if ($exists) {
        // Spalten anzeigen
        try {
            $stmt = $conn->query("DESCRIBE `{$table}`");
            $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            echo "<ul>";
            foreach ($columns as $column) {
                echo "<li>{$column['Field']} ({$column['Type']})</li>";
            }
            echo "</ul>";
        } catch (PDOException $e) {
            echo "<ul><li style='color: red;'>Fehler beim Abrufen der Spalten: {$e->getMessage()}</li></ul>";
        }
    }
}
echo "</ul>";

// Beispieldaten aus wichtigen Tabellen
echo "<h2>Produkt-Daten (Stichprobe)</h2>";
try {
    $stmt = $conn->query("SELECT id, name, active, 
                          (SELECT COUNT(*) FROM order_forms WHERE product_id = products.id AND active = 1) as form_count 
                          FROM products LIMIT 5");
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($products) > 0) {
        echo "<table border='1' cellpadding='5' style='border-collapse: collapse;'>";
        echo "<tr><th>ID</th><th>Name</th><th>Aktiv</th><th>Anzahl aktiver Formulare</th></tr>";
        
        foreach ($products as $product) {
            $active = $product['active'] ? '✅' : '❌';
            $formCount = $product['form_count'];
            $formStatus = $formCount > 0 ? '✅ ' . $formCount : '❌ 0';
            
            echo "<tr>";
            echo "<td>{$product['id']}</td>";
            echo "<td>{$product['name']}</td>";
            echo "<td>{$active}</td>";
            echo "<td>{$formStatus}</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p style='color: red;'>Keine Produkte gefunden!</p>";
    }
} catch (PDOException $e) {
    echo "<p style='color: red;'>Fehler beim Abrufen der Produktdaten: {$e->getMessage()}</p>";
}

// Überprüfen der order_submissions-Struktur
echo "<h2>Order Submissions Struktur</h2>";
try {
    if (tableExists('order_submissions')) {
        $stmt = $conn->query("DESCRIBE `order_submissions`");
        $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<table border='1' cellpadding='5' style='border-collapse: collapse;'>";
        echo "<tr><th>Spalte</th><th>Typ</th><th>Null erlaubt</th><th>Standardwert</th></tr>";
        
        foreach ($columns as $column) {
            echo "<tr>";
            echo "<td>{$column['Field']}</td>";
            echo "<td>{$column['Type']}</td>";
            echo "<td>{$column['Null']}</td>";
            echo "<td>{$column['Default']}</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p style='color: red;'>Die Tabelle order_submissions existiert nicht!</p>";
    }
} catch (PDOException $e) {
    echo "<p style='color: red;'>Fehler beim Abrufen der Tabellenstruktur: {$e->getMessage()}</p>";
}

// Testen einer direkten INSERT-Abfrage
echo "<h2>Test einer INSERT-Abfrage in order_submissions</h2>";
try {
    // Erstelle nur ein temporäres Test-Insert, das wir gleich wieder löschen
    $testData = json_encode(['name' => 'Test', 'email' => 'test@example.com', 'address' => 'Teststraße 1']);
    
    // Versuchen, in die Tabelle einzufügen (mit submission_data)
    $sql = "INSERT INTO order_submissions (form_id, submission_date, customer_data, submission_data, quantity) 
            VALUES (1, NOW(), :customer_data, :submission_data, 1)";
    
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(':customer_data', $testData);
    $stmt->bindParam(':submission_data', $testData);
    
    if ($stmt->execute()) {
        $insertId = $conn->lastInsertId();
        echo "<p style='color: green;'>✅ INSERT-Test erfolgreich (ID: {$insertId})</p>";
        
        // Gleich wieder löschen, um die Datenbank nicht zu verschmutzen
        $conn->exec("DELETE FROM order_submissions WHERE id = {$insertId}");
        echo "<p>Testeintrag wurde wieder gelöscht.</p>";
    } else {
        echo "<p style='color: red;'>❌ INSERT-Test fehlgeschlagen</p>";
    }
} catch (PDOException $e) {
    echo "<p style='color: red;'>❌ Fehler beim INSERT-Test: {$e->getMessage()}</p>";
}

// Link zurück
echo "<p><a href='order_cart.php'>Zurück zum Warenkorb</a></p>";
?> 