# JB Kerzen - PHP Marken-Präsentation

Ein elegantes, modernes PHP-Panel zur Präsentation der Marke JB Kerzen und zur Verlinkung auf verschiedene Online-Shops.

## Funktionen

- Responsive, modernes Design mit eleganter Farbgebung
- Präsentation der Marke und Produkte
- Shop-Verlinkungen mit Logos und Beschreibungen
- Kundenstimmen-Sektion mit automatischem Slider
- Kontaktbereich mit Social Media Links
- Admin-Panel zur Verwaltung aller Inhalte
- SQLite-Datenbank (keine separate DB-Installation nötig)

## Systemanforderungen

- PHP 7.4 oder höher
- SQLite3 PHP-Erweiterung
- Webserver (Apache, Nginx, etc.)
- Moderne Browser (Chrome, Firefox, Edge, Safari)

## Installation

1. Klone oder kopiere alle Dateien auf deinen Webserver.

2. Stelle sicher, dass PHP die SQLite-Erweiterung unterstützt:
   ```
   php -m | grep sqlite
   ```

3. Erstelle folgende Verzeichnisse mit Schreibrechten für den Webserver:
   ```
   mkdir -p database uploads/brand uploads/products uploads/shops
   chmod -R 755 database uploads
   ```

4. Rufe die Website im Browser auf. Die Datenbank wird automatisch erstellt.

5. Melde dich im Admin-Bereich an unter `/admin/`:
   - Standard-Benutzer: `admin`
   - Standard-Passwort: `admin123`

6. Ändere sofort das Passwort im Admin-Bereich unter "Einstellungen"!

## Verzeichnisstruktur

```
├── admin/              # Admin-Panel Dateien
│   ├── includes/       # Admin-Komponenten
│   ├── brand.php       # Markeninfo-Verwaltung
│   ├── shops.php       # Shop-Verwaltung
│   ├── products.php    # Produkt-Verwaltung
│   └── ...
├── assets/
│   ├── css/            # Stylesheets
│   ├── js/             # JavaScript-Dateien
│   └── images/         # Statische Bilder
├── database/           # SQLite-Datenbank
├── includes/           # Kern-Komponenten
├── uploads/            # Hochgeladene Dateien
├── index.php           # Haupt-Startseite
└── README.md           # Diese Datei
```

## Admin-Bereich

Der Admin-Bereich ist unter `/admin/` erreichbar und bietet folgende Funktionen:

- Dashboard mit Übersicht
- Markeninformationen bearbeiten
- Produkte verwalten (hinzufügen, bearbeiten, löschen)
- Shops verwalten (hinzufügen, bearbeiten, löschen) 
- Kundenstimmen verwalten
- Kontaktinformationen bearbeiten

**Wichtig:** Aus Sicherheitsgründen gibt es keinen direkten Link zum Admin-Bereich auf der Hauptseite.

## Anpassung

### Templates und Design

Die CSS-Dateien befinden sich in `assets/css/`:
- `style.css` - Frontend-Styling
- `admin.css` - Admin-Bereich-Styling

### Datenbankstruktur

Die SQLite-Datenbank wird automatisch mit folgenden Tabellen erstellt:

- `admin_users` - Admin-Benutzer
- `brand_info` - Markeninformationen
- `products` - Produktdaten
- `shops` - Shop-Informationen
- `testimonials` - Kundenstimmen
- `contact_info` - Kontaktdaten

## Sicherheit

- Alle Benutzer-Eingaben werden bereinigt
- Passwörter werden mit modernen Hashing-Algorithmen gespeichert
- SQLite-Datenbank außerhalb des Webroot-Verzeichnisses speichern für zusätzliche Sicherheit
- Admin-Bereich mit Session-basierter Authentifizierung geschützt

## Lizenz

Dieses Projekt ist für den privaten Gebrauch erstellt und darf entsprechend verwendet werden. 