<?php
// Einfaches Skript zum Hinzufügen des Preisfeldes zur Produkttabelle
require_once('includes/db_connect.php');

echo "<h1>Preisfeld zur Produkttabelle hinzufügen</h1>";

try {
    // Prüfen, ob die Preisspalte bereits existiert
    $has_price = columnExists('products', 'price');
    
    if (!$has_price) {
        echo "<p>Füge Preisspalte zur products-Tabelle hinzu...</p>";
        
        $conn->exec("ALTER TABLE products ADD COLUMN price DECIMAL(10,2) DEFAULT 0.00");
        
        echo "<p style='color: green; font-weight: bold;'>✅ Preisspalte wurde erfolgreich hinzugefügt!</p>";
    } else {
        echo "<p style='color: blue; font-weight: bold;'>ℹ️ Preisspalte existiert bereits.</p>";
    }
    
    // Prüfen, ob die show_price Spalte bereits existiert
    $has_show_price = columnExists('products', 'show_price');
    
    if (!$has_show_price) {
        echo "<p>Füge show_price Spalte zur products-Tabelle hinzu...</p>";
        
        $conn->exec("ALTER TABLE products ADD COLUMN show_price TINYINT(1) DEFAULT 1");
        
        echo "<p style='color: green; font-weight: bold;'>✅ show_price Spalte wurde erfolgreich hinzugefügt!</p>";
    } else {
        echo "<p style='color: blue; font-weight: bold;'>ℹ️ show_price Spalte existiert bereits.</p>";
    }
    
    // Zeige aktuelle Tabellenstruktur
    echo "<h2>Aktuelle Struktur der products-Tabelle:</h2>";
    $result = $conn->query("DESCRIBE products");
    $columns = $result->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<table border='1' cellpadding='5' style='border-collapse: collapse;'>";
    echo "<tr><th>Spalte</th><th>Typ</th><th>Null</th><th>Schlüssel</th><th>Standard</th></tr>";
    
    foreach ($columns as $column) {
        echo "<tr>";
        echo "<td>{$column['Field']}</td>";
        echo "<td>{$column['Type']}</td>";
        echo "<td>{$column['Null']}</td>";
        echo "<td>{$column['Key']}</td>";
        echo "<td>{$column['Default']}</td>";
        echo "</tr>";
    }
    
    echo "</table>";
    
    echo "<h2>Nächste Schritte:</h2>";
    echo "<ol>";
    echo "<li>Gehen Sie zum Admin-Bereich → Produkte</li>";
    echo "<li>Bearbeiten Sie Ihre Produkte und fügen Sie Preise hinzu</li>";
    echo "<li>Die Preise werden automatisch in der Bestellseite und im Warenkorb angezeigt</li>";
    echo "<li>Die Warenkorb-Berechnung funktioniert jetzt automatisch</li>";
    echo "</ol>";
    
    echo "<p><a href='admin/products.php' style='display: inline-block; padding: 10px 20px; background: #8b6b4f; color: white; text-decoration: none; border-radius: 4px; margin-top: 20px;'>Zu den Produkten</a></p>";
    
} catch (PDOException $e) {
    echo "<p style='color: red; font-weight: bold;'>❌ Fehler: " . $e->getMessage() . "</p>";
}
?> 