<?php
// Address field diagnosis tool
ini_set('display_errors', 1);
error_reporting(E_ALL);

echo "<html><head><title>JB Kerzen - Adressfeld Diagnose</title>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; line-height: 1.6; }
    h1, h2, h3 { color: #8b6b4f; }
    pre { background: #f5f5f5; padding: 15px; border-radius: 5px; overflow: auto; }
    .success { color: green; font-weight: bold; }
    .error { color: red; font-weight: bold; }
    .warning { color: orange; font-weight: bold; }
    table { border-collapse: collapse; width: 100%; margin: 15px 0; }
    th, td { padding: 8px; text-align: left; border-bottom: 1px solid #ddd; }
    th { background-color: #f2f2f2; }
    tr:hover { background-color: #f5f5f5; }
    .fix-button { 
        display: inline-block; 
        background: #8b6b4f; 
        color: white; 
        padding: 10px 20px; 
        text-decoration: none; 
        border-radius: 4px; 
        margin-top: 20px;
        border: none;
        cursor: pointer;
    }
</style>";
echo "</head><body>";
echo "<h1>Adressfeld Diagnose und Reparatur</h1>";

// Include database connection
require_once('includes/db_connect.php');

// Process fix button if clicked
if (isset($_POST['fix_fields'])) {
    echo "<h2>Adressfelder werden repariert...</h2>";
    
    try {
        // Direct MySQL approach - brute force fix all fields with 'adresse' in their name
        $conn->exec("UPDATE form_fields SET field_type = 'address' 
                    WHERE field_label LIKE '%dresse%' OR field_label LIKE '%Adresse%'");
        
        echo "<p class='success'>✓ Feldtypen in der Datenbank wurden aktualisiert.</p>";
        echo "<p>Bitte leeren Sie den Browser-Cache (STRG+F5) und testen Sie erneut.</p>";
    } catch (PDOException $e) {
        echo "<p class='error'>Fehler bei der Aktualisierung: " . $e->getMessage() . "</p>";
    }
}

// Check the MySQL version
echo "<h2>Datenbank-Version</h2>";
try {
    $version = $conn->getAttribute(PDO::ATTR_SERVER_VERSION);
    $driver = $conn->getAttribute(PDO::ATTR_DRIVER_NAME);
    echo "<p>Datenbanktyp: <strong>{$driver}</strong></p>";
    echo "<p>Datenbankversion: <strong>{$version}</strong></p>";
} catch (PDOException $e) {
    echo "<p class='error'>Fehler beim Abrufen der Datenbankversion: " . $e->getMessage() . "</p>";
}

// List all tables to verify structure
echo "<h2>Tabellen in der Datenbank</h2>";
try {
    $tables = $conn->query("SHOW TABLES")->fetchAll(PDO::FETCH_COLUMN);
    echo "<p>Gefundene Tabellen: " . count($tables) . "</p>";
    echo "<ul>";
    foreach ($tables as $table) {
        echo "<li>{$table}</li>";
    }
    echo "</ul>";
} catch (PDOException $e) {
    echo "<p class='error'>Fehler beim Abrufen der Tabellen: " . $e->getMessage() . "</p>";
}

// Examine form_fields table structure
echo "<h2>Struktur der form_fields Tabelle</h2>";
try {
    $result = $conn->query("DESCRIBE form_fields");
    $columns = $result->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<table>";
    echo "<tr><th>Feld</th><th>Typ</th><th>Null</th><th>Schlüssel</th><th>Standard</th></tr>";
    
    foreach ($columns as $column) {
        echo "<tr>";
        foreach ($column as $key => $value) {
            echo "<td>" . htmlspecialchars($value ?? 'NULL') . "</td>";
        }
        echo "</tr>";
    }
    echo "</table>";
} catch (PDOException $e) {
    echo "<p class='error'>Fehler beim Abrufen der Tabellenstruktur: " . $e->getMessage() . "</p>";
}

// Examine all form_fields entries
echo "<h2>Alle Formularfelder</h2>";
try {
    $stmt = $conn->query("SELECT * FROM form_fields ORDER BY form_id, id");
    $fields = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($fields) > 0) {
        echo "<table>";
        echo "<tr><th>ID</th><th>Form-ID</th><th>Label</th><th>Typ</th><th>Erforderlich</th><th>Status</th></tr>";
        
        $addressFieldFound = false;
        
        foreach ($fields as $field) {
            $isAddressField = (stripos($field['field_label'], 'adresse') !== false || 
                               stripos($field['field_label'], 'address') !== false);
            
            if ($isAddressField) {
                $addressFieldFound = true;
            }
            
            $status = $isAddressField ? 
                     ($field['field_type'] === 'address' ? 
                      "<span class='success'>Korrekt</span>" : 
                      "<span class='error'>Falsch (ist '{$field['field_type']}', sollte 'address' sein)</span>") :
                     "";
            
            echo "<tr>";
            echo "<td>" . $field['id'] . "</td>";
            echo "<td>" . $field['form_id'] . "</td>";
            echo "<td>" . htmlspecialchars($field['field_label']) . "</td>";
            echo "<td>" . $field['field_type'] . "</td>";
            echo "<td>" . ($field['required'] ? 'Ja' : 'Nein') . "</td>";
            echo "<td>" . $status . "</td>";
            echo "</tr>";
        }
        echo "</table>";
        
        if (!$addressFieldFound) {
            echo "<p class='warning'>⚠️ Es wurden keine Felder gefunden, die als Adressfelder erkannt werden können!</p>";
        }
    } else {
        echo "<p class='error'>Keine Formularfelder gefunden!</p>";
    }
} catch (PDOException $e) {
    echo "<p class='error'>Fehler beim Abrufen der Formularfelder: " . $e->getMessage() . "</p>";
}

// Examine current function execution
echo "<h2>Funktionsüberprüfung</h2>";
echo "<p>Funktion <code>ensureAddressFieldTypes()</code> wird ausgeführt...</p>";

// Try to directly execute the function to ensure it's working
try {
    ensureAddressFieldTypes();
    echo "<p class='success'>✓ Funktion wurde ausgeführt.</p>";
    
    // Verify results after function execution
    $stmt = $conn->prepare("SELECT COUNT(*) FROM form_fields WHERE field_type = 'address'");
    $stmt->execute();
    $count = $stmt->fetchColumn();
    
    echo "<p>Anzahl der Felder mit Typ 'address' nach Funktionsausführung: <strong>{$count}</strong></p>";
} catch (Exception $e) {
    echo "<p class='error'>Fehler bei der Ausführung der Funktion: " . $e->getMessage() . "</p>";
}

// Check for potential PHP or MySQL errors
echo "<h2>PHP-Fehlerprotokoll</h2>";
if (function_exists('error_get_last')) {
    $lastError = error_get_last();
    if ($lastError) {
        echo "<pre>" . print_r($lastError, true) . "</pre>";
    } else {
        echo "<p>Keine Fehler im Fehlerprotokoll gefunden.</p>";
    }
} else {
    echo "<p>Funktion error_get_last() ist nicht verfügbar.</p>";
}

// Provide a quick fix button
echo "<h2>Adressfelder reparieren</h2>";
echo "<form method='post' action=''>";
echo "<p>Klicken Sie auf den Button, um alle Felder mit 'Adresse' im Namen zu korrigieren:</p>";
echo "<button type='submit' name='fix_fields' class='fix-button'>Adressfelder jetzt reparieren</button>";
echo "</form>";

echo "<p><a href='index.php' class='fix-button'>Zurück zur Startseite</a></p>";

echo "</body></html>";
?> 