<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Kontaktinformationen abrufen
$stmt = $conn->prepare("SELECT * FROM contact_info WHERE id = 1");
$stmt->execute();
$contact = $stmt->fetch();

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = trim($_POST['email']);
    $phone = trim($_POST['phone']);
    $address = trim($_POST['address']);
    $socialFacebook = trim($_POST['social_facebook']);
    $socialInstagram = trim($_POST['social_instagram']);
    
    try {
        if ($contact) {
            // Update bestehender Eintrag
            $stmt = $conn->prepare("UPDATE contact_info SET email = ?, phone = ?, address = ?, social_facebook = ?, social_instagram = ?, updated_at = CURRENT_TIMESTAMP WHERE id = 1");
        } else {
            // Neuen Eintrag erstellen
            $stmt = $conn->prepare("INSERT INTO contact_info (email, phone, address, social_facebook, social_instagram) VALUES (?, ?, ?, ?, ?)");
        }
        
        $stmt->execute([$email, $phone, $address, $socialFacebook, $socialInstagram]);
        $_SESSION['success_message'] = "Kontaktinformationen wurden erfolgreich aktualisiert.";
        
        // Seite neu laden, um aktuelle Daten anzuzeigen
        header('Location: contact.php');
        exit;
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
}

// Seitentitel setzen und Header einfügen
$pageTitle = "Kontaktdaten";
include('includes/header.php');
?>

<div class="form-card">
    <h3>Kontaktinformationen bearbeiten</h3>
    
    <form action="contact.php" method="post">
        <div class="form-group">
            <label for="email">E-Mail</label>
            <input type="email" id="email" name="email" class="form-control" value="<?php echo htmlspecialchars($contact['email'] ?? ''); ?>">
            <small class="form-text text-muted">Wird auf der Kontaktseite angezeigt.</small>
        </div>
        
        <div class="form-group">
            <label for="phone">Telefon</label>
            <input type="text" id="phone" name="phone" class="form-control" value="<?php echo htmlspecialchars($contact['phone'] ?? ''); ?>">
        </div>
        
        <div class="form-group">
            <label for="address">Adresse</label>
            <textarea id="address" name="address" class="form-control" rows="3"><?php echo htmlspecialchars($contact['address'] ?? ''); ?></textarea>
            <small class="form-text text-muted">Geben Sie Ihre vollständige Adresse ein, inkl. Zeilenumbrüchen.</small>
        </div>
        
        <div class="form-group">
            <label for="social_facebook">Facebook URL</label>
            <input type="url" id="social_facebook" name="social_facebook" class="form-control" value="<?php echo htmlspecialchars($contact['social_facebook'] ?? ''); ?>">
            <small class="form-text text-muted">Beispiel: https://facebook.com/ihre-seite</small>
        </div>
        
        <div class="form-group">
            <label for="social_instagram">Instagram URL</label>
            <input type="url" id="social_instagram" name="social_instagram" class="form-control" value="<?php echo htmlspecialchars($contact['social_instagram'] ?? ''); ?>">
            <small class="form-text text-muted">Beispiel: https://instagram.com/ihr-account</small>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
        </div>
    </form>
</div>

<div class="form-card">
    <h3>Vorschau</h3>
    
    <div class="contact-preview">
        <div class="row">
            <div class="col">
                <h4>Kontaktdaten</h4>
                <?php if (!empty($contact['email'] ?? '')): ?>
                    <p><i class="fas fa-envelope"></i> <?php echo htmlspecialchars($contact['email']); ?></p>
                <?php endif; ?>
                
                <?php if (!empty($contact['phone'] ?? '')): ?>
                    <p><i class="fas fa-phone"></i> <?php echo htmlspecialchars($contact['phone']); ?></p>
                <?php endif; ?>
                
                <?php if (!empty($contact['address'] ?? '')): ?>
                    <p><i class="fas fa-map-marker-alt"></i> <?php echo nl2br(htmlspecialchars($contact['address'])); ?></p>
                <?php endif; ?>
            </div>
            
            <div class="col">
                <h4>Social Media</h4>
                <div class="social-preview">
                    <?php if (!empty($contact['social_facebook'] ?? '')): ?>
                        <a href="<?php echo htmlspecialchars($contact['social_facebook']); ?>" target="_blank" class="social-icon facebook">
                            <i class="fab fa-facebook-f"></i>
                        </a>
                    <?php endif; ?>
                    
                    <?php if (!empty($contact['social_instagram'] ?? '')): ?>
                        <a href="<?php echo htmlspecialchars($contact['social_instagram']); ?>" target="_blank" class="social-icon instagram">
                            <i class="fab fa-instagram"></i>
                        </a>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .contact-preview {
        background-color: #f9f9f9;
        padding: 20px;
        border-radius: 4px;
    }
    
    .row {
        display: flex;
        flex-wrap: wrap;
        margin: -10px;
    }
    
    .col {
        flex: 1;
        min-width: 250px;
        padding: 10px;
    }
    
    .contact-preview h4 {
        margin-bottom: 15px;
        color: var(--primary-color);
    }
    
    .contact-preview p {
        margin-bottom: 10px;
        display: flex;
        align-items: flex-start;
    }
    
    .contact-preview i {
        margin-right: 10px;
        color: var(--primary-color);
        font-size: 1.1rem;
        margin-top: 4px;
    }
    
    .social-preview {
        display: flex;
        gap: 15px;
    }
    
    .social-icon {
        display: flex;
        align-items: center;
        justify-content: center;
        width: 40px;
        height: 40px;
        background-color: var(--primary-color);
        color: #fff;
        border-radius: 50%;
        text-decoration: none;
        transition: all 0.3s ease;
    }
    
    .social-icon:hover {
        transform: translateY(-3px);
        background-color: var(--accent-color);
    }
</style>

<?php include('includes/footer.php'); ?> 