<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Daten aus der Datenbank laden
try {
    $stmt = $conn->prepare("SELECT * FROM hero_content WHERE id = 1");
    $stmt->execute();
    $hero = $stmt->fetch();

    // Wenn kein Datensatz existiert, Standard-Werte verwenden
    if (!$hero) {
        $hero = [
            'headline' => 'Handgefertigte Kerzen mit Liebe gemacht',
            'subtext' => 'Entdecken Sie unsere einzigartigen, nachhaltigen Kerzen für jeden Anlass',
            'button_text' => 'Jetzt kaufen',
            'button_url' => '#shops',
            'bg_color' => 'rgba(0, 0, 0, 0.4)',
            'text_color' => '#ffffff',
            'bg_image' => ''
        ];
    }
} catch (PDOException $e) {
    error_log("Fehler beim Laden der Hero-Konfiguration: " . $e->getMessage());
    $hero = [
        'headline' => 'Handgefertigte Kerzen mit Liebe gemacht',
        'subtext' => 'Entdecken Sie unsere einzigartigen, nachhaltigen Kerzen für jeden Anlass',
        'button_text' => 'Jetzt kaufen',
        'button_url' => '#shops',
        'bg_color' => 'rgba(0, 0, 0, 0.4)',
        'text_color' => '#ffffff',
        'bg_image' => ''
    ];
}

// Formular zur Aktualisierung verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $headline = trim($_POST['headline']);
    $subtext = trim($_POST['subtext']);
    $button_text = trim($_POST['button_text']);
    $button_url = trim($_POST['button_url']);
    $bg_color = trim($_POST['bg_color']);
    $text_color = trim($_POST['text_color']);
    $bg_image = trim($_POST['bg_image']);
    
    // Einfache Validierung
    if (empty($headline) || empty($subtext) || empty($button_text)) {
        $_SESSION['error_message'] = "Bitte füllen Sie alle erforderlichen Felder aus.";
    } else {
        try {
            // Aktualisieren oder einfügen, je nachdem ob ein Datensatz existiert
            if ($hero && isset($hero['id'])) {
                $stmt = $conn->prepare("UPDATE hero_content SET headline = ?, subtext = ?, button_text = ?, button_url = ?, bg_color = ?, text_color = ?, bg_image = ?, updated_at = CURRENT_TIMESTAMP WHERE id = 1");
                $stmt->execute([$headline, $subtext, $button_text, $button_url, $bg_color, $text_color, $bg_image]);
            } else {
                $stmt = $conn->prepare("INSERT INTO hero_content (headline, subtext, button_text, button_url, bg_color, text_color, bg_image) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$headline, $subtext, $button_text, $button_url, $bg_color, $text_color, $bg_image]);
            }
            
            $_SESSION['success_message'] = "Hero-Bereich wurde erfolgreich aktualisiert.";
            
            // Daten neu laden
            $stmt = $conn->prepare("SELECT * FROM hero_content WHERE id = 1");
            $stmt->execute();
            $hero = $stmt->fetch();
            
            // Seite neu laden, um die Änderungen anzuzeigen
            header("Location: hero.php");
            exit;
        } catch (PDOException $e) {
            $_SESSION['error_message'] = "Fehler beim Speichern: " . $e->getMessage();
        }
    }
}

// Seitentitel setzen und Header einfügen
$pageTitle = "Hero-Bereich";
include('includes/header.php');
?>

<div class="form-card">
    <h3>Hero-Bereich bearbeiten</h3>
    <p>Hier können Sie die Texte und das Erscheinungsbild des zentralen Bereichs auf der Startseite anpassen.</p>
    
    <form action="hero.php" method="post">
        <div class="form-group">
            <label for="headline">Hauptüberschrift</label>
            <input type="text" id="headline" name="headline" class="form-control" value="<?php echo htmlspecialchars($hero['headline']); ?>" required>
            <small class="form-text text-muted">Die hervorgehobene Überschrift im Hero-Bereich.</small>
        </div>
        
        <div class="form-group">
            <label for="subtext">Untertext</label>
            <textarea id="subtext" name="subtext" class="form-control" required><?php echo htmlspecialchars($hero['subtext']); ?></textarea>
            <small class="form-text text-muted">Der beschreibende Text unter der Hauptüberschrift.</small>
        </div>
        
        <div class="form-group">
            <label for="button_text">Button-Text</label>
            <input type="text" id="button_text" name="button_text" class="form-control" value="<?php echo htmlspecialchars($hero['button_text']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="button_url">Button-Link</label>
            <input type="text" id="button_url" name="button_url" class="form-control" value="<?php echo htmlspecialchars($hero['button_url']); ?>" required>
            <small class="form-text text-muted">Ziel des Buttons. Verwenden Sie z.B. '#shops' für einen Link innerhalb der Seite.</small>
        </div>
        
        <hr class="my-4">
        
        <h4>Erscheinungsbild</h4>
        
        <div class="row">
            <div class="col-md-6">
                <div class="form-group">
                    <label for="text_color">Textfarbe</label>
                    <div class="color-picker-container">
                        <input type="color" id="text_color_picker" class="form-control color-picker" value="<?php echo htmlspecialchars($hero['text_color']); ?>">
                        <input type="text" id="text_color" name="text_color" class="form-control color-value" value="<?php echo htmlspecialchars($hero['text_color']); ?>">
                    </div>
                    <small class="form-text text-muted">Farbe für die Texte und Überschriften im Hero-Bereich.</small>
                </div>
            </div>
            
            <div class="col-md-6">
                <div class="form-group">
                    <label for="bg_color">Hintergrundfarbe</label>
                    <div class="color-picker-container">
                        <input type="color" id="bg_color_picker" class="form-control color-picker" value="<?php echo htmlspecialchars(preg_match('/^rgba?\(/', $hero['bg_color']) ? '#333333' : $hero['bg_color']); ?>">
                        <input type="text" id="bg_color" name="bg_color" class="form-control color-value" value="<?php echo htmlspecialchars($hero['bg_color']); ?>">
                    </div>
                    <small class="form-text text-muted">Hintergrundfarbe oder Overlay-Farbe über dem Bild. Nutzen Sie RGBA für Transparenz, z.B. rgba(0,0,0,0.4) für 60% schwarzer Overlay.</small>
                </div>
            </div>
        </div>
        
        <div class="form-group">
            <label for="bg_image">Hintergrundbild URL (optional)</label>
            <input type="text" id="bg_image" name="bg_image" class="form-control" value="<?php echo htmlspecialchars($hero['bg_image']); ?>">
            <small class="form-text text-muted">URL zu einem Hintergrundbild. Lassen Sie dieses Feld leer, wenn Sie nur eine Hintergrundfarbe verwenden möchten.</small>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Änderungen speichern</button>
        </div>
    </form>
</div>

<div class="form-card">
    <h3>Vorschau</h3>
    <div class="preview-hero-container" style="
        background-color: <?php echo htmlspecialchars($hero['bg_color']); ?>;
        <?php if(!empty($hero['bg_image'])): ?>
        background-image: url('<?php echo htmlspecialchars($hero['bg_image']); ?>');
        background-size: cover;
        background-position: center center;
        background-attachment: scroll;
        <?php endif; ?>
        border-radius: 12px; 
        padding: 30px; 
        color: <?php echo htmlspecialchars($hero['text_color']); ?>; 
        text-align: center;
        min-height: 300px;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
        overflow: hidden;">
        <h2 style="font-size: 2.5rem; margin-bottom: 20px; font-weight: bold;"><?php echo htmlspecialchars($hero['headline']); ?></h2>
        <p style="font-size: 1.2rem; margin-bottom: 25px;"><?php echo htmlspecialchars($hero['subtext']); ?></p>
        <button style="background-color: var(--accent-color); color: white; border: none; padding: 12px 30px; border-radius: 5px; font-weight: 600;"><?php echo htmlspecialchars($hero['button_text']); ?></button>
    </div>
    <p class="mt-3 text-muted text-center">Diese Vorschau ist vereinfacht. Das tatsächliche Erscheinungsbild kann auf der Website leicht anders aussehen.</p>
    <div class="device-preview-note mt-2 text-center">
        <small class="text-muted">Hinweis: Auf mobilen Geräten und Tablets wird der Hero-Bereich responsiv angepasst.</small>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Text-Farbe Picker
    const textColorPicker = document.getElementById('text_color_picker');
    const textColorInput = document.getElementById('text_color');
    
    textColorPicker.addEventListener('input', function() {
        textColorInput.value = this.value;
        updatePreview();
    });
    
    textColorInput.addEventListener('input', function() {
        try {
            // Versuche, die eingegebene Farbe für den Picker zu setzen
            // Aber nur, wenn es sich um einen HEX-Wert handelt
            if (this.value.startsWith('#')) {
                textColorPicker.value = this.value;
            }
            // Unabhängig davon immer die Vorschau aktualisieren
            updatePreview();
        } catch(e) {
            // Ignoriere Fehler, falls der Wert ungültig ist
        }
    });
    
    // Hintergrund-Farbe Picker
    const bgColorPicker = document.getElementById('bg_color_picker');
    const bgColorInput = document.getElementById('bg_color');
    
    bgColorPicker.addEventListener('input', function() {
        // Wir aktualisieren den Textwert mit dem ausgewählten HEX-Wert
        bgColorInput.value = this.value;
        updatePreview();
    });
    
    bgColorInput.addEventListener('input', function() {
        try {
            // Versuche, die eingegebene Farbe für den Picker zu setzen
            // Aber nur, wenn es sich um einen HEX-Wert handelt
            if (this.value.startsWith('#')) {
                bgColorPicker.value = this.value;
            }
            // Unabhängig davon immer die Vorschau aktualisieren
            updatePreview();
        } catch(e) {
            // Ignoriere Fehler, falls der Wert ungültig ist
        }
    });
    
    // Aktualisiere Vorschau beim Ändern des Bildes
    const bgImageInput = document.getElementById('bg_image');
    bgImageInput.addEventListener('input', updatePreview);
    
    // Aktualisiere die Vorschau
    function updatePreview() {
        const previewContainer = document.querySelector('.preview-hero-container');
        const bgColor = document.getElementById('bg_color').value;
        const textColor = document.getElementById('text_color').value;
        const bgImage = document.getElementById('bg_image').value;
        
        previewContainer.style.color = textColor;
        
        // Hintergrundbild und -farbe setzen
        if (bgImage && bgImage.trim() !== '') {
            // Wenn ein Bild vorhanden ist, verwenden wir die Hintergrundfarbe als Overlay
            previewContainer.style.backgroundImage = `url('${bgImage}')`;
            previewContainer.style.backgroundSize = 'cover';
            previewContainer.style.backgroundPosition = 'center center';
            previewContainer.style.backgroundAttachment = 'scroll';
            // Füge ein Overlay mit der angegebenen Farbe hinzu
            previewContainer.style.backgroundColor = bgColor;
            // Wenn die Farbe im RGBA-Format ist, nutzen wir sie direkt, sonst setzen wir den Hintergrund
            if (bgColor.startsWith('rgba')) {
                previewContainer.style.backgroundImage = `linear-gradient(${bgColor}, ${bgColor}), url('${bgImage}')`;
            }
        } else {
            // Wenn kein Bild vorhanden ist, nur Hintergrundfarbe setzen
            previewContainer.style.backgroundImage = 'none';
            previewContainer.style.backgroundColor = bgColor;
        }
    }
    
    // Initialer Update
    updatePreview();
});
</script>

<?php include('includes/footer.php'); ?> 