<?php
// Ensure we're running within the admin context
if (!isset($_SESSION['admin_logged_in'])) {
    header('Location: /admin/index.php');
    exit;
}

// Set default page title if not provided
if (!isset($pageTitle)) {
    $pageTitle = 'JB Kerzenzauber Admin';
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($pageTitle); ?> | JB Kerzen Admin</title>
    <link rel="stylesheet" href="../assets/css/admin.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        /* Fix für das Admin-Menü - Scrollbare Navigation mit fixem Footer */
        .sidebar {
            height: 100vh;
            overflow: hidden;
        }
        .sidebar-header {
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            background-color: #333333;
            z-index: 2;
        }
        .sidebar-nav {
            position: absolute;
            top: 84px; /* Höhe des Headers + padding */
            bottom: 124px; /* Höhe des Footers + padding */
            left: 0;
            right: 0;
            overflow-y: auto;
            padding-bottom: 20px;
        }
        .sidebar-footer {
            position: absolute;
            bottom: 0;
            left: 0;
            right: 0;
            background-color: #333333;
            z-index: 2;
        }
    </style>
</head>
<body>
    <div class="admin-container">
        <aside class="sidebar">
            <div class="sidebar-header">
                <h1>JB Kerzenzauber</h1>
                <p>Admin-Bereich</p>
            </div>
            
            <nav class="sidebar-nav">
                <ul>
                    <li>
                        <a href="dashboard.php" class="<?php echo ($pageTitle == 'Dashboard') ? 'active' : ''; ?>">
                            <i class="fas fa-tachometer-alt"></i>
                            <span>Dashboard</span>
                        </a>
                    </li>
                    <li>
                        <a href="brand.php" class="<?php echo ($pageTitle == 'Markeninformationen') ? 'active' : ''; ?>">
                            <i class="fas fa-trademark"></i>
                            <span>Markeninformationen</span>
                        </a>
                    </li>
                    <li>
                        <a href="products.php" class="<?php echo ($pageTitle == 'Produkte') ? 'active' : ''; ?>">
                            <i class="fas fa-box"></i>
                            <span>Produkte</span>
                        </a>
                    </li>
                    <li>
                        <a href="order_forms.php" class="<?php echo ($pageTitle == 'Bestellformulare') ? 'active' : ''; ?>">
                            <i class="fas fa-clipboard-list"></i>
                            <span>Bestellformulare</span>
                        </a>
                    </li>
                    <li>
                        <a href="shops.php" class="<?php echo ($pageTitle == 'Shops') ? 'active' : ''; ?>">
                            <i class="fas fa-store"></i>
                            <span>Shops</span>
                        </a>
                    </li>
                    <li>
                        <a href="testimonials.php" class="<?php echo ($pageTitle == 'Kundenstimmen') ? 'active' : ''; ?>">
                            <i class="fas fa-comment"></i>
                            <span>Kundenstimmen</span>
                        </a>
                    </li>
                    <li>
                        <a href="hero.php" class="<?php echo ($pageTitle == 'Hero-Bereich') ? 'active' : ''; ?>">
                            <i class="fas fa-image"></i>
                            <span>Hero-Bereich</span>
                        </a>
                    </li>
                    <li>
                        <a href="sections.php" class="<?php echo ($pageTitle == 'Bereiche verwalten') ? 'active' : ''; ?>">
                            <i class="fas fa-columns"></i>
                            <span>Bereiche verwalten</span>
                        </a>
                    </li>
                    <li>
                        <a href="contact.php" class="<?php echo ($pageTitle == 'Kontaktdaten') ? 'active' : ''; ?>">
                            <i class="fas fa-envelope"></i>
                            <span>Kontaktdaten</span>
                        </a>
                    </li>
                    <li>
                        <a href="popups.php" class="<?php echo ($pageTitle == 'Popups verwalten') ? 'active' : ''; ?>">
                            <i class="fas fa-bell"></i>
                            <span>Popups</span>
                        </a>
                    </li>
                    <li>
                        <a href="site_settings.php" class="<?php echo ($pageTitle == 'Website-Einstellungen') ? 'active' : ''; ?>">
                            <i class="fas fa-palette"></i>
                            <span>Website-Einstellungen</span>
                        </a>
                    </li>
                </ul>
            </nav>
            
            <div class="sidebar-footer">
                <a href="settings.php">
                    <i class="fas fa-cog"></i>
                    <span>Einstellungen</span>
                </a>
                <a href="logout.php" class="logout-link">
                    <i class="fas fa-sign-out-alt"></i>
                    <span>Abmelden</span>
                </a>
            </div>
        </aside>
        
        <main class="main-content">
            <header class="admin-header">
                <div class="admin-header-left">
                    <button id="toggle-sidebar" class="toggle-sidebar">
                        <i class="fas fa-bars"></i>
                    </button>
                    <h2><?php echo htmlspecialchars($pageTitle); ?></h2>
                </div>
                
                <div class="admin-header-right">
                    <div class="admin-user">
                        <span>
                            <i class="fas fa-user-circle"></i>
                            <?php echo htmlspecialchars($_SESSION['admin_username']); ?>
                        </span>
                    </div>
                </div>
            </header>
            
            <div class="content-wrapper">
                <?php if (isset($_SESSION['success_message'])): ?>
                    <div class="alert alert-success">
                        <?php 
                        echo htmlspecialchars($_SESSION['success_message']); 
                        unset($_SESSION['success_message']);
                        ?>
                    </div>
                <?php endif; ?>
                
                <?php if (isset($_SESSION['error_message'])): ?>
                    <div class="alert alert-danger">
                        <?php 
                        echo htmlspecialchars($_SESSION['error_message']); 
                        unset($_SESSION['error_message']);
                        ?>
                    </div>
                <?php endif; ?> 