<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Aktion Löschen
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    
    try {
        // Produkt-Informationen abrufen, um das Bild zu löschen
        $stmt = $conn->prepare("SELECT image_path FROM products WHERE id = ?");
        $stmt->execute([$id]);
        $product = $stmt->fetch();
        
        // Produkt löschen
        $stmt = $conn->prepare("DELETE FROM products WHERE id = ?");
        $stmt->execute([$id]);
        
        if ($stmt->rowCount() > 0) {
            // Wenn ein Bild vorhanden ist, dieses löschen
            if (!empty($product['image_path']) && file_exists($product['image_path'])) {
                unlink($product['image_path']);
            }
            
            $_SESSION['success_message'] = "Produkt wurde erfolgreich gelöscht.";
        } else {
            $_SESSION['error_message'] = "Produkt konnte nicht gefunden werden.";
        }
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
    
    header('Location: products.php');
    exit;
}

// Aktion Bearbeiten oder Hinzufügen
$editMode = false;
$productData = [
    'id' => null,
    'name' => '',
    'short_description' => '',
    'description' => '',
    'image_path' => '',
    'active' => 1,
    'sort_order' => 0,
    'stock_level' => 0,
    'show_stock_info' => 1
];

// Bei Bearbeiten Produkt-Daten laden
if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM products WHERE id = ?");
    $stmt->execute([$id]);
    $product = $stmt->fetch();
    
    if ($product) {
        $editMode = true;
        $productData = $product;
    }
}

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $shortDescription = trim($_POST['short_description']);
    $description = trim($_POST['description']);
    $active = isset($_POST['active']) ? 1 : 0;
    $sortOrder = (int)$_POST['sort_order'];
    $stockLevel = (int)$_POST['stock_level'];
    $showStockInfo = isset($_POST['show_stock_info']) ? 1 : 0;
    $editId = isset($_POST['id']) ? (int)$_POST['id'] : null;
    $currentImage = $_POST['current_image'] ?? '';
    $uploadedImage = false;
    
    // Überprüfen, ob ein Bild hochgeladen wurde
    if (isset($_FILES['image']) && $_FILES['image']['error'] !== UPLOAD_ERR_NO_FILE) {
        $uploadDir = '../uploads/products/';
        
        // Überprüfen, ob der Upload-Ordner existiert, sonst erstellen
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0755, true);
        }
        
        $fileExtension = strtolower(pathinfo($_FILES['image']['name'], PATHINFO_EXTENSION));
        $fileName = 'product_' . time() . '.' . $fileExtension;
        $targetFilePath = $uploadDir . $fileName;
        
        // Erlaubte Dateitypen
        $allowedTypes = ['jpg', 'jpeg', 'png', 'gif'];
        
        // Maximale Dateigröße (500 KB)
        $maxFileSize = 500 * 1024; // 500 KB in Bytes
        
        if (!in_array($fileExtension, $allowedTypes)) {
            $_SESSION['error_message'] = "Nur JPG, JPEG, PNG und GIF Dateien sind erlaubt.";
        } 
        elseif ($_FILES['image']['size'] > $maxFileSize) {
            // Bild ist zu groß, versuchen wir es zu komprimieren
            if (in_array($fileExtension, ['jpg', 'jpeg'])) {
                // JPEG-Bild komprimieren
                $image = imagecreatefromjpeg($_FILES['image']['tmp_name']);
                if ($image) {
                    // Bild mit 75% Qualität speichern
                    imagejpeg($image, $targetFilePath, 75);
                    $uploadedImage = true;
                    $imagePath = $targetFilePath;
                    
                    // Altes Bild löschen, wenn ein neues hochgeladen wurde
                    if (!empty($currentImage) && file_exists($currentImage)) {
                        unlink($currentImage);
                    }
                } else {
                    $_SESSION['error_message'] = "Bild ist zu groß (max. 500 KB) und konnte nicht komprimiert werden.";
                }
            } 
            elseif ($fileExtension === 'png') {
                // PNG-Bild komprimieren
                $image = imagecreatefrompng($_FILES['image']['tmp_name']);
                if ($image) {
                    // PNG-Komprimierung mit reduzierter Qualität
                    imagepng($image, $targetFilePath, 6); // 0-9, wobei 0 keine Komprimierung und 9 maximale Komprimierung ist
                    $uploadedImage = true;
                    $imagePath = $targetFilePath;
                    
                    // Altes Bild löschen, wenn ein neues hochgeladen wurde
                    if (!empty($currentImage) && file_exists($currentImage)) {
                        unlink($currentImage);
                    }
                } else {
                    $_SESSION['error_message'] = "Bild ist zu groß (max. 500 KB) und konnte nicht komprimiert werden.";
                }
            } 
            else {
                $_SESSION['error_message'] = "Bild ist zu groß (max. 500 KB). Bitte verkleinern Sie das Bild vor dem Hochladen.";
            }
        } 
        else if (move_uploaded_file($_FILES['image']['tmp_name'], $targetFilePath)) {
            $imagePath = $targetFilePath;
            $uploadedImage = true;
            
            // Altes Bild löschen, wenn ein neues hochgeladen wurde
            if (!empty($currentImage) && file_exists($currentImage)) {
                unlink($currentImage);
            }
        } else {
            $_SESSION['error_message'] = "Fehler beim Hochladen des Bildes.";
        }
    } else {
        $imagePath = $currentImage;
    }
    
    // Zusätzliche Bilder verarbeiten (nur für bereits existierende Produkte)
    $additionalImages = [];
    if ($editId && isset($_FILES['additional_images']) && !empty($_FILES['additional_images']['name'][0])) {
        $uploadDir = '../uploads/products/additional/';
        
        // Überprüfen, ob der Upload-Ordner existiert, sonst erstellen
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0755, true);
        }
        
        // Erlaubte Dateitypen
        $allowedTypes = ['jpg', 'jpeg', 'png', 'gif'];
        
        // Maximale Dateigröße (500 KB)
        $maxFileSize = 500 * 1024; // 500 KB in Bytes
        
        // Anzahl der bereits vorhandenen zusätzlichen Bilder prüfen
        $existingImagesStmt = $conn->prepare("SELECT COUNT(*) FROM product_images WHERE product_id = ?");
        $existingImagesStmt->execute([$editId]);
        $existingImagesCount = $existingImagesStmt->fetchColumn();
        
        // Maximale Anzahl an zusätzlichen Bildern ist 4
        $maxAdditionalImages = 4 - $existingImagesCount;
        
        // Bilder hochladen
        for ($i = 0; $i < count($_FILES['additional_images']['name']) && $i < $maxAdditionalImages; $i++) {
            if ($_FILES['additional_images']['error'][$i] === UPLOAD_ERR_OK) {
                $fileExtension = strtolower(pathinfo($_FILES['additional_images']['name'][$i], PATHINFO_EXTENSION));
                $fileName = 'product_' . $editId . '_additional_' . time() . '_' . $i . '.' . $fileExtension;
                $targetFilePath = $uploadDir . $fileName;
                
                if (!in_array($fileExtension, $allowedTypes)) {
                    $_SESSION['error_message'] = "Nur JPG, JPEG, PNG und GIF Dateien sind erlaubt.";
                    continue;
                }
                
                // Größenprüfung
                if ($_FILES['additional_images']['size'][$i] > $maxFileSize) {
                    // Bild ist zu groß, versuchen wir es zu komprimieren
                    if (in_array($fileExtension, ['jpg', 'jpeg'])) {
                        // JPEG-Bild komprimieren
                        $image = imagecreatefromjpeg($_FILES['additional_images']['tmp_name'][$i]);
                        if ($image) {
                            // Bild mit 75% Qualität speichern
                            imagejpeg($image, $targetFilePath, 75);
                            $additionalImages[] = $targetFilePath;
                        } else {
                            // Komprimierung fehlgeschlagen, überspringen
                            continue;
                        }
                    } 
                    elseif ($fileExtension === 'png') {
                        // PNG-Bild komprimieren
                        $image = imagecreatefrompng($_FILES['additional_images']['tmp_name'][$i]);
                        if ($image) {
                            // PNG-Komprimierung mit reduzierter Qualität
                            imagepng($image, $targetFilePath, 6);
                            $additionalImages[] = $targetFilePath;
                        } else {
                            // Komprimierung fehlgeschlagen, überspringen
                            continue;
                        }
                    }
                    else {
                        // Für GIF und andere Formate keine Komprimierung
                        continue;
                    }
                }
                else if (move_uploaded_file($_FILES['additional_images']['tmp_name'][$i], $targetFilePath)) {
                    $additionalImages[] = $targetFilePath;
                }
            }
        }
    }
    
    try {
        if ($editId) {
            // Update bestehender Eintrag
            $stmt = $conn->prepare("UPDATE products SET name = ?, short_description = ?, description = ?, image_path = ?, active = ?, sort_order = ?, stock_level = ?, show_stock_info = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
            $stmt->execute([$name, $shortDescription, $description, $uploadedImage ? $imagePath : $currentImage, $active, $sortOrder, $stockLevel, $showStockInfo, $editId]);
            
            // Zusätzliche Bilder speichern
            if (!empty($additionalImages)) {
                $addImageStmt = $conn->prepare("INSERT INTO product_images (product_id, image_path, sort_order) VALUES (?, ?, ?)");
                $sort = 0;
                
                // Aktuellen höchsten sort_order-Wert ermitteln
                $sortStmt = $conn->prepare("SELECT MAX(sort_order) FROM product_images WHERE product_id = ?");
                $sortStmt->execute([$editId]);
                $maxSort = $sortStmt->fetchColumn();
                
                if ($maxSort !== false) {
                    $sort = $maxSort + 1;
                }
                
                foreach ($additionalImages as $imgPath) {
                    $addImageStmt->execute([$editId, $imgPath, $sort]);
                    $sort++;
                }
            }
            
            $_SESSION['success_message'] = "Produkt wurde erfolgreich aktualisiert.";
        } else {
            // Neuen Eintrag erstellen
            $stmt = $conn->prepare("INSERT INTO products (name, short_description, description, image_path, active, sort_order, stock_level, show_stock_info) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([$name, $shortDescription, $description, $uploadedImage ? $imagePath : '', $active, $sortOrder, $stockLevel, $showStockInfo]);
            $_SESSION['success_message'] = "Neues Produkt wurde erfolgreich hinzugefügt.";
        }
        
        header('Location: products.php');
        exit;
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
}

// Aktion: Schnelles Update des Lagerbestands
if (isset($_POST['action']) && $_POST['action'] === 'update_stock') {
    if (isset($_POST['product_id']) && isset($_POST['stock_level'])) {
        $productId = (int)$_POST['product_id'];
        $stockLevel = (int)$_POST['stock_level'];
        
        try {
            $stmt = $conn->prepare("UPDATE products SET stock_level = ? WHERE id = ?");
            $stmt->execute([$stockLevel, $productId]);
            
            // Erfolg als JSON zurückgeben
            header('Content-Type: application/json');
            echo json_encode(['success' => true, 'message' => 'Lagerbestand aktualisiert']);
            exit;
        } catch (PDOException $e) {
            // Fehler als JSON zurückgeben
            header('Content-Type: application/json');
            echo json_encode(['success' => false, 'message' => 'Fehler: ' . $e->getMessage()]);
            exit;
        }
    }
}

// Aktion: Zusätzliches Bild löschen (direkter Aufruf via GET)
if (isset($_GET['action']) && $_GET['action'] === 'delete_image' && isset($_GET['id']) && isset($_GET['product_id'])) {
    $imageId = (int)$_GET['id'];
    $productId = (int)$_GET['product_id']; // Für Rückleitung
    
    try {
        // Bild-Informationen abrufen, um die Datei zu löschen
        $stmt = $conn->prepare("SELECT image_path FROM product_images WHERE id = ?");
        $stmt->execute([$imageId]);
        $image = $stmt->fetch();
        
        if ($image) {
            // Bild aus der Datenbank löschen
            $stmt = $conn->prepare("DELETE FROM product_images WHERE id = ?");
            $stmt->execute([$imageId]);
            
            // Bilddatei löschen, wenn sie existiert
            if (file_exists($image['image_path'])) {
                unlink($image['image_path']);
            }
            
            $_SESSION['success_message'] = "Das Bild wurde erfolgreich gelöscht.";
        } else {
            $_SESSION['error_message'] = "Bild konnte nicht gefunden werden.";
        }
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
    
    // Zurück zur Produkt-Bearbeitungsseite
    header("Location: products.php?action=edit&id=" . $productId);
    exit;
}

// Alle Produkte abrufen - optimierte Abfrage, nur notwendige Felder
$stmt = $conn->prepare("SELECT id, name, short_description, image_path, active, sort_order, stock_level, show_stock_info FROM products ORDER BY sort_order, name");
$stmt->execute();
$products = $stmt->fetchAll();

// Seitentitel setzen und Header einfügen
$pageTitle = "Produkte";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Produkte verwalten</h3>
    <div>
        <a href="inventory.php" class="btn btn-success">
            <i class="fas fa-boxes"></i> Lagerbestand verwalten
        </a>
        <button type="button" class="btn btn-primary" onclick="document.getElementById('productForm').reset(); document.getElementById('productFormTitle').textContent = 'Neues Produkt hinzufügen'; document.getElementById('formContainer').style.display = 'block';">
            <i class="fas fa-plus"></i> Neues Produkt hinzufügen
        </button>
    </div>
</div>

<?php if (isset($_SESSION['success_message'])): ?>
    <div class="alert alert-success">
        <?php 
        echo $_SESSION['success_message']; 
        unset($_SESSION['success_message']); 
        ?>
    </div>
<?php endif; ?>

<?php if (isset($_SESSION['error_message'])): ?>
    <div class="alert alert-danger">
        <?php 
        echo $_SESSION['error_message']; 
        unset($_SESSION['error_message']); 
        ?>
    </div>
<?php endif; ?>

<div class="form-card" id="formContainer" style="<?php echo $editMode ? 'display: block;' : 'display: none;'; ?>">
    <h3 id="productFormTitle"><?php echo $editMode ? 'Produkt bearbeiten' : 'Neues Produkt hinzufügen'; ?></h3>
    
    <form action="products.php" method="post" enctype="multipart/form-data" id="productForm">
        <?php if ($editMode): ?>
            <input type="hidden" name="id" value="<?php echo $productData['id']; ?>">
        <?php endif; ?>
        <input type="hidden" name="current_image" value="<?php echo htmlspecialchars($productData['image_path'] ?? ''); ?>">
        
        <div class="form-group">
            <label for="name">Name</label>
            <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($productData['name']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="short_description">Kurzbeschreibung</label>
            <textarea id="short_description" name="short_description" class="form-control" rows="2"><?php echo htmlspecialchars($productData['short_description'] ?? ''); ?></textarea>
            <small class="form-text text-muted">Kurze Beschreibung für Produktübersicht (max. 150 Zeichen)</small>
        </div>
        
        <div class="form-group">
            <label for="description">Detailbeschreibung</label>
            <textarea id="description" name="description" class="form-control" rows="5"><?php echo htmlspecialchars($productData['description'] ?? ''); ?></textarea>
        </div>
        
        <div class="form-group">
            <label for="image">Hauptproduktbild</label>
            <div class="custom-file">
                <input type="file" id="image" name="image" class="custom-file-input" accept="image/*">
                <label for="image" class="custom-file-label">Datei auswählen</label>
            </div>
            <small class="form-text text-muted">Maximale Dateigröße: 500 KB. Größere Bilder werden automatisch komprimiert.</small>
            
            <?php if (!empty($productData['image_path']) && file_exists($productData['image_path'])): ?>
                <div class="image-preview" style="display: block; margin-top: 10px;">
                    <img src="<?php echo htmlspecialchars($productData['image_path']); ?>" alt="Produktbild" style="max-width: 200px; max-height: 150px; object-fit: contain;" loading="lazy">
                </div>
            <?php endif; ?>
        </div>
        
        <?php if ($editMode): ?>
        <div class="form-group">
            <label>Zusätzliche Produktbilder (max. 4)</label>
            <div id="additional-images-container">
                <!-- Hier werden bestehende zusätzliche Bilder angezeigt -->
                <?php
                if ($editMode) {
                    $additionalImagesStmt = $conn->prepare("SELECT * FROM product_images WHERE product_id = ? ORDER BY sort_order LIMIT 4");
                    $additionalImagesStmt->execute([$productData['id']]);
                    $additionalImages = $additionalImagesStmt->fetchAll();
                    
                    if ($additionalImages) {
                        echo '<div class="row mb-3">';
                        foreach ($additionalImages as $img) {
                            echo '<div class="col-md-3 col-sm-6 mb-2 additional-image-item">';
                            echo '<div class="card">';
                            echo '<img src="' . htmlspecialchars($img['image_path']) . '" class="card-img-top" style="height: 150px; object-fit: cover;" loading="lazy">';
                            echo '<div class="card-body p-2 text-center">';
                            echo '<a href="products.php?action=delete_image&id=' . $img['id'] . '&product_id=' . $productData['id'] . '" class="btn btn-sm btn-danger" onclick="return confirm(\'Sind Sie sicher, dass Sie dieses Bild löschen möchten?\')">Entfernen</a>';
                            echo '</div>';
                            echo '</div>';
                            echo '</div>';
                        }
                        echo '</div>';
                    } else {
                        echo '<p>Keine zusätzlichen Bilder vorhanden.</p>';
                    }
                }
                ?>
            </div>
            
            <div class="mt-3">
                <div class="custom-file">
                    <input type="file" id="additional-images" name="additional_images[]" class="custom-file-input" accept="image/*" multiple>
                    <label for="additional-images" class="custom-file-label">Zusätzliche Bilder auswählen (max. 4)</label>
                </div>
                <small class="form-text text-muted">Sie können bis zu 4 zusätzliche Bilder für dieses Produkt hochladen. Maximale Dateigröße pro Bild: 500 KB.</small>
            </div>
        </div>
        <?php endif; ?>
        
        <div class="form-group">
            <label for="sort_order">Sortierreihenfolge</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="<?php echo $productData['sort_order']; ?>" min="0">
        </div>
        
        <div class="form-group">
            <label for="stock_level">Lagerbestand</label>
            <input type="number" id="stock_level" name="stock_level" class="form-control" value="<?php echo $productData['stock_level'] ?? 0; ?>" min="0">
        </div>
        
        <div class="form-group">
            <div class="custom-control custom-checkbox">
                <input type="checkbox" id="active" name="active" class="custom-control-input" <?php echo $productData['active'] ? 'checked' : ''; ?>>
                <label class="custom-control-label" for="active">Aktiv</label>
            </div>
        </div>
        
        <div class="form-group">
            <div class="custom-control custom-checkbox">
                <input type="checkbox" id="show_stock_info" name="show_stock_info" class="custom-control-input" <?php echo $productData['show_stock_info'] ?? 1 ? 'checked' : ''; ?>>
                <label class="custom-control-label" for="show_stock_info">Lagerbestand anzeigen</label>
            </div>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
            <button type="button" class="btn btn-secondary" onclick="document.getElementById('formContainer').style.display = 'none';">Abbrechen</button>
        </div>
    </form>
</div>

<div class="table-responsive">
    <table>
        <thead>
            <tr>
                <th>Bild</th>
                <th>Name</th>
                <th>Kurzbeschreibung</th>
                <th>Sortierung</th>
                <th>Lagerbestand</th>
                <th>Status</th>
                <th>Aktionen</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($products) > 0): ?>
                <?php foreach ($products as $product): ?>
                    <tr>
                        <td>
                            <?php if (!empty($product['image_path']) && file_exists($product['image_path'])): ?>
                                <img src="<?php echo htmlspecialchars($product['image_path']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" style="max-width: 50px; max-height: 50px;" loading="lazy">
                            <?php else: ?>
                                <i class="fas fa-box" style="font-size: 1.5rem; color: #ccc;"></i>
                            <?php endif; ?>
                        </td>
                        <td><?php echo htmlspecialchars($product['name']); ?></td>
                        <td><?php echo htmlspecialchars(substr($product['short_description'] ?? '', 0, 50) . (strlen($product['short_description'] ?? '') > 50 ? '...' : '')); ?></td>
                        <td><?php echo $product['sort_order']; ?></td>
                        <td>
                            <?php echo $product['stock_level']; ?>
                            <?php if ($product['show_stock_info']): ?>
                                <span class="badge badge-info">Angezeigt</span>
                            <?php else: ?>
                                <span class="badge badge-secondary">Verborgen</span>
                            <?php endif; ?>
                        </td>
                        <td>
                            <span class="badge <?php echo $product['active'] ? 'badge-success' : 'badge-danger'; ?>">
                                <?php echo $product['active'] ? 'Aktiv' : 'Inaktiv'; ?>
                            </span>
                        </td>
                        <td>
                            <div class="table-actions">
                                <a href="products.php?action=edit&id=<?php echo $product['id']; ?>" class="btn btn-sm btn-primary">
                                    <i class="fas fa-edit"></i> Bearbeiten
                                </a>
                                <a href="products.php?action=delete&id=<?php echo $product['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Sind Sie sicher, dass Sie dieses Produkt löschen möchten?')">
                                    <i class="fas fa-trash-alt"></i> Löschen
                                </a>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="7" class="text-center">Keine Produkte gefunden.</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<script>
    // Initialisiere den Dateinamen für den Datei-Upload
    $('.custom-file-input').on('change', function() {
        const fileName = $(this).val().split('\\').pop();
        $(this).next('.custom-file-label').html(fileName || 'Datei auswählen');
    });
    
    // Multiple Datei-Upload Anzeigen
    $('#additional-images').on('change', function() {
        const fileCount = this.files.length;
        let fileNames = '';
        
        if (fileCount > 0) {
            if (fileCount > 4) {
                fileNames = `${fileCount} Dateien ausgewählt (max. 4 werden verwendet)`;
            } else {
                fileNames = `${fileCount} Dateien ausgewählt`;
            }
        } else {
            fileNames = 'Zusätzliche Bilder auswählen';
        }
        
        $(this).next('.custom-file-label').html(fileNames);
    });
</script>

<?php include('includes/footer.php'); ?> 