<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Änderungen speichern, wenn Formular abgeschickt wurde
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_visibility'])) {
    try {
        // Alle Bereiche auf unsichtbar setzen
        $stmt = $conn->prepare("UPDATE section_visibility SET visible = 0");
        $stmt->execute();
        
        // Ausgewählte Bereiche auf sichtbar setzen
        if (isset($_POST['visible_sections']) && is_array($_POST['visible_sections'])) {
            $stmt = $conn->prepare("UPDATE section_visibility SET visible = 1 WHERE section_name = ?");
            foreach ($_POST['visible_sections'] as $section) {
                $stmt->execute([$section]);
            }
        }
        
        $_SESSION['success_message'] = "Die Sichtbarkeit der Bereiche wurde erfolgreich aktualisiert.";
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Fehler beim Speichern: " . $e->getMessage();
    }
}

// Aktuelle Sichtbarkeitseinstellungen laden
$stmt = $conn->query("SELECT section_name, visible FROM section_visibility");
$sections = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);

// Abschnittsnamen für die Anzeige
$section_labels = [
    'about' => 'Über uns',
    'products' => 'Produkte',
    'shops' => 'Shops',
    'testimonials' => 'Kundenstimmen',
    'orders' => 'Bestellformulare',
    'contact' => 'Kontakt'
];

// Seitentitel setzen und Header einfügen
$pageTitle = "Bereiche verwalten";
include('includes/header.php');
?>

<div class="form-card">
    <h3>Sichtbare Bereiche verwalten</h3>
    <p>Hier können Sie festlegen, welche Bereiche auf der Webseite angezeigt werden sollen.</p>
    
    <form action="sections.php" method="post">
        <input type="hidden" name="save_visibility" value="1">
        
        <div class="section-visibility-options">
            <?php foreach ($section_labels as $section_id => $section_name): ?>
                <div class="form-check">
                    <input type="checkbox" class="form-check-input" id="section_<?php echo $section_id; ?>" 
                           name="visible_sections[]" value="<?php echo $section_id; ?>"
                           <?php echo (isset($sections[$section_id]) && $sections[$section_id] == 1) ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="section_<?php echo $section_id; ?>">
                        <?php echo htmlspecialchars($section_name); ?> anzeigen
                    </label>
                </div>
            <?php endforeach; ?>
        </div>
        
        <div class="form-group mt-4">
            <button type="submit" class="btn btn-primary">Änderungen speichern</button>
        </div>
    </form>
</div>

<div class="form-card">
    <h3>Hinweise</h3>
    <ul>
        <li>Wenn ein Bereich ausgeblendet wird, werden die entsprechenden Inhalte weiterhin in der Datenbank gespeichert.</li>
        <li>Die Navigation wird automatisch angepasst, wenn bestimmte Bereiche ausgeblendet werden.</li>
        <li>Der Hero-Bereich ist immer sichtbar und kann separat über die Hero-Bereicheinstellungen angepasst werden.</li>
    </ul>
</div>

<style>
.section-visibility-options {
    margin: 20px 0;
}

.form-check {
    margin-bottom: 15px;
    padding: 15px;
    background-color: #f8f9fa;
    border-radius: 8px;
    transition: all 0.3s;
}

.form-check:hover {
    background-color: #e9ecef;
}

.form-check-input {
    margin-right: 10px;
    transform: scale(1.2);
}

.form-check-label {
    font-weight: 500;
    font-size: 1.1rem;
}
</style>

<?php include('includes/footer.php'); ?> 