<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Aktion Löschen
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    
    try {
        // Shop-Informationen abrufen, um das Logo zu löschen
        $stmt = $conn->prepare("SELECT logo_path FROM shops WHERE id = ?");
        $stmt->execute([$id]);
        $shop = $stmt->fetch();
        
        // Shop löschen
        $stmt = $conn->prepare("DELETE FROM shops WHERE id = ?");
        $stmt->execute([$id]);
        
        if ($stmt->rowCount() > 0) {
            // Wenn ein Logo vorhanden ist, dieses löschen
            if (!empty($shop['logo_path']) && file_exists($shop['logo_path'])) {
                unlink($shop['logo_path']);
            }
            
            $_SESSION['success_message'] = "Shop wurde erfolgreich gelöscht.";
        } else {
            $_SESSION['error_message'] = "Shop konnte nicht gefunden werden.";
        }
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
    
    header('Location: shops.php');
    exit;
}

// Aktion Bearbeiten oder Hinzufügen
$editMode = false;
$shopData = [
    'id' => null,
    'name' => '',
    'description' => '',
    'url' => '',
    'logo_path' => '',
    'active' => 1,
    'sort_order' => 0
];

// Bei Bearbeiten Shop-Daten laden
if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM shops WHERE id = ?");
    $stmt->execute([$id]);
    $shop = $stmt->fetch();
    
    if ($shop) {
        $editMode = true;
        $shopData = $shop;
    }
}

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $description = trim($_POST['description']);
    $url = trim($_POST['url']);
    $active = isset($_POST['active']) ? 1 : 0;
    $sortOrder = (int)$_POST['sort_order'];
    $editId = isset($_POST['id']) ? (int)$_POST['id'] : null;
    $currentLogo = $_POST['current_logo'] ?? '';
    $uploadedLogo = false;
    
    // Überprüfen, ob ein Logo hochgeladen wurde
    if (isset($_FILES['logo']) && $_FILES['logo']['error'] !== UPLOAD_ERR_NO_FILE) {
        $uploadDir = '../uploads/shops/';
        
        // Überprüfen, ob der Upload-Ordner existiert, sonst erstellen
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0755, true);
        }
        
        $fileExtension = pathinfo($_FILES['logo']['name'], PATHINFO_EXTENSION);
        $fileName = 'shop_' . time() . '.' . $fileExtension;
        $targetFilePath = $uploadDir . $fileName;
        
        // Erlaubte Dateitypen
        $allowedTypes = ['jpg', 'jpeg', 'png', 'gif'];
        
        if (in_array(strtolower($fileExtension), $allowedTypes)) {
            if (move_uploaded_file($_FILES['logo']['tmp_name'], $targetFilePath)) {
                $logoPath = $targetFilePath;
                $uploadedLogo = true;
                
                // Altes Logo löschen, wenn ein neues hochgeladen wurde
                if (!empty($currentLogo) && file_exists($currentLogo)) {
                    unlink($currentLogo);
                }
            } else {
                $_SESSION['error_message'] = "Fehler beim Hochladen des Logos.";
            }
        } else {
            $_SESSION['error_message'] = "Nur JPG, JPEG, PNG und GIF Dateien sind erlaubt.";
        }
    } else {
        $logoPath = $currentLogo;
    }
    
    try {
        if ($editId) {
            // Update bestehender Eintrag
            $stmt = $conn->prepare("UPDATE shops SET name = ?, description = ?, url = ?, logo_path = ?, active = ?, sort_order = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
            $stmt->execute([$name, $description, $url, $uploadedLogo ? $logoPath : $currentLogo, $active, $sortOrder, $editId]);
            $_SESSION['success_message'] = "Shop wurde erfolgreich aktualisiert.";
        } else {
            // Neuen Eintrag erstellen
            $stmt = $conn->prepare("INSERT INTO shops (name, description, url, logo_path, active, sort_order) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$name, $description, $url, $uploadedLogo ? $logoPath : '', $active, $sortOrder]);
            $_SESSION['success_message'] = "Neuer Shop wurde erfolgreich hinzugefügt.";
        }
        
        header('Location: shops.php');
        exit;
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
}

// Alle Shops abrufen
$stmt = $conn->prepare("SELECT * FROM shops ORDER BY sort_order, name");
$stmt->execute();
$shops = $stmt->fetchAll();

// Seitentitel setzen und Header einfügen
$pageTitle = "Shops";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Shops verwalten</h3>
    <button type="button" class="btn btn-primary" onclick="document.getElementById('shopForm').reset(); document.getElementById('shopFormTitle').textContent = 'Neuen Shop hinzufügen'; document.getElementById('formContainer').style.display = 'block';">
        <i class="fas fa-plus"></i> Neuen Shop hinzufügen
    </button>
</div>

<div class="form-card" id="formContainer" style="<?php echo $editMode ? 'display: block;' : 'display: none;'; ?>">
    <h3 id="shopFormTitle"><?php echo $editMode ? 'Shop bearbeiten' : 'Neuen Shop hinzufügen'; ?></h3>
    
    <form action="shops.php" method="post" enctype="multipart/form-data" id="shopForm">
        <?php if ($editMode): ?>
            <input type="hidden" name="id" value="<?php echo $shopData['id']; ?>">
        <?php endif; ?>
        <input type="hidden" name="current_logo" value="<?php echo htmlspecialchars($shopData['logo_path'] ?? ''); ?>">
        
        <div class="form-group">
            <label for="name">Name</label>
            <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($shopData['name']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="description">Beschreibung</label>
            <textarea id="description" name="description" class="form-control" rows="3"><?php echo htmlspecialchars($shopData['description']); ?></textarea>
        </div>
        
        <div class="form-group">
            <label for="url">Shop-URL</label>
            <input type="url" id="url" name="url" class="form-control" value="<?php echo htmlspecialchars($shopData['url']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="logo">Logo</label>
            <div class="custom-file">
                <input type="file" id="logo" name="logo" class="custom-file-input" accept="image/*">
                <label for="logo" class="custom-file-label">Datei auswählen</label>
            </div>
            
            <?php if (!empty($shopData['logo_path']) && file_exists($shopData['logo_path'])): ?>
                <div class="image-preview" style="display: block; margin-top: 10px;">
                    <img src="<?php echo htmlspecialchars($shopData['logo_path']); ?>" alt="Shop-Logo" style="max-width: 150px;">
                </div>
            <?php endif; ?>
        </div>
        
        <div class="form-group">
            <label for="sort_order">Sortierreihenfolge</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="<?php echo $shopData['sort_order']; ?>" min="0">
        </div>
        
        <div class="form-group">
            <div class="custom-control custom-checkbox">
                <input type="checkbox" id="active" name="active" class="custom-control-input" <?php echo $shopData['active'] ? 'checked' : ''; ?>>
                <label class="custom-control-label" for="active">Aktiv</label>
            </div>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
            <button type="button" class="btn btn-secondary" onclick="document.getElementById('formContainer').style.display = 'none';">Abbrechen</button>
        </div>
    </form>
</div>

<div class="table-responsive">
    <table>
        <thead>
            <tr>
                <th>Logo</th>
                <th>Name</th>
                <th>URL</th>
                <th>Sortierung</th>
                <th>Status</th>
                <th>Aktionen</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($shops) > 0): ?>
                <?php foreach ($shops as $shop): ?>
                    <tr>
                        <td>
                            <?php if (!empty($shop['logo_path']) && file_exists($shop['logo_path'])): ?>
                                <img src="<?php echo htmlspecialchars($shop['logo_path']); ?>" alt="<?php echo htmlspecialchars($shop['name']); ?>" style="max-width: 50px; max-height: 50px;">
                            <?php else: ?>
                                <i class="fas fa-store" style="font-size: 1.5rem; color: #ccc;"></i>
                            <?php endif; ?>
                        </td>
                        <td><?php echo htmlspecialchars($shop['name']); ?></td>
                        <td>
                            <a href="<?php echo htmlspecialchars($shop['url']); ?>" target="_blank">
                                <?php echo htmlspecialchars($shop['url']); ?>
                            </a>
                        </td>
                        <td><?php echo $shop['sort_order']; ?></td>
                        <td>
                            <span class="badge <?php echo $shop['active'] ? 'badge-success' : 'badge-danger'; ?>">
                                <?php echo $shop['active'] ? 'Aktiv' : 'Inaktiv'; ?>
                            </span>
                        </td>
                        <td>
                            <div class="table-actions">
                                <a href="shops.php?action=edit&id=<?php echo $shop['id']; ?>" class="btn btn-sm btn-primary">
                                    <i class="fas fa-edit"></i> Bearbeiten
                                </a>
                                <a href="shops.php?action=delete&id=<?php echo $shop['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Sind Sie sicher, dass Sie diesen Shop löschen möchten?')">
                                    <i class="fas fa-trash-alt"></i> Löschen
                                </a>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="6" class="text-center">Keine Shops gefunden.</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Edit-Links abfangen und Formular anzeigen
        document.querySelectorAll('a[href^="shops.php?action=edit"]').forEach(function(link) {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                
                const url = new URL(this.href);
                const id = url.searchParams.get('id');
                
                // AJAX-Anfrage, um Shop-Daten zu laden
                fetch('shops.php?action=edit&id=' + id)
                    .then(response => {
                        window.location.href = 'shops.php?action=edit&id=' + id;
                    })
                    .catch(error => console.error('Fehler:', error));
            });
        });
    });
</script>

<?php include('includes/footer.php'); ?> 