<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Verarbeitung des Formulars zum Speichern der Einstellungen
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Farbwerte speichern
        foreach (['primary_color', 'secondary_color', 'accent_color', 'site_title'] as $setting) {
            if (isset($_POST[$setting])) {
                $value = trim($_POST[$setting]);
                
                // Prüfen, ob die Einstellung bereits existiert
                $stmt = $conn->prepare("SELECT COUNT(*) FROM site_settings WHERE setting_name = ?");
                $stmt->execute([$setting]);
                $exists = $stmt->fetchColumn();
                
                if ($exists) {
                    // Update
                    $stmt = $conn->prepare("UPDATE site_settings SET setting_value = ? WHERE setting_name = ?");
                    $stmt->execute([$value, $setting]);
                } else {
                    // Insert
                    $stmt = $conn->prepare("INSERT INTO site_settings (setting_name, setting_value) VALUES (?, ?)");
                    $stmt->execute([$setting, $value]);
                }
            }
        }
        
        // Logo für die Bestellseite speichern
        if (!empty($_FILES['order_logo']['name'])) {
            $uploadDir = '../uploads/';
            
            // Verzeichnis erstellen, falls es nicht existiert
            if (!file_exists($uploadDir)) {
                mkdir($uploadDir, 0755, true);
            }
            
            $fileName = 'order_logo_' . time() . '_' . $_FILES['order_logo']['name'];
            $targetFilePath = $uploadDir . $fileName;
            
            // Datei hochladen
            if (move_uploaded_file($_FILES['order_logo']['tmp_name'], $targetFilePath)) {
                // Dateipfad speichern
                $relativeFilePath = 'uploads/' . $fileName;
                
                // Prüfen, ob die Einstellung bereits existiert
                $stmt = $conn->prepare("SELECT COUNT(*) FROM site_settings WHERE setting_name = 'order_logo'");
                $stmt->execute();
                $exists = $stmt->fetchColumn();
                
                if ($exists) {
                    // Altes Logo-Pfad abrufen
                    $stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'order_logo'");
                    $stmt->execute();
                    $oldLogoPath = $stmt->fetchColumn();
                    
                    // Altes Logo löschen, falls vorhanden
                    if (!empty($oldLogoPath) && file_exists('../' . $oldLogoPath)) {
                        unlink('../' . $oldLogoPath);
                    }
                    
                    // Update
                    $stmt = $conn->prepare("UPDATE site_settings SET setting_value = ? WHERE setting_name = 'order_logo'");
                    $stmt->execute([$relativeFilePath]);
                } else {
                    // Insert
                    $stmt = $conn->prepare("INSERT INTO site_settings (setting_name, setting_value) VALUES ('order_logo', ?)");
                    $stmt->execute([$relativeFilePath]);
                }
            }
        }
        
        $_SESSION['success_message'] = "Die Einstellungen wurden erfolgreich gespeichert.";
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Fehler beim Speichern der Einstellungen: " . $e->getMessage();
    }
    
    // Zurück zur gleichen Seite
    header('Location: site_settings.php');
    exit;
}

// Aktuelle Einstellungen laden
$settings = [];
try {
    $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings");
    $settings = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
} catch (PDOException $e) {
    $_SESSION['error_message'] = "Fehler beim Laden der Einstellungen: " . $e->getMessage();
}

// Standardwerte setzen, falls nicht vorhanden
if (!isset($settings['primary_color'])) $settings['primary_color'] = '#8b6b4f';
if (!isset($settings['secondary_color'])) $settings['secondary_color'] = '#333333';
if (!isset($settings['accent_color'])) $settings['accent_color'] = '#d4af37';
if (!isset($settings['site_title'])) $settings['site_title'] = 'JB Kerzen';
$orderLogo = isset($settings['order_logo']) ? $settings['order_logo'] : '';

// Header einbinden
$pageTitle = "Website-Einstellungen";
include('includes/header.php');
?>

<div class="content-header">
    <h2>Website-Einstellungen</h2>
</div>

<div class="row">
    <div class="col-md-6">
        <div class="card">
            <div class="card-header">
                <h3>Allgemeine Einstellungen</h3>
            </div>
            <div class="card-body">
                <form action="site_settings.php" method="post" enctype="multipart/form-data">
                    <div class="form-group">
                        <label for="site_title">Website-Titel</label>
                        <input type="text" class="form-control" id="site_title" name="site_title" value="<?php echo htmlspecialchars($settings['site_title']); ?>">
                        <small class="form-text text-muted">Dieser Titel wird auf allen Seiten im Browser-Tab angezeigt.</small>
                    </div>
                    
                    <div class="form-group">
                        <label for="primary_color">Primärfarbe</label>
                        <div class="input-group">
                            <div class="input-group-prepend">
                                <span class="input-group-text color-preview" style="background-color: <?php echo htmlspecialchars($settings['primary_color']); ?>"></span>
                            </div>
                            <input type="text" class="form-control" id="primary_color" name="primary_color" value="<?php echo htmlspecialchars($settings['primary_color']); ?>">
                        </div>
                        <small class="form-text text-muted">Hauptfarbe für Überschriften, Buttons und Hervorhebungen.</small>
                    </div>
                    
                    <div class="form-group">
                        <label for="secondary_color">Sekundärfarbe</label>
                        <div class="input-group">
                            <div class="input-group-prepend">
                                <span class="input-group-text color-preview" style="background-color: <?php echo htmlspecialchars($settings['secondary_color']); ?>"></span>
                            </div>
                            <input type="text" class="form-control" id="secondary_color" name="secondary_color" value="<?php echo htmlspecialchars($settings['secondary_color']); ?>">
                        </div>
                        <small class="form-text text-muted">Sekundärfarbe für den Footer und andere Elemente.</small>
                    </div>
                    
                    <div class="form-group">
                        <label for="accent_color">Akzentfarbe</label>
                        <div class="input-group">
                            <div class="input-group-prepend">
                                <span class="input-group-text color-preview" style="background-color: <?php echo htmlspecialchars($settings['accent_color']); ?>"></span>
                            </div>
                            <input type="text" class="form-control" id="accent_color" name="accent_color" value="<?php echo htmlspecialchars($settings['accent_color']); ?>">
                        </div>
                        <small class="form-text text-muted">Akzentfarbe für Hover-Effekte und Hervorhebungen.</small>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" class="btn btn-primary">Einstellungen speichern</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-6">
        <div class="card">
            <div class="card-header">
                <h3>Logo für Bestellseite</h3>
            </div>
            <div class="card-body">
                <form action="site_settings.php" method="post" enctype="multipart/form-data">
                    <?php if (!empty($orderLogo) && file_exists('../' . $orderLogo)): ?>
                        <div class="current-logo mb-4">
                            <p><strong>Aktuelles Logo:</strong></p>
                            <img src="../<?php echo htmlspecialchars($orderLogo); ?>" alt="Bestellseiten-Logo" style="max-width: 200px; max-height: 100px;">
                        </div>
                    <?php endif; ?>
                    
                    <div class="form-group">
                        <label for="order_logo">Logo hochladen</label>
                        <input type="file" class="form-control-file" id="order_logo" name="order_logo" accept="image/*">
                        <small class="form-text text-muted">
                            Das Logo wird auf der Bestellseite angezeigt. Empfohlene Größe: 200x60 Pixel.
                            <br>Unterstützte Formate: JPG, PNG, GIF.
                        </small>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" class="btn btn-primary">Logo speichern</button>
                    </div>
                </form>
            </div>
        </div>
        
        <div class="card mt-4">
            <div class="card-header">
                <h3>Vorschau</h3>
            </div>
            <div class="card-body">
                <div class="color-preview-section">
                    <h4 style="color: <?php echo htmlspecialchars($settings['primary_color']); ?>">Überschrift (Primärfarbe)</h4>
                    <p>Normaler Text</p>
                    <p style="color: <?php echo htmlspecialchars($settings['secondary_color']); ?>">Text in Sekundärfarbe</p>
                    <a href="#" style="color: <?php echo htmlspecialchars($settings['accent_color']); ?>">Link in Akzentfarbe</a>
                    <br><br>
                    <button style="background-color: <?php echo htmlspecialchars($settings['primary_color']); ?>; color: white; border: none; padding: 8px 15px; border-radius: 4px;">
                        Button
                    </button>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
.color-preview {
    width: 30px;
    height: 30px;
    border-radius: 3px;
}

.input-group-text {
    padding-top: 0;
    padding-bottom: 0;
}

.color-preview-section {
    padding: 20px;
    border: 1px solid #eee;
    border-radius: 5px;
    background-color: #f9f9f9;
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Vorschau der Farben aktualisieren, wenn sich die Eingabe ändert
    document.querySelectorAll('input[type="text"]').forEach(function(input) {
        input.addEventListener('input', function() {
            const id = this.id;
            const preview = this.parentNode.querySelector('.color-preview');
            
            if (preview) {
                preview.style.backgroundColor = this.value;
            }
            
            // Vorschau in der Farbvorschau-Sektion aktualisieren
            if (id === 'primary_color') {
                document.querySelector('.color-preview-section h4').style.color = this.value;
                document.querySelector('.color-preview-section button').style.backgroundColor = this.value;
            } else if (id === 'secondary_color') {
                document.querySelector('.color-preview-section p[style]').style.color = this.value;
            } else if (id === 'accent_color') {
                document.querySelector('.color-preview-section a').style.color = this.value;
            }
        });
    });
});
</script>

<?php include('includes/footer.php'); ?> 