<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Aktion Löschen
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    
    try {
        // Testimonial löschen
        $stmt = $conn->prepare("DELETE FROM testimonials WHERE id = ?");
        $stmt->execute([$id]);
        
        if ($stmt->rowCount() > 0) {
            $_SESSION['success_message'] = "Kundenstimme wurde erfolgreich gelöscht.";
        } else {
            $_SESSION['error_message'] = "Kundenstimme konnte nicht gefunden werden.";
        }
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
    
    header('Location: testimonials.php');
    exit;
}

// Aktion Bearbeiten oder Hinzufügen
$editMode = false;
$testimonialData = [
    'id' => null,
    'author' => '',
    'content' => '',
    'active' => 1,
    'sort_order' => 0
];

// Bei Bearbeiten Testimonial-Daten laden
if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM testimonials WHERE id = ?");
    $stmt->execute([$id]);
    $testimonial = $stmt->fetch();
    
    if ($testimonial) {
        $editMode = true;
        $testimonialData = $testimonial;
    }
}

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $author = trim($_POST['author']);
    $content = trim($_POST['content']);
    $active = isset($_POST['active']) ? 1 : 0;
    $sortOrder = (int)$_POST['sort_order'];
    $editId = isset($_POST['id']) ? (int)$_POST['id'] : null;
    
    try {
        if ($editId) {
            // Update bestehender Eintrag
            $stmt = $conn->prepare("UPDATE testimonials SET author = ?, content = ?, active = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([$author, $content, $active, $sortOrder, $editId]);
            $_SESSION['success_message'] = "Kundenstimme wurde erfolgreich aktualisiert.";
        } else {
            // Neuen Eintrag erstellen
            $stmt = $conn->prepare("INSERT INTO testimonials (author, content, active, sort_order) VALUES (?, ?, ?, ?)");
            $stmt->execute([$author, $content, $active, $sortOrder]);
            $_SESSION['success_message'] = "Neue Kundenstimme wurde erfolgreich hinzugefügt.";
        }
        
        header('Location: testimonials.php');
        exit;
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
}

// Alle Testimonials abrufen
$stmt = $conn->prepare("SELECT * FROM testimonials ORDER BY sort_order, id");
$stmt->execute();
$testimonials = $stmt->fetchAll();

// Seitentitel setzen und Header einfügen
$pageTitle = "Kundenstimmen";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Kundenstimmen verwalten</h3>
    <button type="button" class="btn btn-primary" onclick="document.getElementById('testimonialForm').reset(); document.getElementById('testimonialFormTitle').textContent = 'Neue Kundenstimme hinzufügen'; document.getElementById('formContainer').style.display = 'block';">
        <i class="fas fa-plus"></i> Neue Kundenstimme hinzufügen
    </button>
</div>

<div class="form-card" id="formContainer" style="<?php echo $editMode ? 'display: block;' : 'display: none;'; ?>">
    <h3 id="testimonialFormTitle"><?php echo $editMode ? 'Kundenstimme bearbeiten' : 'Neue Kundenstimme hinzufügen'; ?></h3>
    
    <form action="testimonials.php" method="post" id="testimonialForm">
        <?php if ($editMode): ?>
            <input type="hidden" name="id" value="<?php echo $testimonialData['id']; ?>">
        <?php endif; ?>
        
        <div class="form-group">
            <label for="author">Name des Kunden</label>
            <input type="text" id="author" name="author" class="form-control" value="<?php echo htmlspecialchars($testimonialData['author']); ?>" required>
        </div>
        
        <div class="form-group">
            <label for="content">Kundenstimme</label>
            <textarea id="content" name="content" class="form-control" rows="4" required><?php echo htmlspecialchars($testimonialData['content']); ?></textarea>
        </div>
        
        <div class="form-group">
            <label for="sort_order">Sortierreihenfolge</label>
            <input type="number" id="sort_order" name="sort_order" class="form-control" value="<?php echo $testimonialData['sort_order']; ?>" min="0">
        </div>
        
        <div class="form-group">
            <div class="custom-control custom-checkbox">
                <input type="checkbox" id="active" name="active" class="custom-control-input" <?php echo $testimonialData['active'] ? 'checked' : ''; ?>>
                <label class="custom-control-label" for="active">Aktiv</label>
            </div>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
            <button type="button" class="btn btn-secondary" onclick="document.getElementById('formContainer').style.display = 'none';">Abbrechen</button>
        </div>
    </form>
</div>

<div class="table-responsive">
    <table>
        <thead>
            <tr>
                <th>Name</th>
                <th>Kundenstimme</th>
                <th>Sortierung</th>
                <th>Status</th>
                <th>Aktionen</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($testimonials) > 0): ?>
                <?php foreach ($testimonials as $testimonial): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($testimonial['author']); ?></td>
                        <td><?php echo htmlspecialchars(substr($testimonial['content'], 0, 100) . (strlen($testimonial['content']) > 100 ? '...' : '')); ?></td>
                        <td><?php echo $testimonial['sort_order']; ?></td>
                        <td>
                            <span class="badge <?php echo $testimonial['active'] ? 'badge-success' : 'badge-danger'; ?>">
                                <?php echo $testimonial['active'] ? 'Aktiv' : 'Inaktiv'; ?>
                            </span>
                        </td>
                        <td>
                            <div class="table-actions">
                                <a href="testimonials.php?action=edit&id=<?php echo $testimonial['id']; ?>" class="btn btn-sm btn-primary">
                                    <i class="fas fa-edit"></i> Bearbeiten
                                </a>
                                <a href="testimonials.php?action=delete&id=<?php echo $testimonial['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Sind Sie sicher, dass Sie diese Kundenstimme löschen möchten?')">
                                    <i class="fas fa-trash-alt"></i> Löschen
                                </a>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="5" class="text-center">Keine Kundenstimmen gefunden.</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // Edit-Links abfangen und Formular anzeigen
        document.querySelectorAll('a[href^="testimonials.php?action=edit"]').forEach(function(link) {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                
                const url = new URL(this.href);
                const id = url.searchParams.get('id');
                
                // AJAX-Anfrage, um Testimonial-Daten zu laden
                fetch('testimonials.php?action=edit&id=' + id)
                    .then(response => {
                        window.location.href = 'testimonials.php?action=edit&id=' + id;
                    })
                    .catch(error => console.error('Fehler:', error));
            });
        });
    });
</script>

<?php include('includes/footer.php'); ?> 