<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

$voucherId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if (!$voucherId) {
    header('Location: vouchers.php');
    exit;
}

// Gutschein-Daten laden
$stmt = $conn->prepare("SELECT * FROM vouchers WHERE id = ?");
$stmt->execute([$voucherId]);
$voucher = $stmt->fetch();

if (!$voucher) {
    $_SESSION['error_message'] = "Gutschein nicht gefunden.";
    header('Location: vouchers.php');
    exit;
}

// Verwendungen laden
$stmt = $conn->prepare("SELECT * FROM voucher_uses WHERE voucher_id = ? ORDER BY used_at DESC");
$stmt->execute([$voucherId]);
$uses = $stmt->fetchAll();

// Statistiken berechnen
$totalUses = count($uses);
$totalDiscount = array_sum(array_column($uses, 'discount_amount'));
$totalOrderValue = array_sum(array_column($uses, 'order_total'));

// Seitentitel setzen und Header einfügen
$pageTitle = "Gutschein-Verwendungen";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Gutschein-Verwendungen: <?php echo htmlspecialchars($voucher['code']); ?></h3>
    <div>
        <a href="vouchers.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Zurück zu Gutscheinen
        </a>
    </div>
</div>

<!-- Gutschein-Informationen -->
<div class="form-card">
    <h4>Gutschein-Details</h4>
    <div class="row">
        <div class="col-md-3">
            <strong>Code:</strong><br>
            <?php echo htmlspecialchars($voucher['code']); ?>
        </div>
        <div class="col-md-3">
            <strong>Beschreibung:</strong><br>
            <?php echo htmlspecialchars($voucher['description']); ?>
        </div>
        <div class="col-md-3">
            <strong>Rabatt:</strong><br>
            <?php if ($voucher['discount_type'] === 'percentage'): ?>
                <?php echo $voucher['discount_value']; ?>%
            <?php else: ?>
                <?php echo number_format($voucher['discount_value'], 2); ?> €
            <?php endif; ?>
        </div>
        <div class="col-md-3">
            <strong>Gültigkeitszeitraum:</strong><br>
            <?php echo date('d.m.Y', strtotime($voucher['valid_from'])); ?> - 
            <?php echo date('d.m.Y', strtotime($voucher['valid_until'])); ?>
        </div>
    </div>
</div>

<!-- Statistiken -->
<div class="form-card">
    <h4>Verwendungsstatistiken</h4>
    <div class="row">
        <div class="col-md-3">
            <div class="stat-card">
                <div class="stat-number"><?php echo $totalUses; ?></div>
                <div class="stat-label">Gesamte Verwendungen</div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="stat-card">
                <div class="stat-number"><?php echo $voucher['max_uses'] ? ($voucher['max_uses'] - $voucher['current_uses']) : '∞'; ?></div>
                <div class="stat-label">Verbleibende Verwendungen</div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="stat-card">
                <div class="stat-number"><?php echo number_format($totalDiscount, 2); ?> €</div>
                <div class="stat-label">Gesamter Rabatt gewährt</div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="stat-card">
                <div class="stat-number"><?php echo number_format($totalOrderValue, 2); ?> €</div>
                <div class="stat-label">Gesamter Bestellwert</div>
            </div>
        </div>
    </div>
</div>

<!-- Verwendungshistorie -->
<div class="table-responsive">
    <h4>Verwendungshistorie</h4>
    
    <?php if (count($uses) > 0): ?>
        <table>
            <thead>
                <tr>
                    <th>Datum</th>
                    <th>Kunde</th>
                    <th>E-Mail</th>
                    <th>Bestellwert</th>
                    <th>Rabatt</th>
                    <th>Endpreis</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($uses as $use): ?>
                    <tr>
                        <td><?php echo date('d.m.Y H:i', strtotime($use['used_at'])); ?></td>
                        <td><?php echo htmlspecialchars($use['customer_name']); ?></td>
                        <td><?php echo htmlspecialchars($use['customer_email']); ?></td>
                        <td><?php echo number_format($use['order_total'], 2); ?> €</td>
                        <td style="color: #28a745;">-<?php echo number_format($use['discount_amount'], 2); ?> €</td>
                        <td><strong><?php echo number_format($use['order_total'] - $use['discount_amount'], 2); ?> €</strong></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        
        <!-- Export-Optionen -->
        <div style="margin-top: 20px;">
            <button onclick="exportToCSV()" class="btn btn-success">
                <i class="fas fa-download"></i> Als CSV exportieren
            </button>
        </div>
    <?php else: ?>
        <div class="alert alert-info">
            <i class="fas fa-info-circle"></i> Dieser Gutschein wurde noch nicht verwendet.
        </div>
    <?php endif; ?>
</div>

<style>
    .stat-card {
        background: linear-gradient(135deg, var(--primary-color), var(--accent-color));
        color: white;
        padding: 20px;
        border-radius: 8px;
        text-align: center;
        margin-bottom: 20px;
    }
    
    .stat-number {
        font-size: 2rem;
        font-weight: bold;
        margin-bottom: 5px;
    }
    
    .stat-label {
        font-size: 0.9rem;
        opacity: 0.9;
    }
    
    .alert-info {
        background-color: #d1ecf1;
        border: 1px solid #bee5eb;
        color: #0c5460;
        padding: 15px;
        border-radius: 4px;
        margin: 20px 0;
    }
</style>

<script>
    function exportToCSV() {
        const data = [
            ['Datum', 'Kunde', 'E-Mail', 'Bestellwert', 'Rabatt', 'Endpreis']
        ];
        
        <?php foreach ($uses as $use): ?>
        data.push([
            '<?php echo date('d.m.Y H:i', strtotime($use['used_at'])); ?>',
            '<?php echo addslashes($use['customer_name']); ?>',
            '<?php echo addslashes($use['customer_email']); ?>',
            '<?php echo number_format($use['order_total'], 2); ?> €',
            '-<?php echo number_format($use['discount_amount'], 2); ?> €',
            '<?php echo number_format($use['order_total'] - $use['discount_amount'], 2); ?> €'
        ]);
        <?php endforeach; ?>
        
        const csvContent = data.map(row => row.map(field => `"${field}"`).join(';')).join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'gutschein_<?php echo $voucher['code']; ?>_verwendungen.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
</script>

<?php include('includes/footer.php'); ?> 