<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Aktion Löschen
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    
    try {
        $stmt = $conn->prepare("DELETE FROM vouchers WHERE id = ?");
        $stmt->execute([$id]);
        
        if ($stmt->rowCount() > 0) {
            $_SESSION['success_message'] = "Gutschein wurde erfolgreich gelöscht.";
        } else {
            $_SESSION['error_message'] = "Gutschein konnte nicht gefunden werden.";
        }
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
    }
    
    header('Location: vouchers.php');
    exit;
}

// Aktion Bearbeiten oder Hinzufügen
$editMode = false;
$voucherData = [
    'id' => null,
    'code' => '',
    'description' => '',
    'discount_type' => 'percentage',
    'discount_value' => 0,
    'min_order_value' => 0,
    'max_uses' => null,
    'valid_from' => date('Y-m-d'),
    'valid_until' => date('Y-m-d', strtotime('+1 year')),
    'active' => 1
];

// Bei Bearbeiten Gutschein-Daten laden
if (isset($_GET['action']) && $_GET['action'] === 'edit' && isset($_GET['id'])) {
    $id = (int)$_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM vouchers WHERE id = ?");
    $stmt->execute([$id]);
    $voucher = $stmt->fetch();
    
    if ($voucher) {
        $editMode = true;
        $voucherData = $voucher;
    }
}

// Formular verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $code = strtoupper(trim($_POST['code']));
    $description = trim($_POST['description']);
    $discountType = $_POST['discount_type'];
    $discountValue = floatval($_POST['discount_value']);
    $minOrderValue = floatval($_POST['min_order_value']);
    $maxUses = !empty($_POST['max_uses']) ? intval($_POST['max_uses']) : null;
    $validFrom = $_POST['valid_from'];
    $validUntil = $_POST['valid_until'];
    $active = isset($_POST['active']) ? 1 : 0;
    $editId = isset($_POST['id']) ? (int)$_POST['id'] : null;
    
    // Validierung
    $errors = [];
    
    if (empty($code)) {
        $errors[] = "Gutscheincode ist erforderlich.";
    } elseif (!preg_match('/^[A-Z0-9]+$/', $code)) {
        $errors[] = "Gutscheincode darf nur Großbuchstaben und Zahlen enthalten.";
    }
    
    if ($discountValue <= 0) {
        $errors[] = "Rabattwert muss größer als 0 sein.";
    }
    
    if ($discountType === 'percentage' && $discountValue > 100) {
        $errors[] = "Prozentualer Rabatt darf nicht über 100% liegen.";
    }
    
    if (strtotime($validUntil) <= strtotime($validFrom)) {
        $errors[] = "Das Enddatum muss nach dem Startdatum liegen.";
    }
    
    // Prüfen, ob Code bereits existiert (außer bei Bearbeitung des gleichen Gutscheins)
    $stmt = $conn->prepare("SELECT id FROM vouchers WHERE code = ? AND id != ?");
    $stmt->execute([$code, $editId ?: 0]);
    if ($stmt->fetch()) {
        $errors[] = "Dieser Gutscheincode existiert bereits.";
    }
    
    if (empty($errors)) {
        try {
            if ($editId) {
                // Update bestehender Eintrag
                $stmt = $conn->prepare("UPDATE vouchers SET code = ?, description = ?, discount_type = ?, discount_value = ?, min_order_value = ?, max_uses = ?, valid_from = ?, valid_until = ?, active = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
                $stmt->execute([$code, $description, $discountType, $discountValue, $minOrderValue, $maxUses, $validFrom, $validUntil, $active, $editId]);
                $_SESSION['success_message'] = "Gutschein wurde erfolgreich aktualisiert.";
            } else {
                // Neuen Eintrag erstellen
                $stmt = $conn->prepare("INSERT INTO vouchers (code, description, discount_type, discount_value, min_order_value, max_uses, valid_from, valid_until, active) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$code, $description, $discountType, $discountValue, $minOrderValue, $maxUses, $validFrom, $validUntil, $active]);
                $_SESSION['success_message'] = "Neuer Gutschein wurde erfolgreich erstellt.";
            }
            
            header('Location: vouchers.php');
            exit;
        } catch (PDOException $e) {
            $_SESSION['error_message'] = "Datenbankfehler: " . $e->getMessage();
        }
    } else {
        $_SESSION['error_message'] = implode('<br>', $errors);
    }
}

// Alle Gutscheine abrufen
$stmt = $conn->prepare("SELECT v.*, COUNT(vu.id) as usage_count FROM vouchers v LEFT JOIN voucher_uses vu ON v.id = vu.voucher_id GROUP BY v.id ORDER BY v.created_at DESC");
$stmt->execute();
$vouchers = $stmt->fetchAll();

// Seitentitel setzen und Header einfügen
$pageTitle = "Gutscheine";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Gutscheine verwalten</h3>
    <div>
        <button type="button" class="btn btn-primary" onclick="document.getElementById('voucherForm').reset(); document.getElementById('voucherFormTitle').textContent = 'Neuen Gutschein erstellen'; document.getElementById('formContainer').style.display = 'block';">
            <i class="fas fa-plus"></i> Neuen Gutschein erstellen
        </button>
    </div>
</div>

<?php if (isset($_SESSION['success_message'])): ?>
    <div class="alert alert-success">
        <?php 
        echo $_SESSION['success_message']; 
        unset($_SESSION['success_message']); 
        ?>
    </div>
<?php endif; ?>

<?php if (isset($_SESSION['error_message'])): ?>
    <div class="alert alert-danger">
        <?php 
        echo $_SESSION['error_message']; 
        unset($_SESSION['error_message']); 
        ?>
    </div>
<?php endif; ?>

<div class="form-card" id="formContainer" style="<?php echo $editMode ? 'display: block;' : 'display: none;'; ?>">
    <h3 id="voucherFormTitle"><?php echo $editMode ? 'Gutschein bearbeiten' : 'Neuen Gutschein erstellen'; ?></h3>
    
    <form action="vouchers.php" method="post" id="voucherForm">
        <?php if ($editMode): ?>
            <input type="hidden" name="id" value="<?php echo $voucherData['id']; ?>">
        <?php endif; ?>
        
        <div class="row">
            <div class="col-md-6">
                <div class="form-group">
                    <label for="code">Gutscheincode *</label>
                    <input type="text" id="code" name="code" class="form-control" value="<?php echo htmlspecialchars($voucherData['code']); ?>" required style="text-transform: uppercase;">
                    <small class="form-text text-muted">Nur Großbuchstaben und Zahlen erlaubt</small>
                </div>
            </div>
            
            <div class="col-md-6">
                <div class="form-group">
                    <label for="description">Beschreibung</label>
                    <input type="text" id="description" name="description" class="form-control" value="<?php echo htmlspecialchars($voucherData['description']); ?>">
                </div>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-4">
                <div class="form-group">
                    <label for="discount_type">Rabatt-Art *</label>
                    <select id="discount_type" name="discount_type" class="form-control" required>
                        <option value="percentage" <?php echo $voucherData['discount_type'] === 'percentage' ? 'selected' : ''; ?>>Prozentual (%)</option>
                        <option value="fixed" <?php echo $voucherData['discount_type'] === 'fixed' ? 'selected' : ''; ?>>Fester Betrag (€)</option>
                    </select>
                </div>
            </div>
            
            <div class="col-md-4">
                <div class="form-group">
                    <label for="discount_value">Rabatt-Wert *</label>
                    <input type="number" id="discount_value" name="discount_value" class="form-control" step="0.01" min="0.01" value="<?php echo $voucherData['discount_value']; ?>" required>
                    <small class="form-text text-muted" id="discount_hint">Wert in % oder €</small>
                </div>
            </div>
            
            <div class="col-md-4">
                <div class="form-group">
                    <label for="min_order_value">Mindestbestellwert (€)</label>
                    <input type="number" id="min_order_value" name="min_order_value" class="form-control" step="0.01" min="0" value="<?php echo $voucherData['min_order_value']; ?>">
                </div>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-4">
                <div class="form-group">
                    <label for="max_uses">Maximale Verwendungen</label>
                    <input type="number" id="max_uses" name="max_uses" class="form-control" min="1" value="<?php echo $voucherData['max_uses']; ?>">
                    <small class="form-text text-muted">Leer lassen für unbegrenzte Verwendung</small>
                </div>
            </div>
            
            <div class="col-md-4">
                <div class="form-group">
                    <label for="valid_from">Gültig ab *</label>
                    <input type="date" id="valid_from" name="valid_from" class="form-control" value="<?php echo $voucherData['valid_from']; ?>" required>
                </div>
            </div>
            
            <div class="col-md-4">
                <div class="form-group">
                    <label for="valid_until">Gültig bis *</label>
                    <input type="date" id="valid_until" name="valid_until" class="form-control" value="<?php echo $voucherData['valid_until']; ?>" required>
                </div>
            </div>
        </div>
        
        <div class="form-group">
            <div class="custom-control custom-checkbox">
                <input type="checkbox" id="active" name="active" class="custom-control-input" <?php echo $voucherData['active'] ? 'checked' : ''; ?>>
                <label class="custom-control-label" for="active">Aktiv</label>
            </div>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Speichern</button>
            <button type="button" class="btn btn-secondary" onclick="document.getElementById('formContainer').style.display = 'none';">Abbrechen</button>
        </div>
    </form>
</div>

<div class="table-responsive">
    <table>
        <thead>
            <tr>
                <th>Code</th>
                <th>Beschreibung</th>
                <th>Rabatt</th>
                <th>Min. Bestellwert</th>
                <th>Verwendungen</th>
                <th>Gültigkeitszeitraum</th>
                <th>Status</th>
                <th>Aktionen</th>
            </tr>
        </thead>
        <tbody>
            <?php if (count($vouchers) > 0): ?>
                <?php foreach ($vouchers as $voucher): ?>
                    <?php
                    $isExpired = strtotime($voucher['valid_until']) < time();
                    $isMaxUsed = $voucher['max_uses'] && $voucher['current_uses'] >= $voucher['max_uses'];
                    $isActive = $voucher['active'] && !$isExpired && !$isMaxUsed;
                    ?>
                    <tr>
                        <td><strong><?php echo htmlspecialchars($voucher['code']); ?></strong></td>
                        <td><?php echo htmlspecialchars($voucher['description']); ?></td>
                        <td>
                            <?php if ($voucher['discount_type'] === 'percentage'): ?>
                                <?php echo $voucher['discount_value']; ?>%
                            <?php else: ?>
                                <?php echo number_format($voucher['discount_value'], 2); ?> €
                            <?php endif; ?>
                        </td>
                        <td><?php echo number_format($voucher['min_order_value'], 2); ?> €</td>
                        <td>
                            <?php echo $voucher['current_uses']; ?>/<?php echo $voucher['max_uses'] ?: '∞'; ?>
                            <?php if ($voucher['usage_count'] > 0): ?>
                                <br><small><a href="voucher_usage.php?id=<?php echo $voucher['id']; ?>">Details anzeigen</a></small>
                            <?php endif; ?>
                        </td>
                        <td>
                            <?php echo date('d.m.Y', strtotime($voucher['valid_from'])); ?> - 
                            <?php echo date('d.m.Y', strtotime($voucher['valid_until'])); ?>
                            <?php if ($isExpired): ?>
                                <br><small style="color: red;">Abgelaufen</small>
                            <?php endif; ?>
                        </td>
                        <td>
                            <?php if ($isActive): ?>
                                <span class="badge badge-success">Aktiv</span>
                            <?php elseif (!$voucher['active']): ?>
                                <span class="badge badge-secondary">Deaktiviert</span>
                            <?php elseif ($isExpired): ?>
                                <span class="badge badge-danger">Abgelaufen</span>
                            <?php elseif ($isMaxUsed): ?>
                                <span class="badge badge-warning">Aufgebraucht</span>
                            <?php endif; ?>
                        </td>
                        <td>
                            <div class="table-actions">
                                <a href="vouchers.php?action=edit&id=<?php echo $voucher['id']; ?>" class="btn btn-sm btn-primary">
                                    <i class="fas fa-edit"></i> Bearbeiten
                                </a>
                                <a href="vouchers.php?action=delete&id=<?php echo $voucher['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Sind Sie sicher, dass Sie diesen Gutschein löschen möchten?')">
                                    <i class="fas fa-trash-alt"></i> Löschen
                                </a>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="8" class="text-center">Keine Gutscheine gefunden.</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<script>
    // Automatische Großschreibung für Gutscheincode
    document.getElementById('code').addEventListener('input', function() {
        this.value = this.value.toUpperCase().replace(/[^A-Z0-9]/g, '');
    });
    
    // Rabatt-Typ Änderung
    document.getElementById('discount_type').addEventListener('change', function() {
        const hint = document.getElementById('discount_hint');
        const valueInput = document.getElementById('discount_value');
        
        if (this.value === 'percentage') {
            hint.textContent = 'Wert in % (z.B. 10 für 10%)';
            valueInput.max = '100';
        } else {
            hint.textContent = 'Wert in € (z.B. 5.00 für 5€)';
            valueInput.removeAttribute('max');
        }
    });
    
    // Trigger initial hint update
    document.getElementById('discount_type').dispatchEvent(new Event('change'));
</script>

<?php include('includes/footer.php'); ?> 