<?php
// Adressfeld-Prüfung und Korrektur
ini_set('display_errors', 1);

echo "<html><head><title>JB Kerzen - Adressfeld-Korrektur</title>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; line-height: 1.6; }
    h1 { color: #8b6b4f; }
    pre { background: #f5f5f5; padding: 15px; border-radius: 5px; overflow: auto; }
    .success { color: green; }
    .error { color: red; }
    .info { color: blue; }
    .warning { color: orange; }
</style>";
echo "</head><body>";
echo "<h1>Adressfeld-Diagnose und Korrektur</h1>";
echo "<pre>";

// Datenbankkonfiguration einbinden
require_once('includes/db_connect.php');

// Aktuelle Einstellung der Adressfelder prüfen
$adressFields = [];
try {
    $stmt = $conn->prepare("SELECT id, form_id, field_label, field_type FROM form_fields WHERE field_label LIKE '%Adresse%'");
    $stmt->execute();
    $adressFields = $stmt->fetchAll();
    
    if (count($adressFields) > 0) {
        echo "<span class='info'>Gefundene Adressfelder: " . count($adressFields) . "</span>\n\n";
        
        foreach ($adressFields as $field) {
            echo "ID: {$field['id']}, Form-ID: {$field['form_id']}, Label: {$field['field_label']}, Typ: {$field['field_type']}\n";
            
            // Korrigiere den Feldtyp wenn nötig
            if ($field['field_type'] !== 'address') {
                try {
                    $updateStmt = $conn->prepare("UPDATE form_fields SET field_type = 'address' WHERE id = ?");
                    $updateStmt->execute([$field['id']]);
                    echo "<span class='success'>✓ Feldtyp für ID {$field['id']} zu 'address' geändert.</span>\n";
                } catch (PDOException $e) {
                    echo "<span class='error'>Fehler beim Aktualisieren des Feldtyps: " . $e->getMessage() . "</span>\n";
                }
            } else {
                echo "<span class='success'>✓ Feldtyp bereits korrekt gesetzt.</span>\n";
            }
        }
    } else {
        echo "<span class='warning'>Keine Adressfelder in der Datenbank gefunden!</span>\n";
    }
} catch (PDOException $e) {
    echo "<span class='error'>Datenbankfehler: " . $e->getMessage() . "</span>\n";
}

// Cache-Dateien leeren, falls vorhanden
$cacheDir = __DIR__ . '/cache';
if (is_dir($cacheDir)) {
    echo "\n<span class='info'>Versuche Cache-Dateien zu löschen...</span>\n";
    $files = glob($cacheDir . '/*');
    $count = 0;
    foreach ($files as $file) {
        if (is_file($file)) {
            unlink($file);
            $count++;
        }
    }
    echo "<span class='success'>$count Cache-Dateien gelöscht.</span>\n";
}

// Frontend-Code für Adressfelder überprüfen
echo "\n<span class='info'>Überprüfe Frontend-Code für Adressfelder...</span>\n";

// Überprüfe order_form.php
$orderFormPath = __DIR__ . '/order_form.php';
if (file_exists($orderFormPath)) {
    $orderFormContent = file_get_contents($orderFormPath);
    
    // Prüfe, ob der Code Adressfelder korrekt erkennt
    if (strpos($orderFormContent, 'field_type === \'address\'') !== false || 
        strpos($orderFormContent, "field_type == 'address'") !== false) {
        echo "<span class='success'>✓ order_form.php enthält Code zur Erkennung von Adressfeldern.</span>\n";
    } else {
        echo "<span class='warning'>order_form.php scheint keine spezielle Behandlung für Adressfelder zu haben.</span>\n";
    }
    
    // Prüfe, ob Adressfeld auch über das Label erkannt wird
    if (strpos($orderFormContent, 'strtolower($field_label) === \'adresse\'') !== false ||
        strpos($orderFormContent, "strtolower(\$field['field_label']) === 'adresse'") !== false) {
        echo "<span class='success'>✓ order_form.php erkennt Adressfelder auch über das Label.</span>\n";
    }
} else {
    echo "<span class='error'>order_form.php nicht gefunden!</span>\n";
}

echo "</pre>";
echo "<p>Nächster Schritt: <a href='order.php' style='display: inline-block; padding: 10px 15px; background: #8b6b4f; color: white; text-decoration: none; border-radius: 4px;'>Zur Bestellseite</a> und prüfen Sie, ob das Adressfeld jetzt korrekt angezeigt wird.</p>";
echo "<p><small>Hinweis: Sie sollten möglicherweise Ihren Browser-Cache leeren (STRG+F5 oder CMD+SHIFT+R).</small></p>";
echo "<p><a href='index.php' style='color: #8b6b4f;'>Zurück zur Startseite</a></p>";

// Nachdem Diagnose angezeigt wurde, diese Datei nach Ausführung selbst löschen
echo "<script>
    setTimeout(function() {
        if (confirm('Möchten Sie diese Diagnosedatei jetzt löschen?')) {
            window.location.href = 'delete_diagnosis.php?file=adress_field_fix.php';
        }
    }, 30000); // 30 Sekunden warten
</script>";

echo "</body></html>";
?> 