<?php
// Dedicated AJAX endpoint for voucher validation
error_reporting(E_ALL);
ini_set('display_errors', 0); // Disable display_errors for clean JSON output

require_once('includes/db_connect.php');
require_once('includes/voucher_functions.php');

// Start session
session_start();

// Set JSON header immediately
header('Content-Type: application/json');

// Only process POST requests
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode([
        'success' => false,
        'message' => 'Nur POST-Requests erlaubt.',
        'voucher_data' => null
    ]);
    exit;
}

// Handle voucher validation
if (isset($_POST['action']) && $_POST['action'] === 'validate_voucher') {
    $code = $_POST['voucher_code'] ?? '';
    $orderTotal = floatval($_POST['order_total'] ?? 0);
    
    // Log for debugging
    error_log("AJAX Voucher Validation: Code='$code', OrderTotal=$orderTotal");
    
    try {
        $result = validateVoucher($conn, $code, $orderTotal);
        
        if ($result['success']) {
            // Save voucher to session
            $_SESSION['applied_voucher'] = [
                'code' => $result['voucher_data']['code'],
                'id' => $result['voucher_data']['id'],
                'discount_amount' => floatval($result['discount_amount']),
                'description' => $result['voucher_data']['description']
            ];
            
            // Ensure discount_amount is returned as float
            $result['discount_amount'] = floatval($result['discount_amount']);
            
            error_log("Voucher successfully applied: " . $result['voucher_data']['code']);
        } else {
            error_log("Voucher validation failed: " . $result['message']);
        }
        
        echo json_encode($result);
        
    } catch (Exception $e) {
        error_log("Voucher validation exception: " . $e->getMessage());
        
        echo json_encode([
            'success' => false,
            'message' => 'Technischer Fehler bei der Gutschein-Validierung.',
            'voucher_data' => null
        ]);
    }
    
    exit;
}

// Handle voucher removal
if (isset($_POST['action']) && $_POST['action'] === 'remove_voucher') {
    unset($_SESSION['applied_voucher']);
    echo json_encode(['success' => true]);
    exit;
}

// Invalid action
echo json_encode([
    'success' => false,
    'message' => 'Ungültige Aktion.',
    'voucher_data' => null
]);
?> 