document.addEventListener('DOMContentLoaded', function() {
    // Smooth scrolling for navigation links
    const navLinks = document.querySelectorAll('nav a[href^="#"]');
    navLinks.forEach(link => {
        link.addEventListener('click', function(e) {
            e.preventDefault();
            
            const targetId = this.getAttribute('href');
            const targetElement = document.querySelector(targetId);
            
            if (targetElement) {
                const headerHeight = document.querySelector('header').offsetHeight;
                const targetPosition = targetElement.getBoundingClientRect().top + window.pageYOffset - headerHeight;
                
                window.scrollTo({
                    top: targetPosition,
                    behavior: 'smooth'
                });
            }
        });
    });
    
    // Header scroll effect
    window.addEventListener('scroll', function() {
        const header = document.querySelector('header');
        if (window.scrollY > 50) {
            header.style.backgroundColor = 'rgba(255, 255, 255, 0.98)';
            header.style.boxShadow = '0 2px 10px rgba(0, 0, 0, 0.1)';
        } else {
            header.style.backgroundColor = 'rgba(255, 255, 255, 0.95)';
            header.style.boxShadow = '0 2px 10px rgba(0, 0, 0, 0.05)';
        }
    });
    
    // Testimonial slider autoplay
    const testimonialSlider = document.querySelector('.testimonials-slider');
    if (testimonialSlider && testimonialSlider.children.length > 1) {
        let currentPosition = 0;
        const slideWidth = 380; // card width + gap
        const maxPosition = (testimonialSlider.children.length - 1) * slideWidth;
        
        setInterval(() => {
            currentPosition += slideWidth;
            if (currentPosition > maxPosition) {
                currentPosition = 0;
                // Quick return to start without animation
                testimonialSlider.scrollTo({
                    left: 0,
                    behavior: 'auto'
                });
            } else {
                testimonialSlider.scrollTo({
                    left: currentPosition,
                    behavior: 'smooth'
                });
            }
        }, 5000);
    }
    
    // Animation for product cards on scroll
    const productCards = document.querySelectorAll('.product-card');
    const shopCards = document.querySelectorAll('.shop-card');
    
    // Simple animation when elements come into view
    function animateOnScroll(elements) {
        elements.forEach(element => {
            const elementPosition = element.getBoundingClientRect().top;
            const screenPosition = window.innerHeight / 1.3;
            
            if (elementPosition < screenPosition) {
                element.style.opacity = '1';
                element.style.transform = 'translateY(0)';
            }
        });
    }
    
    // Set initial state
    productCards.forEach(card => {
        card.style.opacity = '0';
        card.style.transform = 'translateY(20px)';
        card.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
    });
    
    shopCards.forEach(card => {
        card.style.opacity = '0';
        card.style.transform = 'translateY(20px)';
        card.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
    });
    
    // Trigger animation on scroll
    window.addEventListener('scroll', () => {
        animateOnScroll(productCards);
        animateOnScroll(shopCards);
    });
    
    // Trigger once on page load
    animateOnScroll(productCards);
    animateOnScroll(shopCards);
}); 