<?php
// Skript zum Erstellen des Gutschein-Systems
require_once('includes/db_connect.php');

echo "<h1>Gutschein-System einrichten</h1>";

try {
    // 1. Gutscheine-Tabelle erstellen
    $sql = "CREATE TABLE IF NOT EXISTS vouchers (
        id INT AUTO_INCREMENT PRIMARY KEY,
        code VARCHAR(50) UNIQUE NOT NULL,
        description VARCHAR(255),
        discount_type ENUM('percentage', 'fixed') NOT NULL DEFAULT 'percentage',
        discount_value DECIMAL(10,2) NOT NULL,
        min_order_value DECIMAL(10,2) DEFAULT 0.00,
        max_uses INT DEFAULT NULL,
        current_uses INT DEFAULT 0,
        valid_from DATE,
        valid_until DATE,
        active TINYINT(1) DEFAULT 1,
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    )";
    
    $conn->exec($sql);
    echo "<p style='color: green;'>✅ Gutscheine-Tabelle wurde erstellt.</p>";
    
    // 2. Gutschein-Verwendungen-Tabelle erstellen (für Tracking)
    $sql = "CREATE TABLE IF NOT EXISTS voucher_uses (
        id INT AUTO_INCREMENT PRIMARY KEY,
        voucher_id INT NOT NULL,
        order_id INT DEFAULT NULL,
        customer_email VARCHAR(255),
        customer_name VARCHAR(255),
        discount_amount DECIMAL(10,2) NOT NULL,
        order_total DECIMAL(10,2) NOT NULL,
        used_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (voucher_id) REFERENCES vouchers(id) ON DELETE CASCADE
    )";
    
    $conn->exec($sql);
    echo "<p style='color: green;'>✅ Gutschein-Verwendungen-Tabelle wurde erstellt.</p>";
    
    // 3. Beispiel-Gutscheine erstellen
    $sampleVouchers = [
        [
            'code' => 'WELCOME10',
            'description' => 'Willkommensrabatt 10%',
            'discount_type' => 'percentage',
            'discount_value' => 10.00,
            'min_order_value' => 20.00,
            'max_uses' => 100,
            'valid_from' => date('Y-m-d'),
            'valid_until' => date('Y-m-d', strtotime('+1 year'))
        ],
        [
            'code' => 'SAVE5',
            'description' => '5€ Rabatt ab 30€ Bestellwert',
            'discount_type' => 'fixed',
            'discount_value' => 5.00,
            'min_order_value' => 30.00,
            'max_uses' => 50,
            'valid_from' => date('Y-m-d'),
            'valid_until' => date('Y-m-d', strtotime('+6 months'))
        ]
    ];
    
    $stmt = $conn->prepare("INSERT INTO vouchers (code, description, discount_type, discount_value, min_order_value, max_uses, valid_from, valid_until) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
    
    foreach ($sampleVouchers as $voucher) {
        try {
            $stmt->execute([
                $voucher['code'],
                $voucher['description'],
                $voucher['discount_type'],
                $voucher['discount_value'],
                $voucher['min_order_value'],
                $voucher['max_uses'],
                $voucher['valid_from'],
                $voucher['valid_until']
            ]);
        } catch (PDOException $e) {
            // Ignoriere Duplikate
            if ($e->getCode() != 23000) {
                throw $e;
            }
        }
    }
    
    echo "<p style='color: green;'>✅ Beispiel-Gutscheine wurden erstellt.</p>";
    
    // 4. Zeige aktuelle Gutscheine
    echo "<h2>Aktuelle Gutscheine:</h2>";
    $stmt = $conn->query("SELECT * FROM vouchers ORDER BY created_at DESC");
    $vouchers = $stmt->fetchAll();
    
    if ($vouchers) {
        echo "<table border='1' cellpadding='10' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background-color: #f0f0f0;'>";
        echo "<th>Code</th><th>Beschreibung</th><th>Rabatt</th><th>Min. Bestellwert</th><th>Verwendet</th><th>Gültig bis</th><th>Status</th>";
        echo "</tr>";
        
        foreach ($vouchers as $voucher) {
            echo "<tr>";
            echo "<td><strong>" . htmlspecialchars($voucher['code']) . "</strong></td>";
            echo "<td>" . htmlspecialchars($voucher['description']) . "</td>";
            
            if ($voucher['discount_type'] == 'percentage') {
                echo "<td>" . $voucher['discount_value'] . "%</td>";
            } else {
                echo "<td>" . number_format($voucher['discount_value'], 2) . " €</td>";
            }
            
            echo "<td>" . number_format($voucher['min_order_value'], 2) . " €</td>";
            echo "<td>" . $voucher['current_uses'] . "/" . ($voucher['max_uses'] ?: '∞') . "</td>";
            echo "<td>" . date('d.m.Y', strtotime($voucher['valid_until'])) . "</td>";
            echo "<td>" . ($voucher['active'] ? '<span style="color: green;">Aktiv</span>' : '<span style="color: red;">Inaktiv</span>') . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    }
    
    echo "<h2>Nächste Schritte:</h2>";
    echo "<ol>";
    echo "<li><a href='admin/vouchers.php'>Gutscheine verwalten</a> - Neue Gutscheine erstellen und bearbeiten</li>";
    echo "<li>Das Gutschein-System ist jetzt im Warenkorb verfügbar</li>";
    echo "<li>Kunden können Gutscheincodes beim Checkout eingeben</li>";
    echo "</ol>";
    
} catch (PDOException $e) {
    echo "<p style='color: red;'>❌ Fehler: " . $e->getMessage() . "</p>";
}
?> 