<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Datenschutzerklärung - JB - Kerzenzauber</title>
    <?php
    // Verbindung zur Datenbank herstellen
    require_once('includes/db_connect.php');
    
    // Standard-Farbwerte
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
    
    // Prüfen, ob benutzerdefinierte Farben in der Datenbank vorhanden sind
    try {
        $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
        $savedColors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
        
        foreach ($colors as $name => $defaultValue) {
            if (isset($savedColors[$name]) && !empty($savedColors[$name])) {
                $colors[$name] = $savedColors[$name];
            }
        }
    } catch (PDOException $e) {
        // Falls die Tabelle noch nicht existiert, verwenden wir die Standardfarben
        error_log("Fehler beim Laden der Farbkonfiguration: " . $e->getMessage());
    }
    ?>
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
            --light-color: #f5f5f5;
            --dark-color: #212121;
            --font-main: 'Montserrat', sans-serif;
            --font-secondary: 'Playfair Display', serif;
        }
    </style>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
</head>
<body>
    <div class="container">
        <header>
            <div class="logo">
                <h1><a href="index.php">JB - Kerzenzauber</a></h1>
            </div>
            <nav>
                <ul>
                    <li><a href="index.php#ueber-uns">Über uns</a></li>
                    <li><a href="index.php#produkte">Produkte</a></li>
                    <li><a href="index.php#shops">Shops</a></li>
                    <li><a href="index.php#kontakt">Kontakt</a></li>
                </ul>
            </nav>
        </header>

        <section class="legal-content">
            <div class="section-header">
                <h2>Datenschutzerklärung</h2>
            </div>
            <div class="content">
                <h3>1. Datenschutz auf einen Blick</h3>
                <h4>Allgemeine Hinweise</h4>
                <p>Die folgenden Hinweise geben einen einfachen Überblick darüber, was mit Ihren personenbezogenen Daten passiert, wenn Sie unsere Website besuchen. Personenbezogene Daten sind alle Daten, mit denen Sie persönlich identifiziert werden können.</p>
                
                <h4>Datenerfassung auf unserer Website</h4>
                <p>Die Datenverarbeitung auf dieser Website erfolgt durch den Websitebetreiber. Dessen Kontaktdaten können Sie dem Impressum dieser Website entnehmen.</p>
                
                <h3>2. Allgemeine Hinweise und Pflichtinformationen</h3>
                <h4>Datenschutz</h4>
                <p>Die Betreiber dieser Seiten nehmen den Schutz Ihrer persönlichen Daten sehr ernst. Wir behandeln Ihre personenbezogenen Daten vertraulich und entsprechend der gesetzlichen Datenschutzvorschriften sowie dieser Datenschutzerklärung.</p>
                
                <h4>Hinweis zur verantwortlichen Stelle</h4>
                <p>Die verantwortliche Stelle für die Datenverarbeitung auf dieser Website ist:</p>
                <p>
                    JB - Kerzenzauber<br>
                    Musterstraße 1<br>
                    12345 Musterstadt<br>
                    Deutschland
                </p>
                <p>
                    Telefon: +49 123 456789<br>
                    E-Mail: info@jb-kerzenzauber.de
                </p>
                
                <h3>3. Datenerfassung auf unserer Website</h3>
                <h4>Cookies</h4>
                <p>Unsere Internetseiten verwenden teilweise so genannte Cookies. Cookies richten auf Ihrem Rechner keinen Schaden an und enthalten keine Viren. Cookies dienen dazu, unser Angebot nutzerfreundlicher, effektiver und sicherer zu machen.</p>
                
                <!-- Weitere Datenschutz-Inhalte hier einfügen -->

                <p><em>Diese Datenschutzerklärung ist ein Beispiel und muss an die tatsächlichen Gegebenheiten der Website angepasst werden.</em></p>
            </div>
        </section>
        
        <footer>
            <div class="footer-content" style="display: flex; flex-direction: column; align-items: center; justify-content: center; text-align: center;">
                <div class="copyright" style="width: 100%; text-align: center; margin-bottom: 15px;">
                    &copy; <?php echo date("Y"); ?> JB - Kerzenzauber. Alle Rechte vorbehalten.
                </div>
                <div class="footer-links" style="width: 100%; text-align: center; display: flex; justify-content: center; gap: 20px;">
                    <a href="datenschutz.php">Datenschutz</a>
                    <a href="impressum.php">Impressum</a>
                </div>
            </div>
        </footer>
    </div>

    <script src="assets/js/main.js"></script>
</body>
</html> 