<?php
// Direct database fix for address fields
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Include database connection
require_once('includes/db_connect.php');

echo "<html><head><title>JB Kerzen - Direkte DB-Reparatur</title>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; line-height: 1.6; }
    h1, h2 { color: #8b6b4f; }
    .success { color: green; font-weight: bold; }
    .error { color: red; font-weight: bold; }
    .button { display: inline-block; padding: 10px 20px; background: #8b6b4f; color: white; 
              text-decoration: none; border-radius: 4px; margin-top: 20px; }
</style>";
echo "</head><body>";
echo "<h1>Direkte Datenbank-Reparatur</h1>";

try {
    // 1. Force update all address fields
    $sql = "UPDATE form_fields SET field_type = 'address' WHERE field_label LIKE '%adresse%' OR field_label LIKE '%Adresse%'";
    $conn->exec($sql);
    echo "<p class='success'>Step 1: Adressfelder in der Datenbank aktualisiert.</p>";
    
    // 2. Check if it worked
    $stmt = $conn->prepare("SELECT COUNT(*) FROM form_fields WHERE field_type = 'address'");
    $stmt->execute();
    $count = $stmt->fetchColumn();
    echo "<p>Anzahl der Felder mit Typ 'address': {$count}</p>";
    
    // 3. If no fields were updated, try harder - update any field that might be an address
    if ($count == 0) {
        $sql = "UPDATE form_fields SET field_type = 'address' 
                WHERE field_label LIKE '%straße%' 
                OR field_label LIKE '%plz%'
                OR field_label LIKE '%postleitzahl%'
                OR field_label LIKE '%ort%'
                OR field_label LIKE '%stadt%'
                OR field_label = 'Adresse'";
        $conn->exec($sql);
        echo "<p class='success'>Step 2: Erweiterte Adressfeld-Erkennung durchgeführt.</p>";
        
        $stmt = $conn->prepare("SELECT COUNT(*) FROM form_fields WHERE field_type = 'address'");
        $stmt->execute();
        $count = $stmt->fetchColumn();
        echo "<p>Anzahl der Felder mit Typ 'address' nach erweiterter Suche: {$count}</p>";
    }
    
    // 4. Force create an address field if none exists
    if ($count == 0) {
        $stmt = $conn->prepare("SELECT id FROM order_forms LIMIT 1");
        $stmt->execute();
        $formId = $stmt->fetchColumn();
        
        if ($formId) {
            $sql = "INSERT INTO form_fields (form_id, field_label, field_type, required, sort_order) 
                    VALUES (?, 'Adresse', 'address', 1, 10)";
            $stmt = $conn->prepare($sql);
            $stmt->execute([$formId]);
            echo "<p class='success'>Step 3: Neues Adressfeld zur Form {$formId} hinzugefügt.</p>";
        } else {
            echo "<p class='error'>Keine Formulare gefunden, um ein Adressfeld hinzuzufügen.</p>";
        }
    }
    
    echo "<h2>Reparatur abgeschlossen</h2>";
    echo "<p>Bitte führen Sie folgende Schritte aus:</p>";
    echo "<ol>";
    echo "<li>Leeren Sie den Browser-Cache vollständig (STRG+F5 oder CMD+SHIFT+R)</li>";
    echo "<li>Prüfen Sie, ob die Adressfelder jetzt korrekt angezeigt werden</li>";
    echo "</ol>";
    
} catch (PDOException $e) {
    echo "<p class='error'>Fehler: " . $e->getMessage() . "</p>";
}

echo "<p><a href='index.php' class='button'>Zurück zur Startseite</a></p>";
echo "</body></html>";
?> 