<?php
// Force address field script
// This script adds JavaScript to guarantee address field rendering

ini_set('display_errors', 1);
error_reporting(E_ALL);

// Include database connection
require_once('includes/db_connect.php');

echo "<html><head><title>JB Kerzen - Template Fix</title>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; line-height: 1.6; }
    h1, h2 { color: #8b6b4f; }
    .success { color: green; font-weight: bold; }
    .error { color: red; font-weight: bold; }
    pre { background: #f5f5f5; padding: 15px; border-radius: 5px; margin: 10px 0; }
    .button { display: inline-block; padding: 10px 20px; background: #8b6b4f; color: white; 
              text-decoration: none; border-radius: 4px; margin-top: 20px; }
</style>";
echo "</head><body>";
echo "<h1>Template- und JavaScript-Reparatur für Adressfelder</h1>";

try {
    // First force update the database
    $sql = "UPDATE form_fields SET field_type = 'address' WHERE field_label LIKE '%adresse%' OR field_label LIKE '%Adresse%'";
    $conn->exec($sql);
    echo "<p class='success'>Adressfelder in der Datenbank aktualisiert.</p>";
    
    // Now add a JavaScript fix to ensure proper rendering
    $jsFixCode = <<<'EOT'
// JavaScript-Fix für Adressfelder
document.addEventListener('DOMContentLoaded', function() {
    // Suche nach Adressfeldern im Formular
    document.querySelectorAll('label').forEach(function(label) {
        if (label.textContent.toLowerCase().includes('adresse')) {
            // Gefundenes Adressfeld
            const fieldGroup = label.closest('.form-group');
            if (!fieldGroup) return;
            
            // Prüfe, ob es bereits als Adressfeld gestaltet ist
            if (fieldGroup.querySelector('.address-container')) return;
            
            // ID des zugehörigen Feldes ermitteln
            const forAttr = label.getAttribute('for');
            if (!forAttr) return;
            
            // Altes Eingabefeld ausblenden
            const oldInput = document.getElementById(forAttr);
            if (oldInput) {
                oldInput.style.display = 'none';
                
                // Erstelle Container für die Adresskomponenten
                const addressContainer = document.createElement('div');
                addressContainer.className = 'address-container';
                addressContainer.style.border = '1px solid #ddd';
                addressContainer.style.borderRadius = '5px';
                addressContainer.style.padding = '15px';
                addressContainer.style.backgroundColor = '#f9f9f9';
                addressContainer.style.marginTop = '10px';
                
                // Erstelle die Felder für Straße, Hausnummer, PLZ und Stadt
                addressContainer.innerHTML = `
                    <div style="display: flex; gap: 15px; margin-bottom: 15px;">
                        <div style="flex: 2;">
                            <label style="display: block; font-weight: 500; margin-bottom: 5px; font-size: 14px;">Straße</label>
                            <input type="text" id="${forAttr}_street" name="${forAttr}_street" class="form-control" style="width: 100%; padding: 8px; border: 1px solid #ddd; border-radius: 4px;">
                        </div>
                        <div style="flex: 1;">
                            <label style="display: block; font-weight: 500; margin-bottom: 5px; font-size: 14px;">Hausnummer</label>
                            <input type="text" id="${forAttr}_number" name="${forAttr}_number" class="form-control" style="width: 100%; padding: 8px; border: 1px solid #ddd; border-radius: 4px;">
                        </div>
                    </div>
                    <div style="display: flex; gap: 15px;">
                        <div style="flex: 1;">
                            <label style="display: block; font-weight: 500; margin-bottom: 5px; font-size: 14px;">PLZ</label>
                            <input type="text" id="${forAttr}_zip" name="${forAttr}_zip" class="form-control" style="width: 100%; padding: 8px; border: 1px solid #ddd; border-radius: 4px;">
                        </div>
                        <div style="flex: 2;">
                            <label style="display: block; font-weight: 500; margin-bottom: 5px; font-size: 14px;">Stadt</label>
                            <input type="text" id="${forAttr}_city" name="${forAttr}_city" class="form-control" style="width: 100%; padding: 8px; border: 1px solid #ddd; border-radius: 4px;">
                        </div>
                    </div>
                `;
                
                // Füge den Container nach dem alten Eingabefeld ein
                oldInput.insertAdjacentElement('afterend', addressContainer);
                
                // Füge JavaScript hinzu, um die Werte zu kombinieren
                const form = oldInput.closest('form');
                if (form) {
                    form.addEventListener('submit', function() {
                        const street = document.getElementById(`${forAttr}_street`).value || '';
                        const number = document.getElementById(`${forAttr}_number`).value || '';
                        const zip = document.getElementById(`${forAttr}_zip`).value || '';
                        const city = document.getElementById(`${forAttr}_city`).value || '';
                        oldInput.value = street + ' ' + number + ', ' + zip + ' ' + city;
                    });
                }
            }
        }
    });
});
EOT;
    
    echo "<h2>JavaScript-Fix für Rendering</h2>";
    echo "<p>Dieser JavaScript-Code wurde erstellt, um Adressfelder auf dem Frontend korrekt darzustellen:</p>";
    echo "<pre>" . htmlspecialchars($jsFixCode) . "</pre>";
    
    echo "<h2>So verwenden Sie den Fix:</h2>";
    echo "<ol>";
    echo "<li>Kopieren Sie den kompletten JavaScript-Code oben</li>";
    echo "<li>Fügen Sie ihn in Ihre Webseite ein, z.B. direkt vor dem schließenden &lt;/body&gt; Tag</li>";
    echo "<li>Sie können den Code auch in einer separaten .js-Datei speichern und diese einbinden</li>";
    echo "</ol>";
    
    echo "<p>Der JavaScript-Code wird aktiviert, sobald die Seite geladen wird, und wandelt automatisch jedes Feld mit 'Adresse' im Label in ein Adressfeld mit separaten Eingabefeldern um.</p>";
    
    // Option to save the script to a file
    if (isset($_POST['save_script'])) {
        $scriptContent = "// Adressfeld-Fix\n\n" . $jsFixCode;
        $filename = "assets/js/address-fix.js";
        
        // Ensure the directory exists
        if (!file_exists(dirname($filename))) {
            mkdir(dirname($filename), 0777, true);
        }
        
        if (file_put_contents($filename, $scriptContent)) {
            echo "<p class='success'>JavaScript-Fix wurde als <strong>{$filename}</strong> gespeichert.</p>";
            
            // Try to automatically include it in the order_form.php
            $orderFormPath = "order_form.php";
            if (file_exists($orderFormPath)) {
                $orderFormContent = file_get_contents($orderFormPath);
                $insertPoint = strpos($orderFormContent, '</body>');
                
                if ($insertPoint !== false) {
                    $newContent = substr($orderFormContent, 0, $insertPoint);
                    $newContent .= "\n<script src=\"assets/js/address-fix.js\"></script>\n";
                    $newContent .= substr($orderFormContent, $insertPoint);
                    
                    if (file_put_contents($orderFormPath, $newContent)) {
                        echo "<p class='success'>JavaScript wurde automatisch in order_form.php eingebunden.</p>";
                    } else {
                        echo "<p class='error'>Konnte die order_form.php nicht aktualisieren. Bitte binden Sie das Script manuell ein.</p>";
                    }
                }
            }
        } else {
            echo "<p class='error'>Konnte Script nicht speichern. Überprüfen Sie die Berechtigungen.</p>";
        }
    }
    
    echo "<form method='post' action=''>";
    echo "<button type='submit' name='save_script' class='button'>JavaScript-Fix speichern und einbinden</button>";
    echo "</form>";
    
} catch (PDOException $e) {
    echo "<p class='error'>Fehler: " . $e->getMessage() . "</p>";
}

echo "<p><a href='index.php' class='button'>Zurück zur Startseite</a></p>";
echo "</body></html>";
?> 