<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Impressum - JB - Kerzenzauber</title>
    <?php
    // Verbindung zur Datenbank herstellen
    require_once('includes/db_connect.php');
    
    // Standard-Farbwerte
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
    
    // Prüfen, ob benutzerdefinierte Farben in der Datenbank vorhanden sind
    try {
        $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
        $savedColors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
        
        foreach ($colors as $name => $defaultValue) {
            if (isset($savedColors[$name]) && !empty($savedColors[$name])) {
                $colors[$name] = $savedColors[$name];
            }
        }
    } catch (PDOException $e) {
        // Falls die Tabelle noch nicht existiert, verwenden wir die Standardfarben
        error_log("Fehler beim Laden der Farbkonfiguration: " . $e->getMessage());
    }
    ?>
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
            --light-color: #f5f5f5;
            --dark-color: #212121;
            --font-main: 'Montserrat', sans-serif;
            --font-secondary: 'Playfair Display', serif;
        }
    </style>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
</head>
<body>
    <div class="container">
        <header>
            <div class="logo">
                <h1><a href="index.php">JB - Kerzenzauber</a></h1>
            </div>
            <nav>
                <ul>
                    <li><a href="index.php#ueber-uns">Über uns</a></li>
                    <li><a href="index.php#produkte">Produkte</a></li>
                    <li><a href="index.php#shops">Shops</a></li>
                    <li><a href="index.php#kontakt">Kontakt</a></li>
                </ul>
            </nav>
        </header>

        <section class="legal-content">
            <div class="section-header">
                <h2>Impressum</h2>
            </div>
            <div class="content">
                <h3>Angaben gemäß § 5 TMG</h3>
                <p>
                    JB - Kerzenzauber<br>
                    Musterstraße 1<br>
                    12345 Musterstadt<br>
                    Deutschland
                </p>
                
                <h3>Kontakt</h3>
                <p>
                    Telefon: +49 123 456789<br>
                    E-Mail: info@jb-kerzenzauber.de
                </p>
                
                <h3>Umsatzsteuer-Identifikationsnummer</h3>
                <p>Umsatzsteuer-Identifikationsnummer gemäß § 27 a Umsatzsteuergesetz: DE123456789</p>
                
                <h3>Verantwortlich für den Inhalt nach § 55 Abs. 2 RStV</h3>
                <p>
                    Max Mustermann<br>
                    Musterstraße 1<br>
                    12345 Musterstadt<br>
                    Deutschland
                </p>
                
                <h3>Streitschlichtung</h3>
                <p>Die Europäische Kommission stellt eine Plattform zur Online-Streitbeilegung (OS) bereit: <a href="https://ec.europa.eu/consumers/odr/" target="_blank">https://ec.europa.eu/consumers/odr/</a></p>
                <p>Wir sind nicht bereit oder verpflichtet, an Streitbeilegungsverfahren vor einer Verbraucherschlichtungsstelle teilzunehmen.</p>
                
                <h3>Haftung für Inhalte</h3>
                <p>Als Diensteanbieter sind wir gemäß § 7 Abs.1 TMG für eigene Inhalte auf diesen Seiten nach den allgemeinen Gesetzen verantwortlich. Nach §§ 8 bis 10 TMG sind wir als Diensteanbieter jedoch nicht verpflichtet, übermittelte oder gespeicherte fremde Informationen zu überwachen oder nach Umständen zu forschen, die auf eine rechtswidrige Tätigkeit hinweisen.</p>
                <p>Verpflichtungen zur Entfernung oder Sperrung der Nutzung von Informationen nach den allgemeinen Gesetzen bleiben hiervon unberührt. Eine diesbezügliche Haftung ist jedoch erst ab dem Zeitpunkt der Kenntnis einer konkreten Rechtsverletzung möglich. Bei Bekanntwerden von entsprechenden Rechtsverletzungen werden wir diese Inhalte umgehend entfernen.</p>
                
                <p><em>Dieses Impressum ist ein Beispiel und muss an die tatsächlichen Gegebenheiten angepasst werden.</em></p>
            </div>
        </section>
        
        <footer>
            <div class="footer-content" style="display: flex; flex-direction: column; align-items: center; justify-content: center; text-align: center;">
                <div class="copyright" style="width: 100%; text-align: center; margin-bottom: 15px;">
                    &copy; <?php echo date("Y"); ?> JB - Kerzenzauber. Alle Rechte vorbehalten.
                </div>
                <div class="footer-links" style="width: 100%; text-align: center; display: flex; justify-content: center; gap: 20px;">
                    <a href="datenschutz.php">Datenschutz</a>
                    <a href="impressum.php">Impressum</a>
                </div>
            </div>
        </footer>
    </div>

    <script src="assets/js/main.js"></script>
</body>
</html> 