<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>JB´s - Kerzenzauber - Elegante Kerzen für jeden Anlass</title>
    <?php
    // Session starten für Popup-Tracking
    session_start();
    
    // Initialisiere die Session-Variable für Popups, falls sie noch nicht existiert
    if (!isset($_SESSION['popups_seen'])) {
        $_SESSION['popups_seen'] = [];
    }
    
    // Verbindung zur Datenbank herstellen
    require_once('includes/db_connect.php');
    
    // Standard-Farbwerte
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
    
    // Prüfen, ob benutzerdefinierte Farben in der Datenbank vorhanden sind
    try {
        $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
        $savedColors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
        
        foreach ($colors as $name => $defaultValue) {
            if (isset($savedColors[$name]) && !empty($savedColors[$name])) {
                $colors[$name] = $savedColors[$name];
            }
        }
    } catch (PDOException $e) {
        // Falls die Tabelle noch nicht existiert, verwenden wir die Standardfarben
        error_log("Fehler beim Laden der Farbkonfiguration: " . $e->getMessage());
    }
    
    // Aktive Popups laden
    $activePopups = [];
    try {
        $today = date('Y-m-d');
        // Hole aktive Popups, die im Datumszeitraum liegen (oder keinen definierten Zeitraum haben)
        $stmt = $conn->prepare("SELECT * FROM popups 
                               WHERE active = 1 
                               AND (start_date IS NULL OR start_date <= ?) 
                               AND (end_date IS NULL OR end_date >= ?)
                               ORDER BY created_at DESC");
        $stmt->execute([$today, $today]);
        $activePopups = $stmt->fetchAll();
    } catch (PDOException $e) {
        // Falls die Tabelle noch nicht existiert, ignorieren
        error_log("Fehler beim Laden der Popups: " . $e->getMessage());
    }
    
    // Sichtbare Bereiche laden
    $visibleSections = [];
    try {
        $stmt = $conn->query("SELECT section_name FROM section_visibility WHERE visible = 1");
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $visibleSections[] = $row['section_name'];
        }
    } catch (PDOException $e) {
        // Standardmäßig alle Bereiche anzeigen
        $visibleSections = ['about', 'products', 'shops', 'testimonials', 'contact'];
        error_log("Fehler beim Laden der Sektionssichtbarkeit: " . $e->getMessage());
    }
    ?>
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
            --light-color: #f5f5f5;
            --dark-color: #212121;
            --font-main: 'Montserrat', sans-serif;
            --font-secondary: 'Playfair Display', serif;
            --container-width: 1200px; /* Standard width variable */
        }
        
        /* Order Forms Styles */
        .order-forms-container {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            justify-content: center;
            margin-top: 30px;
        }
        
        .order-form-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 3px 10px rgba(0,0,0,0.1);
            padding: 25px;
            width: 300px;
            text-align: center;
            transition: transform 0.3s ease, box-shadow 0.3s ease;
        }
        
        .order-form-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(0,0,0,0.2);
        }
        
        .order-form-card h3 {
            margin-top: 0;
            color: var(--primary-color);
            font-size: 1.3rem;
            margin-bottom: 10px;
        }
        
        .order-form-card .form-description {
            margin-bottom: 20px;
            color: #666;
        }
        
        .order-form-card .btn {
            background-color: var(--primary-color);
            color: white;
            padding: 10px 20px;
            border-radius: 5px;
            text-decoration: none;
            display: inline-block;
            font-weight: 500;
            transition: background-color 0.3s ease;
        }
        
        .order-form-card .btn:hover {
            background-color: var(--accent-color);
        }
        
        /* Popup-Styles */
        .popup-overlay {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
            z-index: 9999;
            justify-content: center;
            align-items: center;
        }
        
        .popup-container {
            background-color: white;
            max-width: 600px;
            width: 90%;
            border-radius: 6px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.2);
            position: relative;
            padding: 0;
            overflow: hidden;
            max-height: 90vh;
            display: flex;
            flex-direction: column;
        }
        
        .popup-header {
            padding: 15px 20px;
            border-bottom: 1px solid #e9ecef;
            position: relative;
        }
        
        .popup-title {
            margin: 0;
            font-size: 1.25rem;
            color: var(--secondary-color);
            font-weight: 600;
            padding-right: 30px;
        }
        
        .popup-close {
            position: absolute;
            top: 10px;
            right: 15px;
            font-size: 24px;
            cursor: pointer;
            color: #aaa;
            border: none;
            background: transparent;
            transition: color 0.2s;
        }
        
        .popup-close:hover {
            color: var(--secondary-color);
        }
        
        .popup-body {
            padding: 20px;
            overflow-y: auto;
        }
        
        .popup-footer {
            padding: 15px 20px;
            border-top: 1px solid #e9ecef;
            text-align: right;
        }
        
        .popup-button {
            background-color: var(--accent-color);
            color: white;
            border: none;
            padding: 8px 16px;
            border-radius: 4px;
            cursor: pointer;
            font-weight: 500;
            transition: background-color 0.2s;
        }
        
        .popup-button:hover {
            background-color: var(--primary-color);
        }
        
        /* Popup-Typen */
        .popup-info .popup-header {
            background-color: #17a2b8;
            color: white;
        }
        
        .popup-warning .popup-header {
            background-color: #dc3545;
            color: white;
        }
        
        .popup-success .popup-header {
            background-color: #28a745;
            color: white;
        }
        
        .popup-promo .popup-header {
            background-color: var(--accent-color);
            color: white;
        }
        
        .popup-info .popup-title, 
        .popup-success .popup-title, 
        .popup-promo .popup-title,
        .popup-warning .popup-title {
            color: white;
        }
        
        .popup-info .popup-close, 
        .popup-success .popup-close, 
        .popup-promo .popup-close,
        .popup-warning .popup-close {
            color: rgba(255, 255, 255, 0.8);
        }
        
        .popup-info .popup-close:hover, 
        .popup-success .popup-close:hover, 
        .popup-promo .popup-close:hover,
        .popup-warning .popup-close:hover {
            color: white;
        }
        
        /* Consistent container width */
        .container, 
        header,
        section,
        footer {
            max-width: var(--container-width) !important;
            margin-left: auto !important;
            margin-right: auto !important;
            width: 100% !important;
            box-sizing: border-box !important;
        }
        
        /* Remove any side margins */
        header, section, footer {
            margin-left: auto !important;
            margin-right: auto !important;
            padding-left: 0 !important;
            padding-right: 0 !important;
        }
        
        /* Fix display issues */
        #desktop-header {
            display: flex !important;
            width: 100% !important;
            max-width: 1200px !important;
            margin: 0 auto !important;
            padding: 15px 20px !important;
            justify-content: space-between !important;
            align-items: center !important;
        }
        
        #mobile-header {
            width: 100% !important;
            max-width: 1200px !important;
            margin: 0 auto !important;
        }
        
        header {
            padding: 15px 20px;
        }
        
        /* Direct logo size control regardless of device */
        .logo h1, 
        .logo h1 a,
        header .logo h1,
        header .logo h1 a {
            font-size: 24px !important;
            max-width: 220px !important;
        }
        
        /* Desktop navigation links */
        #desktop-nav ul li a {
            font-size: 18px !important;
            font-weight: 500 !important;
        }
        
        /* Hide mobile menu and button by default */
        #mobile-menu {
            display: none;
        }
        
        #mobile-menu-btn {
            display: none;
        }
        
        /* Mobile menu styles */
        #mobile-menu .mobile-menu-content a {
            font-size: 22px !important; /* Larger text in the mobile menu */
            padding: 14px !important;
            font-weight: 500 !important;
        }
        
        /* Adjust mobile specific styles */
        @media (max-width: 768px) {
            /* Hide desktop navigation */
            #desktop-nav {
                display: none !important;
            }
            
            /* Show mobile button */
            #mobile-menu-btn {
                display: block !important;
            }
            
            .logo h1 {
                font-size: 20px !important;
            }
            
            /* Ensure mobile menu has appropriate text size */
            .mobile-menu-content a {
                font-size: 22px !important;
                padding: 14px 8px !important;
            }
            
            /* Mobile menu styles */
            #mobile-menu {
                display: none;
                position: fixed;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                background: rgba(0, 0, 0, 0.8);
                z-index: 999;
            }
            
            #mobile-menu.active {
                display: block;
            }
            
            .mobile-menu-content {
                position: absolute;
                top: 0;
                right: 0;
                width: 80%;
                height: 100%;
                background: white;
                padding: 20px;
                overflow-y: auto;
            }
            
            .mobile-menu-content ul {
                list-style: none;
                padding: 0;
                margin: 50px 0 0 0;
            }
            
            .mobile-menu-content li {
                margin: 15px 0;
                text-align: center;
            }
            
            .mobile-menu-content a {
                display: block;
                padding: 10px;
                color: var(--primary-color);
                text-decoration: none;
                font-size: 20px;
                border-bottom: 1px solid #eee;
                font-weight: 500;
            }
            
            .close-menu {
                position: absolute;
                top: 15px;
                right: 20px;
                font-size: 30px;
                cursor: pointer;
                color: var(--primary-color);
            }
            
            /* Make hero section smaller on mobile */
            .hero {
                height: 60vh !important; /* Smaller height on mobile */
                min-height: 400px !important; /* Minimum height to ensure content fits */
            }
            
            .hero-content h2 {
                font-size: 2rem !important;
                margin-bottom: 10px !important;
            }
            
            .hero-content p {
                font-size: 1rem !important;
                margin-bottom: 20px !important;
            }
        }
        
        @media (max-width: 480px) {
            /* Even smaller text on small devices */
            .logo h1 {
                font-size: 20px !important;
            }
            
            .hero {
                height: 50vh !important;
                min-height: 350px !important;
            }
            
            .hero-content h2 {
                font-size: 1.8rem !important;
            }
            
            .hero-content p {
                font-size: 0.9rem !important;
                margin-bottom: 15px !important;
            }
        }
        
        /* Mobile-only header elements */
        #mobile-header {
            display: none !important; /* Hidden by default - adding !important */
        }
        
        @media (max-width: 768px) {
            #desktop-header {
                display: none !important; /* Hide desktop header on mobile */
            }
            
            #mobile-header {
                display: flex !important; /* Show mobile header on small screens */
            }
        }
    </style>
    <link rel="stylesheet" href="assets/css/style.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="assets/css/center-fix.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="assets/css/order-forms.css?v=<?php echo time(); ?>">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
</head>
<body style="--logo-font-size: 18px;">
    <?php if (!empty($activePopups)): ?>
        <?php foreach ($activePopups as $popup): ?>
            <?php 
            // Prüfen, ob dieser Popup bereits in dieser Sitzung angezeigt wurde
            if (!in_array($popup['id'], $_SESSION['popups_seen'])): 
            ?>
                <div id="popup-<?php echo $popup['id']; ?>" class="popup-overlay popup-<?php echo htmlspecialchars($popup['type']); ?>">
                    <div class="popup-container">
                        <div class="popup-header">
                            <h3 class="popup-title"><?php echo htmlspecialchars($popup['title']); ?></h3>
                            <button type="button" class="popup-close" data-popup-id="<?php echo $popup['id']; ?>">&times;</button>
                        </div>
                        <div class="popup-body">
                            <?php echo $popup['content']; ?>
                        </div>
                        <div class="popup-footer">
                            <button type="button" class="popup-button" data-popup-id="<?php echo $popup['id']; ?>">Verstanden</button>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        <?php endforeach; ?>
    <?php endif; ?>
    
    <div class="container">
        <!-- Desktop header (hidden on mobile) -->
        <header id="desktop-header">
            <div style="display: flex; justify-content: space-between; align-items: center; width: 100%; max-width: 1200px; margin: 0 auto; padding: 15px 20px;">
                <div class="logo" style="flex: 1; max-width: 40%;">
                    <h1 style="font-size: 24px !important; white-space: normal; overflow: visible; margin: 0;"><a href="index.php" style="display: inline-block; font-size: 26px !important;">JB - Kerzenzauber</a></h1>
                </div>
                
                <!-- Desktop Navigation -->
                <nav id="desktop-nav" style="flex: 1; text-align: right;">
                    <ul style="display: flex; justify-content: flex-end; align-items: center;">
                        <?php if (in_array('about', $visibleSections)): ?>
                        <li><a href="#ueber-uns" style="font-size: 18px; font-weight: 500; padding: 0 15px;">Über uns</a></li>
                        <?php endif; ?>
                        
                        <?php if (in_array('products', $visibleSections)): ?>
                        <li><a href="#produkte" style="font-size: 18px; font-weight: 500; padding: 0 15px;">Produkte</a></li>
                        <?php endif; ?>
                        
                        <?php if (in_array('shops', $visibleSections)): ?>
                        <li><a href="#shops" style="font-size: 18px; font-weight: 500; padding: 0 15px;">Shops</a></li>
                        <?php endif; ?>
                        
                        <?php if (in_array('orders', $visibleSections)): ?>
                        <li><a href="#orders" style="font-size: 18px; font-weight: 500; padding: 0 15px;">Bestellungen</a></li>
                        <?php endif; ?>
                        
                        <?php if (in_array('contact', $visibleSections)): ?>
                        <li><a href="#kontakt" style="font-size: 18px; font-weight: 500; padding: 0 15px;">Kontakt</a></li>
                        <?php endif; ?>
                    </ul>
                </nav>
            </div>
        </header>
        
        <!-- Mobile header (only shown on mobile) -->
        <header id="mobile-header" style="display: none;">
            <div style="display: flex; justify-content: space-between; align-items: center; width: 100%; max-width: 1200px; margin: 0 auto; padding: 10px 20px;">
                <div class="logo" style="flex: 1; max-width: 80%;">
                    <h1 style="font-size: 20px !important; white-space: normal; overflow: visible; margin: 0; line-height: 1.2;"><a href="index.php" style="display: inline-block; font-size: 25px !important; letter-spacing: -0.3px;">JB - Kerzenzauber</a></h1>
                </div>
                
                <!-- Mobile Menu Button -->
                <div id="mobile-menu-btn" style="cursor: pointer; margin-left: 5px; padding: 5px; z-index: 900; flex: 0 0 auto;">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" style="fill: #8b6b4f;">
                        <path d="M3 18h18v-2H3v2zm0-5h18v-2H3v2zm0-7v2h18V6H3z"></path>
                    </svg>
                </div>
            </div>
        </header>

        <!-- New Mobile Menu -->
        <div id="mobile-menu">
            <div class="mobile-menu-content">
                <div class="close-menu">&times;</div>
                <ul>
                    <?php if (in_array('about', $visibleSections)): ?>
                    <li><a href="#ueber-uns" style="font-size: 22px; font-weight: 500; padding: 14px 8px;">Über uns</a></li>
                    <?php endif; ?>
                    
                    <?php if (in_array('products', $visibleSections)): ?>
                    <li><a href="#produkte" style="font-size: 22px; font-weight: 500; padding: 14px 8px;">Produkte</a></li>
                    <?php endif; ?>
                    
                    <?php if (in_array('shops', $visibleSections)): ?>
                    <li><a href="#shops" style="font-size: 22px; font-weight: 500; padding: 14px 8px;">Shops</a></li>
                    <?php endif; ?>
                    
                    <?php if (in_array('orders', $visibleSections)): ?>
                    <li><a href="#orders" style="font-size: 22px; font-weight: 500; padding: 14px 8px;">Bestellungen</a></li>
                    <?php endif; ?>
                    
                    <?php if (in_array('contact', $visibleSections)): ?>
                    <li><a href="#kontakt" style="font-size: 22px; font-weight: 500; padding: 14px 8px;">Kontakt</a></li>
                    <?php endif; ?>
                </ul>
            </div>
        </div>
        
        <section class="hero">
            <div class="hero-content">
                <?php
                $stmt = $conn->prepare("SELECT * FROM hero_content WHERE id = 1");
                $stmt->execute();
                $hero = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($hero) {
                    // Wir setzen den Hintergrund mit Inline-Style
                    echo '<style>';
                    echo '.hero {';
                    if (!empty($hero['bg_image'])) {
                        echo 'background-image: linear-gradient(' . htmlspecialchars($hero['bg_color']) . ', ' . htmlspecialchars($hero['bg_color']) . '), url(\'' . htmlspecialchars($hero['bg_image']) . '\');';
                        echo 'background-size: cover !important;';
                        echo 'background-position: center center !important;';
                        echo 'background-attachment: scroll !important;';
                    } else {
                        echo 'background-image: none;';
                        echo 'background-color: ' . htmlspecialchars($hero['bg_color']) . ';';
                    }
                    echo '}';
                    
                    // Responsive Anpassungen
                    echo '@media (max-width: 768px) {';
                    echo '.hero {';
                    echo 'height: 70vh !important;';
                    echo 'min-height: 450px !important;';
                    if (!empty($hero['bg_image'])) {
                        echo 'background-position: center center !important;';
                        echo 'background-size: cover !important;';
                        echo 'background-attachment: scroll !important;';
                    }
                    echo '}';
                    echo '}';
                    
                    echo '@media (max-width: 480px) {';
                    echo '.hero {';
                    echo 'height: 60vh !important;';
                    echo 'min-height: 400px !important;';
                    echo '}';
                    echo '}';
                    
                    echo '.hero-content { color: ' . htmlspecialchars($hero['text_color']) . '; }';
                    echo '</style>';
                    
                    echo '<h2>' . htmlspecialchars($hero['headline']) . '</h2>';
                    echo '<p>' . htmlspecialchars($hero['subtext']) . '</p>';
                    echo '<a href="' . htmlspecialchars($hero['button_url']) . '" class="btn">' . htmlspecialchars($hero['button_text']) . '</a>';
                } else {
                    // Fallback, falls keine Daten in der Datenbank sind
                    echo '<h2>Handgefertigte Kerzen mit Liebe gemacht</h2>';
                    echo '<p>Entdecken Sie unsere einzigartigen, nachhaltigen Kerzen für jeden Anlass</p>';
                    echo '<a href="#shops" class="btn">Jetzt kaufen</a>';
                }
                ?>
            </div>
        </section>

        <?php if (in_array('about', $visibleSections)): ?>
        <section id="ueber-uns" class="about">
            <div class="section-header">
                <h2>Über uns</h2>
            </div>
            <div class="about-content">
                <?php
                $stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
                $stmt->execute();
                $brand = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($brand) {
                    echo '<div class="about-text">';
                    echo '<h3>' . htmlspecialchars($brand['title']) . '</h3>';
                    echo '<p>' . nl2br(htmlspecialchars($brand['description'])) . '</p>';
                    echo '</div>';
                    
                    if (!empty($brand['image_path'])) {
                        echo '<div class="about-image">';
                        echo '<img src="' . htmlspecialchars($brand['image_path']) . '" alt="' . htmlspecialchars($brand['title']) . '">';
                        echo '</div>';
                    }
                } else {
                    echo '<p>Informationen werden geladen...</p>';
                }
                ?>
            </div>
        </section>
        <?php endif; ?>

        <?php if (in_array('products', $visibleSections)): ?>
        <section id="produkte" class="products" style="text-align: center;">
            <div class="section-header">
                <h2>Unsere Produkte</h2>
            </div>
            <div class="products-grid" style="text-align: center; display: flex; flex-wrap: wrap; gap: 40px; padding: 0 40px; margin: 0 auto; justify-content: center;">
                <?php
                $stmt = $conn->prepare("SELECT * FROM products WHERE active = 1 ORDER BY sort_order");
                $stmt->execute();
                $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                if ($products) {
                    foreach ($products as $product) {
                        echo '<div class="product-card" style="text-align: center; margin: 0 auto 30px; display: flex; flex-direction: column; align-items: center; width: 280px; max-width: 100%; cursor: pointer;" data-product-id="' . $product['id'] . '">';
                        echo '<div class="product-image" style="display: flex; justify-content: center; align-items: center; width: 100%;">';
                        echo '<img src="' . htmlspecialchars($product['image_path']) . '" alt="' . htmlspecialchars($product['name']) . '">';
                        echo '</div>';
                        echo '<div class="product-info" style="text-align: center; display: flex; flex-direction: column; align-items: center; width: 100%;">';
                        echo '<h3 style="text-align: center; width: 100%;">' . htmlspecialchars($product['name']) . '</h3>';
                        echo '<p style="text-align: center; width: 100%;">' . htmlspecialchars($product['short_description']) . '</p>';
                        
                        // Preis anzeigen, falls aktiviert
                        if ($product['price'] > 0 && $product['show_price']) {
                            echo '<div class="product-price" style="font-size: 1.2rem; font-weight: bold; color: var(--accent-color); margin: 10px 0;">';
                            echo number_format($product['price'], 2, ',', '.') . ' €';
                            echo '</div>';
                        }
                        
                        if ($product['show_stock_info']) {
                            if ($product['stock_level'] > 0) {
                                echo '<p class="stock-info in-stock" style="margin-top: auto;">Auf Lager: ' . $product['stock_level'] . '</p>';
                            } else {
                                echo '<p class="stock-info out-of-stock" style="margin-top: auto;">zurzeit Ausverkauft</p>';
                            }
                        }
                        
                        echo '</div>';
                        echo '</div>';
                    }
                } else {
                    echo '<p>Keine Produkte gefunden</p>';
                }
                ?>
            </div>
        </section>
        <?php endif; ?>

        <!-- Produkt-Detail-Modal -->
        <div id="product-modal" class="modal">
            <div class="modal-content">
                <span class="close-modal">&times;</span>
                <div class="modal-header">
                    <h2 id="modal-product-name"></h2>
                </div>
                <div class="modal-body">
                    <div class="modal-product-gallery">
                        <img id="modal-main-image" class="modal-main-image" src="" alt="" loading="lazy">
                        <div class="gallery-thumbnails" id="gallery-thumbnails">
                            <!-- Thumbnails werden dynamisch hinzugefügt -->
                        </div>
                    </div>
                    <div class="modal-product-details">
                        <p id="modal-product-description"></p>
                        <p id="modal-product-price" style="font-size: 1.3rem; font-weight: bold; color: var(--accent-color); margin: 15px 0;"></p>
                        <p id="modal-product-stock"></p>
                    </div>
                </div>
            </div>
        </div>

        <?php if (in_array('shops', $visibleSections)): ?>
        <section id="shops" class="shops">
            <div class="section-header">
                <h2>In unseren Shops kaufen</h2>
            </div>
            <div class="shops-container">
                <?php
                $stmt = $conn->prepare("SELECT * FROM shops WHERE active = 1 ORDER BY sort_order");
                $stmt->execute();
                $shops = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                if ($shops) {
                    foreach ($shops as $shop) {
                        echo '<div class="shop-card">';
                        if (!empty($shop['logo_path'])) {
                            echo '<div class="shop-logo">';
                            echo '<img src="' . htmlspecialchars($shop['logo_path']) . '" alt="' . htmlspecialchars($shop['name']) . '">';
                            echo '</div>';
                        }
                        echo '<div class="shop-info">';
                        echo '<h3>' . htmlspecialchars($shop['name']) . '</h3>';
                        echo '<p>' . htmlspecialchars($shop['description']) . '</p>';
                        echo '<a href="' . htmlspecialchars($shop['url']) . '" class="btn" target="_blank">Zum Shop <i class="fas fa-external-link-alt"></i></a>';
                        echo '</div>';
                        echo '</div>';
                    }
                } else {
                    echo '<p>Keine Shops gefunden</p>';
                }
                ?>
            </div>
        </section>
        <?php endif; ?>
        
        <?php if (in_array('testimonials', $visibleSections)): ?>
        <section id="testimonials" class="testimonials">
            <div class="section-header">
                <h2>Kundenstimmen</h2>
            </div>
            <div class="testimonials-slider">
                <?php
                $stmt = $conn->prepare("SELECT * FROM testimonials WHERE active = 1 ORDER BY sort_order");
                $stmt->execute();
                $testimonials = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                if ($testimonials) {
                    foreach ($testimonials as $testimonial) {
                        echo '<div class="testimonial-card">';
                        echo '<div class="testimonial-text">';
                        echo '<i class="fas fa-quote-left"></i>';
                        echo '<p>' . htmlspecialchars($testimonial['content']) . '</p>';
                        echo '</div>';
                        echo '<div class="testimonial-author">';
                        echo '<p>' . htmlspecialchars($testimonial['author']) . '</p>';
                        echo '</div>';
                        echo '</div>';
                    }
                } else {
                    echo '<p>Keine Kundenstimmen gefunden</p>';
                }
                ?>
            </div>
        </section>
        <?php endif; ?>
        
        <?php if (in_array('orders', $visibleSections)): ?>
        <section id="orders" class="section">
            <div class="container">
                <h2 class="section-title">Bestellungen</h2>
                
                <div class="order-section-content" style="text-align: center; max-width: 800px; margin: 0 auto;">
                    <p style="margin-bottom: 30px; font-size: 18px;">
                        Bestellen Sie unsere hochwertigen Kerzenprodukte bequem online. Wählen Sie Ihr gewünschtes Produkt, um mit Ihrer Bestellung zu beginnen.
                    </p>
                    <a href="order.php" class="btn" style="font-size: 18px; padding: 12px 30px;">
                        <i class="fas fa-shopping-cart"></i> Jetzt bestellen
                    </a>
                </div>
            </div>
        </section>
        <?php endif; ?>
        
        <?php if (in_array('contact', $visibleSections)): ?>
        <section id="kontakt" class="contact">
            <div class="section-header">
                <h2>Kontakt</h2>
            </div>
            <div class="contact-content">
                <?php
                $stmt = $conn->prepare("SELECT * FROM contact_info WHERE id = 1");
                $stmt->execute();
                $contact = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($contact) {
                    echo '<div class="contact-info">';
                    echo '<h3>Kontaktieren Sie uns</h3>';
                    if (!empty($contact['email'])) {
                        echo '<p><i class="fas fa-envelope"></i> ' . htmlspecialchars($contact['email']) . '</p>';
                    }
                    
                    if (!empty($contact['phone'])) {
                        echo '<p><i class="fas fa-phone"></i> ' . htmlspecialchars($contact['phone']) . '</p>';
                    }
                    if (!empty($contact['address'])) {
                        echo '<p><i class="fas fa-map-marker-alt"></i> ' . nl2br(htmlspecialchars($contact['address'])) . '</p>';
                    }
                    echo '</div>';
                    
                    if (!empty($contact['social_facebook']) || !empty($contact['social_instagram'])) {
                        echo '<div class="social-links">';
                        echo '<h3>Folgen Sie uns</h3>';
                        echo '<div class="social-icons">';
                        if (!empty($contact['social_facebook'])) {
                            echo '<a href="' . htmlspecialchars($contact['social_facebook']) . '" target="_blank"><i class="fab fa-facebook-f"></i></a>';
                        }
                        if (!empty($contact['social_instagram'])) {
                            echo '<a href="' . htmlspecialchars($contact['social_instagram']) . '" target="_blank"><i class="fab fa-instagram"></i></a>';
                        }
                        echo '</div>';
                        echo '</div>';
                    }
                } else {
                    echo '<p>Kontaktinformationen werden geladen...</p>';
                }
                ?>
            </div>
        </section>
        <?php endif; ?>
        
        <footer>
            <div class="footer-content" style="display: flex; flex-direction: column; align-items: center; justify-content: center; text-align: center;">
                <div class="copyright" style="width: 100%; text-align: center; margin-bottom: 15px;">
                    &copy; <?php echo date("Y"); ?> - JB - Kerzenzauber.<br> Alle Rechte vorbehalten.
                </div>
                <div class="footer-links" style="width: 100%; text-align: center; display: flex; justify-content: center; gap: 20px;">
                    <a href="datenschutz.php">Datenschutz</a>
                    <a href="impressum.php">Impressum</a>
                </div>
            </div>
        </footer>
    </div>

    <script src="assets/js/main.js"></script>
    <script>
        // Popup-Funktionalität
        document.addEventListener('DOMContentLoaded', function() {
            // Popup-Handler
            const popupOverlays = document.querySelectorAll('.popup-overlay');
            
            // Alle aktiven Popups anzeigen
            setTimeout(function() {
                popupOverlays.forEach(function(popup) {
                    popup.style.display = 'flex';
                });
            }, 500); // Kleine Verzögerung, damit die Seite zuerst laden kann
            
            // Funktion zum Schließen eines Popups
            function closePopup(popupId) {
                const popup = document.getElementById('popup-' + popupId);
                if (popup) {
                    popup.style.display = 'none';
                    
                    // AJAX-Anfrage, um den Popup als gesehen zu markieren
                    const xhr = new XMLHttpRequest();
                    xhr.open('POST', 'mark_popup_seen.php', true);
                    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                    xhr.send('popup_id=' + popupId);
                }
            }
            
            // Event-Listener für Schließen-Buttons
            document.querySelectorAll('.popup-close, .popup-button').forEach(function(button) {
                button.addEventListener('click', function() {
                    const popupId = this.getAttribute('data-popup-id');
                    closePopup(popupId);
                });
            });
            
            // Popup schließen, wenn außerhalb geklickt wird
            popupOverlays.forEach(function(overlay) {
                overlay.addEventListener('click', function(e) {
                    if (e.target === this) {
                        const popupId = this.id.replace('popup-', '');
                        closePopup(popupId);
                    }
                });
            });
        });
        
        // Ultra-simple mobile menu
        document.addEventListener('DOMContentLoaded', function() {
            // Ensure proper header display
            function updateHeaders() {
                const isMobile = window.innerWidth <= 768;
                document.getElementById('desktop-header').style.display = isMobile ? 'none' : 'flex';
                document.getElementById('mobile-header').style.display = isMobile ? 'flex' : 'none';
                console.log(isMobile ? 'Mobile view active' : 'Desktop view active');
            }
            
            // Run once on load
            updateHeaders();
            
            // Run on resize
            window.addEventListener('resize', updateHeaders);
            
            // Get elements
            const mobileMenuBtn = document.getElementById('mobile-menu-btn');
            const mobileMenu = document.getElementById('mobile-menu');
            const closeMenu = document.querySelector('.close-menu');
            const mobileLinks = document.querySelectorAll('#mobile-menu a');
            
            // Open menu when button is clicked
            mobileMenuBtn.addEventListener('click', function() {
                console.log('Mobile button clicked');
                mobileMenu.classList.add('active');
            });
            
            // Close menu when X is clicked
            closeMenu.addEventListener('click', function() {
                console.log('Close button clicked');
                mobileMenu.classList.remove('active');
            });
            
            // Close menu when any link is clicked
            mobileLinks.forEach(function(link) {
                link.addEventListener('click', function() {
                    console.log('Link clicked');
                    mobileMenu.classList.remove('active');
                });
            });
            
            // Close menu when clicking outside
            mobileMenu.addEventListener('click', function(e) {
                if (e.target === mobileMenu) {
                    mobileMenu.classList.remove('active');
                }
            });
            
            // Debug info
            console.log('Mobile menu initialized');
            
            // Produkt-Modal Funktionalität
            const productCards = document.querySelectorAll('.product-card');
            const productModal = document.getElementById('product-modal');
            const closeModal = document.querySelector('.close-modal');
            const modalProductName = document.getElementById('modal-product-name');
            const modalMainImage = document.getElementById('modal-main-image');
            const galleryThumbnails = document.getElementById('gallery-thumbnails');
            const modalProductDescription = document.getElementById('modal-product-description');
            const modalProductPrice = document.getElementById('modal-product-price');
            const modalProductStock = document.getElementById('modal-product-stock');
            
            // Produkt-Daten speichern
            const productData = <?php 
                $productJSON = [];
                if (isset($products) && is_array($products)) {
                    foreach ($products as $p) {
                        // Zusätzliche Bilder aus der Datenbank laden
                        $additionalImages = [];
                        
                        // Hauptbild immer als erstes
                        $additionalImages[] = $p['image_path'];
                        
                        // Weitere Bilder aus der Datenbank laden
                        try {
                            $imagesStmt = $conn->prepare("SELECT image_path FROM product_images WHERE product_id = ? ORDER BY sort_order LIMIT 4");
                            $imagesStmt->execute([$p['id']]);
                            $productImages = $imagesStmt->fetchAll(PDO::FETCH_COLUMN);
                            
                            foreach ($productImages as $imgPath) {
                                $additionalImages[] = $imgPath;
                            }
                        } catch (PDOException $e) {
                            // Bei Fehler ignorieren, nur Hauptbild anzeigen
                            error_log("Fehler beim Laden der zusätzlichen Bilder: " . $e->getMessage());
                        }
                        
                        $productJSON[$p['id']] = [
                            'name' => $p['name'],
                            'short_description' => $p['short_description'],
                            'description' => $p['description'],
                            'image_path' => $p['image_path'],
                            'images' => $additionalImages, // Array mit allen Produktbildern
                            'price' => $p['price'],
                            'show_price' => $p['show_price'],
                            'stock_level' => $p['stock_level'],
                            'show_stock_info' => $p['show_stock_info']
                        ];
                    }
                }
                echo json_encode($productJSON);
            ?>;
            
            // Produkt-Karten klickbar machen
            productCards.forEach(function(card) {
                card.addEventListener('click', function() {
                    const productId = this.getAttribute('data-product-id');
                    if (productId && productData[productId]) {
                        const product = productData[productId];
                        
                        // Modal mit Produktdaten befüllen
                        modalProductName.textContent = product.name;
                        modalMainImage.src = product.image_path;
                        modalMainImage.alt = product.name;
                        modalProductDescription.innerHTML = product.description.replace(/\n/g, '<br>');
                        
                        // Preis anzeigen, falls aktiviert
                        if (product.price > 0 && product.show_price == 1) {
                            modalProductPrice.textContent = parseFloat(product.price).toLocaleString('de-DE', {
                                minimumFractionDigits: 2,
                                maximumFractionDigits: 2
                            }) + ' €';
                            modalProductPrice.style.display = 'block';
                        } else {
                            modalProductPrice.style.display = 'none';
                        }
                        
                        // Lagerbestand anzeigen falls aktiviert
                        if (product.show_stock_info && product.show_stock_info == 1) {
                            if (product.stock_level > 0) {
                                modalProductStock.className = 'in-stock';
                                modalProductStock.textContent = 'Auf Lager: ' + product.stock_level;
                            } else {
                                modalProductStock.className = 'out-of-stock';
                                modalProductStock.textContent = 'zurzeit Ausverkauft';
                            }
                            modalProductStock.style.display = 'inline-block';
                        } else {
                            modalProductStock.style.display = 'none';
                        }
                        
                        // Bildergalerie erstellen
                        createGalleryThumbnails(product.images, product.name);
                        
                        // Modal öffnen
                        productModal.style.display = 'block';
                        document.body.style.overflow = 'hidden'; // Scrolling verhindern
                    }
                });
            });
            
            // Funktion zum Erstellen der Bildergalerie-Thumbnails
            function createGalleryThumbnails(images, productName) {
                // Thumbnails-Container leeren
                galleryThumbnails.innerHTML = '';
                
                // Für jedes Bild einen Thumbnail erstellen
                images.forEach(function(imagePath, index) {
                    const thumbnail = document.createElement('img');
                    thumbnail.src = imagePath;
                    thumbnail.alt = productName + ' - Bild ' + (index + 1);
                    thumbnail.className = 'gallery-thumbnail' + (index === 0 ? ' active' : '');
                    thumbnail.dataset.index = index;
                    thumbnail.loading = 'lazy';
                    
                    // Event-Listener für Klick auf Thumbnail
                    thumbnail.addEventListener('click', function() {
                        // Hauptbild aktualisieren
                        modalMainImage.src = imagePath;
                        
                        // Aktive Klasse aktualisieren
                        galleryThumbnails.querySelectorAll('.gallery-thumbnail').forEach(function(thumb) {
                            thumb.classList.remove('active');
                        });
                        thumbnail.classList.add('active');
                    });
                    
                    // Thumbnail zum Container hinzufügen
                    galleryThumbnails.appendChild(thumbnail);
                });
            }
            
            // Modal schließen wenn X geklickt wird
            if (closeModal) {
                closeModal.addEventListener('click', function() {
                    productModal.style.display = 'none';
                    document.body.style.overflow = ''; // Scrolling wieder erlauben
                });
            }
            
            // Modal schließen wenn außerhalb geklickt wird
            window.addEventListener('click', function(e) {
                if (e.target === productModal) {
                    productModal.style.display = 'none';
                    document.body.style.overflow = ''; // Scrolling wieder erlauben
                }
            });
            
            // ESC-Taste zum Schließen des Modals
            window.addEventListener('keydown', function(e) {
                if (e.key === 'Escape' && productModal.style.display === 'block') {
                    productModal.style.display = 'none';
                    document.body.style.overflow = ''; // Scrolling wieder erlauben
                }
            });
        });
    </script>
</body>
</html> 