<?php
require_once('includes/db_connect.php');

// Get product ID from query string if available
$selected_product_id = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
$show_form = false;
$form_id = 0;

// If a product is selected, find the associated form
if ($selected_product_id > 0) {
    $stmt = $conn->prepare("
        SELECT id FROM order_forms 
        WHERE product_id = :product_id AND active = 1
        LIMIT 1
    ");
    $stmt->bindParam(':product_id', $selected_product_id);
    $stmt->execute();
    
    if ($form = $stmt->fetch()) {
        $form_id = $form['id'];
        $show_form = true;
    }
}

// Get active products
$stmt = $conn->prepare("
    SELECT id, name, image_path, short_description
    FROM products 
    WHERE active = 1 
    ORDER BY sort_order
");
$stmt->execute();
$products = $stmt->fetchAll();

// Get site title
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'site_title'");
$stmt->execute();
$site_title = $stmt->fetchColumn() ?: 'JB Kerzen';

// Get brand info
$stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
$stmt->execute();
$brand = $stmt->fetch();

// Get order logo
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'order_logo'");
$stmt->execute();
$order_logo = $stmt->fetchColumn() ?: '';

// Load CSS Variables
$stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
$colors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);

// Default colors if not found
if (!isset($colors['primary_color'])) $colors['primary_color'] = '#8b6b4f';
if (!isset($colors['secondary_color'])) $colors['secondary_color'] = '#333333';
if (!isset($colors['accent_color'])) $colors['accent_color'] = '#d4af37';
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Bestellung | <?php echo htmlspecialchars($site_title); ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css">
    <link rel="stylesheet" href="assets/css/order-forms.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
        }
        
        .section {
            padding: 60px 0;
        }
        
        .section-title {
            text-align: center;
            margin-bottom: 40px;
            font-size: 32px;
            color: var(--primary-color);
        }
        
        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 20px;
        }
        
        .product-selection {
            margin-bottom: 50px;
        }
        
        .product-grid {
            display: flex;
            flex-wrap: wrap;
            justify-content: center;
            gap: 25px;
        }
        
        .product-card {
            width: 280px;
            border-radius: 10px;
            overflow: hidden;
            box-shadow: 0 3px 10px rgba(0,0,0,0.1);
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            background: white;
            cursor: pointer;
        }
        
        .product-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(0,0,0,0.2);
        }
        
        .product-card.selected {
            border: 2px solid #28a745;
            background-color: rgba(40, 167, 69, 0.05);
        }
        
        .product-image {
            height: 200px;
            overflow: hidden;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        
        .product-image img {
            width: 100%;
            height: 100%;
            object-fit: contain;
        }
        
        .product-details {
            padding: 20px;
            text-align: center;
        }
        
        .product-details h3 {
            margin-top: 0;
            color: var(--primary-color);
            font-size: 1.2rem;
        }
        
        .product-details p {
            color: #555;
            margin-bottom: 15px;
        }
        
        .quantity-label {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 10px;
            margin-top: 10px;
        }
        
        .quantity-input {
            width: 60px;
            padding: 5px;
            border: 1px solid #ddd;
            border-radius: 5px;
            text-align: center;
        }
        
        .quantity-input:focus {
            border-color: var(--primary-color);
            outline: none;
        }
        
        .select-product {
            width: 100%;
            margin-top: 10px;
        }
        
        .select-product.selected-btn {
            background-color: #28a745;
        }
        
        .btn-lg {
            padding: 12px 30px;
            font-size: 18px;
        }
        
        .btn {
            display: inline-block;
            padding: 10px 20px;
            background-color: var(--primary-color);
            color: white;
            text-decoration: none;
            border-radius: 5px;
            transition: background-color 0.3s;
            border: none;
            cursor: pointer;
            font-size: 16px;
        }
        
        .btn:hover {
            background-color: var(--accent-color);
        }
        
        /* Form container styling */
        .order-form-container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 5px 15px rgba(0,0,0,0.1);
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: 500;
            color: var(--secondary-color);
        }
        
        .form-control {
            width: 100%;
            padding: 12px 15px;
            border: 1px solid #ddd;
            border-radius: 5px;
            font-size: 16px;
        }
        
        .text-danger {
            color: #dc3545;
        }
        
        .checkbox-group, 
        .radio-group {
            display: flex;
            flex-direction: column;
            gap: 8px;
        }
        
        .checkbox-option,
        .radio-option {
            display: flex;
            align-items: center;
        }
        
        .checkbox-option input,
        .radio-option input {
            margin-right: 10px;
        }
        
        .required-mark {
            color: #dc3545;
            margin-left: 3px;
        }
        
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 5px;
        }
        
        .alert-danger {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
        }
        
        .alert-success {
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
            color: #155724;
        }
        
        .site-header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            position: relative;
            z-index: 100;
            padding: 15px 0;
        }
        
        .header-content {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .brand-text {
            font-size: 24px;
            color: var(--primary-color);
            text-decoration: none;
            font-weight: bold;
        }
        
        .brand-logo {
            height: 60px;
            width: auto;
        }
        
        .back-link {
            color: var(--primary-color);
            text-decoration: none;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .back-link:hover {
            color: var(--accent-color);
        }
        
        .site-footer {
            background-color: var(--secondary-color);
            color: white;
            padding: 30px 0;
            margin-top: 50px;
        }
        
        .footer-content {
            display: flex;
            flex-direction: column;
            align-items: center;
            text-align: center;
        }
        
        .footer-copyright {
            margin-bottom: 15px;
        }
        
        .footer-links {
            display: flex;
            gap: 20px;
        }
        
        .footer-links a {
            color: white;
            text-decoration: none;
        }
        
        .footer-links a:hover {
            text-decoration: underline;
        }
        
        /* Steps indicator */
        .order-steps {
            display: flex;
            justify-content: center;
            margin-bottom: 40px;
        }
        
        .step {
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 150px;
            position: relative;
        }
        
        .step:not(:last-child)::after {
            content: '';
            position: absolute;
            top: 30px;
            right: -50%;
            width: 100%;
            height: 2px;
            background-color: #ddd;
            z-index: 1;
        }
        
        .step.active:not(:last-child)::after {
            background-color: var(--accent-color);
        }
        
        .step-number {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            background-color: #ddd;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 24px;
            font-weight: bold;
            color: white;
            margin-bottom: 10px;
            position: relative;
            z-index: 2;
        }
        
        .step.active .step-number {
            background-color: var(--accent-color);
        }
        
        .step-title {
            font-weight: 500;
            color: #777;
        }
        
        .step.active .step-title {
            color: var(--accent-color);
        }
        
        /* Responsive adjustments */
        @media (max-width: 768px) {
            .product-card {
                width: 100%;
                max-width: 320px;
            }
            
            .order-steps {
                flex-direction: column;
                align-items: center;
                gap: 20px;
            }
            
            .step {
                flex-direction: row;
                width: 100%;
                gap: 15px;
            }
            
            .step:not(:last-child)::after {
                display: none;
            }
            
            .step-number {
                width: 40px;
                height: 40px;
                font-size: 18px;
                margin-bottom: 0;
            }
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="site-header">
        <div class="container">
            <div class="header-content">
                <div class="brand">
                    <?php if (!empty($order_logo) && file_exists($order_logo)): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($order_logo); ?>" alt="<?php echo htmlspecialchars($site_title); ?>" class="brand-logo">
                        </a>
                    <?php elseif (isset($brand['image_path']) && !empty($brand['image_path'])): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($brand['image_path']); ?>" alt="<?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>" class="brand-logo">
                        </a>
                    <?php else: ?>
                        <a href="index.php" class="brand-text">
                            <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>
                        </a>
                    <?php endif; ?>
                </div>
                
                <a href="index.php" class="back-link">
                    <i class="fas fa-arrow-left"></i> Zurück zur Startseite
                </a>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <main>
        <section class="section">
            <div class="container">
                <h1 class="section-title">Bestellung aufgeben</h1>
                
                <!-- Steps indicator -->
                <div class="order-steps">
                    <div class="step <?php echo (!$show_form) ? 'active' : ''; ?>">
                        <div class="step-number">1</div>
                        <div class="step-title">Produkt auswählen</div>
                    </div>
                    <div class="step <?php echo ($show_form) ? 'active' : ''; ?>">
                        <div class="step-number">2</div>
                        <div class="step-title">Bestelldaten eingeben</div>
                    </div>
                </div>
                
                <?php if (!$show_form): ?>
                    <!-- Product selection -->
                    <div class="product-selection">
                        <h2 style="text-align: center; margin-bottom: 30px;">Wählen Sie Ihre Produkte</h2>
                        
                        <?php if (empty($products)): ?>
                            <div class="alert alert-info" style="text-align: center;">
                                <p>Aktuell sind keine Produkte verfügbar.</p>
                                <a href="index.php" class="btn" style="margin-top: 15px;">Zurück zur Startseite</a>
                            </div>
                        <?php else: ?>
                            <form method="post" action="order_cart.php" id="orderForm">
                                <div class="selected-products-summary" style="text-align: center; margin-bottom: 20px; display: none;">
                                    <p>Sie haben <span id="selectedProductsCount">0</span> Produkte ausgewählt.</p>
                                    <button type="submit" class="btn" style="margin-top: 10px;">
                                        <i class="fas fa-shopping-cart"></i> Weiter zur Bestellung
                                    </button>
                                </div>
                                
                                <div class="product-grid">
                                    <?php foreach ($products as $product): ?>
                                        <?php
                                        // Check if this product has an order form
                                        $stmt = $conn->prepare("SELECT COUNT(*) FROM order_forms WHERE product_id = :id AND active = 1");
                                        $stmt->bindParam(':id', $product['id']);
                                        $stmt->execute();
                                        $hasForm = $stmt->fetchColumn() > 0;
                                        ?>
                                        <div class="product-card product-selectable" data-product-id="<?php echo $product['id']; ?>" <?php echo !$hasForm ? 'style="opacity: 0.6;"' : ''; ?>>
                                            <div class="product-image">
                                                <img src="<?php echo htmlspecialchars($product['image_path']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>">
                                            </div>
                                            <div class="product-details">
                                                <h3><?php echo htmlspecialchars($product['name']); ?></h3>
                                                <p><?php echo htmlspecialchars($product['short_description']); ?></p>
                                                
                                                <?php if ($hasForm): ?>
                                                    <div class="product-selection-controls">
                                                        <button type="button" class="btn select-product" data-product-id="<?php echo $product['id']; ?>">
                                                            <i class="fas fa-plus"></i> Auswählen
                                                        </button>
                                                        <input type="hidden" name="quantities[<?php echo $product['id']; ?>]" 
                                                               value="0" class="quantity-input" data-product-id="<?php echo $product['id']; ?>">
                                                    </div>
                                                <?php else: ?>
                                                    <span style="color: #888; display: block;">Kein Formular verfügbar</span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                
                                <div style="text-align: center; margin-top: 30px;">
                                    <button type="submit" class="btn btn-lg">
                                        <i class="fas fa-shopping-cart"></i> Weiter zur Bestellung
                                    </button>
                                </div>
                            </form>
                        <?php endif; ?>
                    </div>
                <?php else: ?>
                    <!-- Embed the form via iframe for simplicity -->
                    <iframe src="order_form.php?id=<?php echo $form_id; ?>&embedded=1" style="width: 100%; height: 800px; border: none; overflow: hidden;" id="orderFormFrame"></iframe>
                    
                    <script>
                        // Adjust iframe height based on content
                        window.addEventListener('message', function(e) {
                            if (e.data && e.data.type === 'formHeight') {
                                document.getElementById('orderFormFrame').style.height = (e.data.height + 30) + 'px';
                            }
                        });
                    </script>
                <?php endif; ?>
            </div>
        </section>
    </main>
    
    <!-- Footer -->
    <footer class="site-footer">
        <div class="container">
            <div class="footer-content">
                <div class="footer-copyright">
                    <p>&copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>. Alle Rechte vorbehalten.</p>
                </div>
                <div class="footer-links">
                    <a href="impressum.php">Impressum</a>
                    <a href="datenschutz.php">Datenschutz</a>
                </div>
            </div>
        </div>
    </footer>
    
    <script>
        function selectProduct(productId) {
            window.location.href = 'order.php?product_id=' + productId;
        }
        
        // Handle product selection and quantity changes
        document.addEventListener('DOMContentLoaded', function() {
            const quantityInputs = document.querySelectorAll('.quantity-input');
            const productCards = document.querySelectorAll('.product-selectable');
            const summaryElement = document.querySelector('.selected-products-summary');
            const countElement = document.getElementById('selectedProductsCount');
            
            // Update the summary when quantity changes
            function updateSummary() {
                let totalSelected = 0;
                
                quantityInputs.forEach(input => {
                    const quantity = parseInt(input.value) || 0;
                    const productId = input.dataset.productId;
                    const card = document.querySelector(`.product-card[data-product-id="${productId}"]`);
                    
                    if (quantity > 0) {
                        totalSelected++;
                        card.classList.add('selected');
                    } else {
                        card.classList.remove('selected');
                    }
                });
                
                countElement.textContent = totalSelected;
                
                if (totalSelected > 0) {
                    summaryElement.style.display = 'block';
                } else {
                    summaryElement.style.display = 'none';
                }
            }
            
            // Add event listeners to quantity inputs
            quantityInputs.forEach(input => {
                input.addEventListener('change', updateSummary);
                input.addEventListener('input', updateSummary);
            });
            
            // Add event listeners to product cards for quick increment
            productCards.forEach(card => {
                card.addEventListener('click', function(e) {
                    // Don't trigger if clicking on the input itself
                    if (e.target.classList.contains('quantity-input') || e.target.classList.contains('select-product') || 
                        e.target.closest('.select-product')) {
                        return;
                    }
                    
                    const productId = this.dataset.productId;
                    selectProductItem(productId);
                });
            });
            
            // Add event listeners to select buttons
            document.querySelectorAll('.select-product').forEach(button => {
                button.addEventListener('click', function() {
                    const productId = this.dataset.productId;
                    selectProductItem(productId);
                });
            });
            
            // Function to select a product
            function selectProductItem(productId) {
                const input = document.querySelector(`.quantity-input[data-product-id="${productId}"]`);
                const card = document.querySelector(`.product-card[data-product-id="${productId}"]`);
                const button = card.querySelector('.select-product');
                
                if (input) {
                    if (input.value === "0") {
                        // Select product
                        input.value = "1";
                        card.classList.add('selected');
                        button.innerHTML = '<i class="fas fa-check"></i> Ausgewählt';
                        button.classList.add('selected-btn');
                    } else {
                        // Deselect product
                        input.value = "0";
                        card.classList.remove('selected');
                        button.innerHTML = '<i class="fas fa-plus"></i> Auswählen';
                        button.classList.remove('selected-btn');
                    }
                    
                    input.dispatchEvent(new Event('change'));
                }
            }
            
            // Form validation
            document.getElementById('orderForm').addEventListener('submit', function(e) {
                let totalItems = 0;
                
                quantityInputs.forEach(input => {
                    totalItems += parseInt(input.value) || 0;
                });
                
                if (totalItems === 0) {
                    e.preventDefault();
                    alert('Bitte wählen Sie mindestens ein Produkt aus.');
                }
            });
        });
    </script>
</body>
</html> 