<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once('includes/db_connect.php');

echo "<h1>Bestellungsprozess-Test</h1>";

// Prüfen, ob die notwendigen Tabellen existieren
function checkRequiredTables() {
    $requiredTables = [
        'order_submissions',
        'order_forms',
        'products'
    ];
    
    $results = [];
    foreach ($requiredTables as $table) {
        $results[$table] = tableExists($table);
    }
    
    return $results;
}

$tableResults = checkRequiredTables();
echo "<h2>Tabellenstatus:</h2>";
echo "<ul>";
foreach ($tableResults as $table => $exists) {
    $status = $exists ? "✅ vorhanden" : "❌ FEHLT";
    echo "<li><strong>{$table}</strong>: {$status}</li>";
}
echo "</ul>";

// Prüfen, ob wir Testdaten haben
echo "<h2>Verfügbare Testdaten:</h2>";

try {
    // Produkte mit Formularen abrufen
    $stmt = $conn->query("SELECT p.id, p.name, 
                          (SELECT id FROM order_forms WHERE product_id = p.id AND active = 1 LIMIT 1) as form_id
                          FROM products p
                          WHERE p.active = 1
                          LIMIT 10");
    
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($products) > 0) {
        echo "<table border='1' cellpadding='5' style='border-collapse: collapse;'>";
        echo "<tr><th>Produkt-ID</th><th>Name</th><th>Formular-ID</th><th>Aktion</th></tr>";
        
        foreach ($products as $product) {
            $formStatus = !empty($product['form_id']) ? "✅ {$product['form_id']}" : "❌ fehlt";
            
            echo "<tr>";
            echo "<td>{$product['id']}</td>";
            echo "<td>{$product['name']}</td>";
            echo "<td>{$formStatus}</td>";
            echo "<td>";
            if (!empty($product['form_id'])) {
                echo "<form method='post'>";
                echo "<input type='hidden' name='test_order' value='1'>";
                echo "<input type='hidden' name='product_id' value='{$product['id']}'>";
                echo "<input type='hidden' name='form_id' value='{$product['form_id']}'>";
                echo "<button type='submit'>Testbestellung</button>";
                echo "</form>";
            } else {
                echo "Nicht bestellbar";
            }
            echo "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p style='color: red;'>Keine aktiven Produkte gefunden!</p>";
    }
} catch (PDOException $e) {
    echo "<p style='color: red;'>Fehler beim Abrufen der Produktdaten: {$e->getMessage()}</p>";
}

// Wenn ein Bestelltest angefordert wird
if (isset($_POST['test_order']) && $_POST['test_order'] == 1) {
    echo "<h2>Bestelltest wird durchgeführt...</h2>";
    
    $productId = isset($_POST['product_id']) ? (int)$_POST['product_id'] : 0;
    $formId = isset($_POST['form_id']) ? (int)$_POST['form_id'] : 0;
    
    if ($productId > 0 && $formId > 0) {
        // Testkundendaten
        $customerData = [
            'name' => 'Testbestellung',
            'email' => 'test@example.com',
            'address' => 'Teststraße 123, 12345 Teststadt',
            'phone' => '0123-456789',
            'message' => 'Dies ist eine automatische Testbestellung'
        ];
        
        $customerJson = json_encode($customerData, JSON_UNESCAPED_UNICODE);
        $quantity = 1;
        
        try {
            // Führe die MySQL-spezifische INSERT-Anweisung aus
            $sql = "INSERT INTO order_submissions (form_id, submission_date, customer_data, submission_data, quantity) 
                    VALUES (:form_id, NOW(), :customer_data, :submission_data, :quantity)";
            
            $stmt = $conn->prepare($sql);
            $stmt->bindParam(':form_id', $formId);
            $stmt->bindParam(':customer_data', $customerJson);
            $stmt->bindParam(':submission_data', $customerJson);
            $stmt->bindParam(':quantity', $quantity);
            
            if ($stmt->execute()) {
                $orderId = $conn->lastInsertId();
                echo "<p style='color: green; font-weight: bold;'>✅ Testbestellung erfolgreich erstellt (ID: {$orderId})</p>";
                
                echo "<h3>MySQL-Abfrage:</h3>";
                echo "<pre>" . htmlspecialchars($sql) . "</pre>";
                echo "<p>Parameter:</p>";
                echo "<ul>";
                echo "<li>form_id: {$formId}</li>";
                echo "<li>customer_data: " . htmlspecialchars($customerJson) . "</li>";
                echo "<li>submission_data: " . htmlspecialchars($customerJson) . "</li>";
                echo "<li>quantity: {$quantity}</li>";
                echo "</ul>";
                
                // Zeige den eingetragenen Datensatz
                $checkStmt = $conn->prepare("SELECT * FROM order_submissions WHERE id = :id");
                $checkStmt->bindParam(':id', $orderId);
                $checkStmt->execute();
                $order = $checkStmt->fetch(PDO::FETCH_ASSOC);
                
                echo "<h3>Eingetragener Datensatz:</h3>";
                echo "<pre>";
                print_r($order);
                echo "</pre>";
                
                // Sofort wieder löschen
                $deleteStmt = $conn->prepare("DELETE FROM order_submissions WHERE id = :id");
                $deleteStmt->bindParam(':id', $orderId);
                $deleteStmt->execute();
                echo "<p>Der Testdatensatz wurde wieder aus der Datenbank entfernt.</p>";
                
            } else {
                echo "<p style='color: red;'>❌ Fehler beim Erstellen der Testbestellung</p>";
            }
        } catch (PDOException $e) {
            echo "<p style='color: red;'>❌ Datenbankfehler: {$e->getMessage()}</p>";
            
            // Zeige den SQL-Fehlercode
            echo "<p><strong>SQL-Fehlercode:</strong> " . $e->getCode() . "</p>";
            
            // Versuche anderen Syntax
            echo "<h3>Alternative Syntax wird versucht...</h3>";
            try {
                // Versuche einen alternativen Ansatz ohne Parameter
                $sql2 = "INSERT INTO order_submissions (form_id, submission_date, customer_data, submission_data, quantity) 
                        VALUES ({$formId}, CURRENT_TIMESTAMP, " . 
                        $conn->quote($customerJson) . ", " .
                        $conn->quote($customerJson) . ", {$quantity})";
                
                echo "<pre>" . htmlspecialchars($sql2) . "</pre>";
                
                $result = $conn->exec($sql2);
                if ($result) {
                    echo "<p style='color: green;'>✅ Alternative Methode erfolgreich!</p>";
                } else {
                    echo "<p style='color: red;'>❌ Alternative Methode fehlgeschlagen</p>";
                }
            } catch (PDOException $e2) {
                echo "<p style='color: red;'>❌ Auch alternative Methode fehlgeschlagen: {$e2->getMessage()}</p>";
            }
        }
    } else {
        echo "<p style='color: red;'>Ungültige Produkt- oder Formular-ID</p>";
    }
}

// Link zurück
echo "<p><br><a href='order_cart.php'>Zurück zum Warenkorb</a> | <a href='db_check.php'>Datenbank-Check</a></p>";
?> 