<?php
require_once('includes/db_connect.php');

// Get site title
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'site_title'");
$stmt->execute();
$site_title = $stmt->fetchColumn() ?: 'JB Kerzen';

// Get brand info
$stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
$stmt->execute();
$brand = $stmt->fetch();

// Get order logo
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'order_logo'");
$stmt->execute();
$order_logo = $stmt->fetchColumn() ?: '';

// Get site colors for styling
try {
    $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
    $colors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
} catch (PDOException $e) {
    // Use default colors if query fails
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
}

// If colors not found, use defaults
if (!isset($colors['primary_color'])) $colors['primary_color'] = '#8b6b4f';
if (!isset($colors['secondary_color'])) $colors['secondary_color'] = '#333333';
if (!isset($colors['accent_color'])) $colors['accent_color'] = '#d4af37';
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Bestellung abgeschlossen | <?php echo htmlspecialchars($site_title); ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css">
    <link rel="stylesheet" href="assets/css/order-forms.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
        }
        
        body {
            font-family: 'Helvetica Neue', Arial, sans-serif;
            line-height: 1.6;
            color: #333;
            margin: 0;
            padding: 0;
            background-color: #f8f8f8;
        }
        
        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 20px;
        }
        
        .section {
            padding: 60px 0;
        }
        
        .section-title {
            text-align: center;
            margin-bottom: 40px;
            font-size: 32px;
            color: var(--primary-color);
        }
        
        .success-container {
            background: white;
            border-radius: 10px;
            box-shadow: 0 3px 15px rgba(0,0,0,0.1);
            padding: 40px;
            text-align: center;
            max-width: 700px;
            margin: 0 auto;
        }
        
        .success-icon {
            font-size: 80px;
            color: #28a745;
            margin-bottom: 20px;
        }
        
        .success-message {
            margin-bottom: 30px;
        }
        
        .success-message h2 {
            color: var(--primary-color);
            font-size: 28px;
            margin-bottom: 15px;
        }
        
        .success-message p {
            color: #666;
            font-size: 18px;
            margin-bottom: 5px;
        }
        
        .btn {
            display: inline-block;
            background-color: var(--primary-color);
            color: white;
            font-size: 16px;
            font-weight: 500;
            padding: 12px 25px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s;
            text-decoration: none;
            margin-top: 20px;
        }
        
        .btn:hover {
            background-color: var(--accent-color);
        }
        
        .site-header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            position: relative;
            z-index: 100;
            padding: 15px 0;
        }
        
        .header-content {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .brand-text {
            font-size: 24px;
            color: var(--primary-color);
            text-decoration: none;
            font-weight: bold;
        }
        
        .brand-logo {
            height: 60px;
            width: auto;
        }
        
        .site-footer {
            background-color: var(--secondary-color);
            color: white;
            padding: 30px 0;
            margin-top: 50px;
        }
        
        .footer-content {
            display: flex;
            flex-direction: column;
            align-items: center;
            text-align: center;
        }
        
        .footer-copyright {
            margin-bottom: 15px;
        }
        
        .footer-links {
            display: flex;
            gap: 20px;
        }
        
        .footer-links a {
            color: white;
            text-decoration: none;
        }
        
        .footer-links a:hover {
            text-decoration: underline;
        }
        
        /* Order steps indicator */
        .order-steps {
            display: flex;
            justify-content: center;
            margin-bottom: 40px;
        }
        
        .step {
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 150px;
            position: relative;
        }
        
        .step:not(:last-child)::after {
            content: '';
            position: absolute;
            top: 30px;
            right: -50%;
            width: 100%;
            height: 2px;
            background-color: #ddd;
            z-index: 1;
        }
        
        .step.completed:not(:last-child)::after {
            background-color: #28a745;
        }
        
        .step-number {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            background-color: #ddd;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 24px;
            font-weight: bold;
            color: white;
            margin-bottom: 10px;
            position: relative;
            z-index: 2;
        }
        
        .step.completed .step-number {
            background-color: #28a745;
        }
        
        .step-title {
            font-weight: 500;
            color: #777;
        }
        
        .step.completed .step-title {
            color: #28a745;
        }
        
        /* Responsive adjustments */
        @media (max-width: 768px) {
            .success-container {
                padding: 30px 20px;
            }
            
            .order-steps {
                flex-direction: column;
                align-items: center;
                gap: 20px;
            }
            
            .step {
                flex-direction: row;
                width: 100%;
                gap: 15px;
            }
            
            .step:not(:last-child)::after {
                display: none;
            }
            
            .step-number {
                width: 40px;
                height: 40px;
                font-size: 18px;
                margin-bottom: 0;
            }
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="site-header">
        <div class="container">
            <div class="header-content">
                <div class="brand">
                    <?php if (!empty($order_logo) && file_exists($order_logo)): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($order_logo); ?>" alt="<?php echo htmlspecialchars($site_title); ?>" class="brand-logo">
                        </a>
                    <?php elseif (isset($brand['image_path']) && !empty($brand['image_path'])): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($brand['image_path']); ?>" alt="<?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>" class="brand-logo">
                        </a>
                    <?php else: ?>
                        <a href="index.php" class="brand-text">
                            <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>
                        </a>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <main>
        <section class="section">
            <div class="container">
                <h1 class="section-title">Bestellung abgeschlossen</h1>
                
                <!-- Steps indicator -->
                <div class="order-steps">
                    <div class="step completed">
                        <div class="step-number"><i class="fas fa-check"></i></div>
                        <div class="step-title">Produkte auswählen</div>
                    </div>
                    <div class="step completed">
                        <div class="step-number"><i class="fas fa-check"></i></div>
                        <div class="step-title">Bestelldaten</div>
                    </div>
                    <div class="step completed">
                        <div class="step-number"><i class="fas fa-check"></i></div>
                        <div class="step-title">Bestätigung</div>
                    </div>
                </div>
                
                <div class="success-container">
                    <div class="success-icon">
                        <i class="fas fa-check-circle"></i>
                    </div>
                    
                    <div class="success-message">
                        <h2>Vielen Dank für Ihre Bestellung!</h2>
                        <p>Wir haben Ihre Bestellung erfolgreich erhalten.</p>
                        <p>Eine Bestätigung wurde an die von Ihnen angegebene E-Mail-Adresse gesendet.</p>
                        <p>Wir werden uns in Kürze mit Ihnen in Verbindung setzen.</p>
                    </div>
                    
                    <a href="index.php" class="btn">Zurück zur Startseite</a>
                </div>
            </div>
        </section>
    </main>
    
    <!-- Footer -->
    <footer class="site-footer">
        <div class="container">
            <div class="footer-content">
                <div class="footer-copyright">
                    <p>&copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>. Alle Rechte vorbehalten.</p>
                </div>
                <div class="footer-links">
                    <a href="impressum.php">Impressum</a>
                    <a href="datenschutz.php">Datenschutz</a>
                </div>
            </div>
        </div>
    </footer>
</body>
</html> 