<?php
// Skript zum vollständigen Entfernen der Adressfelder aus der Datenbank und dem Bestellformular
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Include database connection
require_once('includes/db_connect.php');

echo "<html><head><title>JB Kerzen - Adressfelder entfernen</title>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; line-height: 1.6; }
    h1, h2, h3 { color: #8b6b4f; }
    .success { color: green; font-weight: bold; }
    .error { color: red; font-weight: bold; }
    .warning { color: orange; font-weight: bold; }
    pre { background: #f5f5f5; padding: 15px; border-radius: 5px; margin: 10px 0; }
    .button { display: inline-block; padding: 10px 20px; background: #8b6b4f; color: white; 
              text-decoration: none; border-radius: 4px; margin-top: 20px; cursor: pointer; border: none; }
</style>";
echo "</head><body>";
echo "<h1>Adressfelder entfernen</h1>";

$message = '';

// Execute removal if confirmed
if (isset($_POST['confirm_removal'])) {
    try {
        // 1. Remove address fields from the database
        $stmt = $conn->prepare("DELETE FROM form_fields 
                               WHERE field_label LIKE '%adresse%' 
                               OR field_label LIKE '%Adresse%'
                               OR field_label LIKE '%strasse%'
                               OR field_label LIKE '%straße%'");
        $stmt->execute();
        $deletedCount = $stmt->rowCount();
        
        $message .= "<p class='success'>✓ {$deletedCount} Adressfelder wurden aus der Datenbank entfernt.</p>";
        
        // 2. Clean up the order_form.php file
        $orderFormPath = "order_form.php";
        
        if (file_exists($orderFormPath)) {
            $originalContent = file_get_contents($orderFormPath);
            $newContent = $originalContent;
            
            // Remove any address-related JavaScript we may have added
            $newContent = preg_replace('/<!-- BEGIN FORCED ADDRESS FIELDS -->.*?<!-- END FORCED ADDRESS FIELDS -->/s', '', $newContent);
            
            // Remove any address debug script
            $newContent = str_replace('<script src="assets/js/address-debug.js"></script>', '', $newContent);
            
            // Clean up any added CSS
            $cssToRemove = "/* Erzwungene Adressfeld-Stile */
.address-container, .address-fields {
    display: block !important;
    border: 1px solid #ddd !important;
    border-radius: 5px !important;
    padding: 15px !important;
    background-color: #f9f9f9 !important;
    margin-top: 10px !important;
}

.address-row, .address-fields .row {
    display: flex !important;
    flex-wrap: wrap !important;
    gap: 15px !important;
    margin-bottom: 15px !important;
}

.address-col, .address-fields .col-md-4, .address-fields .col-md-8 {
    flex: 1 !important;
}

.address-col.street, .address-fields .col-md-8 {
    flex: 2 !important;
}

@media (max-width: 768px) {
    .address-row, .address-fields .row {
        flex-direction: column !important;
    }
}";
            $newContent = str_replace($cssToRemove, '', $newContent);
            
            // Only write if changes were made
            if ($newContent !== $originalContent) {
                if (file_put_contents($orderFormPath, $newContent)) {
                    $message .= "<p class='success'>✓ CSS und JavaScript für Adressfelder wurden aus order_form.php entfernt.</p>";
                } else {
                    $message .= "<p class='error'>Fehler: Konnte die Datei order_form.php nicht aktualisieren.</p>";
                }
            } else {
                $message .= "<p class='warning'>Keine Änderungen an order_form.php vorgenommen.</p>";
            }
        } else {
            $message .= "<p class='error'>Fehler: Die Datei order_form.php wurde nicht gefunden.</p>";
        }
        
        // 3. Clean up the form templates that might have address fields
        try {
            // Get all form templates
            $stmt = $conn->prepare("SELECT id, template FROM forms");
            $stmt->execute();
            $forms = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            $updatedForms = 0;
            
            foreach ($forms as $form) {
                $template = $form['template'];
                
                // Check if the template contains any address-related code
                if (strpos($template, 'adresse') !== false || 
                    strpos($template, 'Adresse') !== false ||
                    strpos($template, 'address-container') !== false ||
                    strpos($template, 'address-fields') !== false) {
                    
                    // Remove the address field container if it exists
                    $pattern = '/<div[^>]*class="[^"]*form-group[^"]*"[^>]*>.*?<label[^>]*>.*?adresse.*?<\/label>.*?<\/div>/is';
                    $cleanedTemplate = preg_replace($pattern, '', $template);
                    
                    // Also try to remove any address-specific container
                    $patternAddress = '/<div[^>]*class="[^"]*address-container[^"]*"[^>]*>.*?<\/div>/is';
                    $cleanedTemplate = preg_replace($patternAddress, '', $cleanedTemplate);
                    
                    // Apply the changes if any were made
                    if ($cleanedTemplate !== $template) {
                        $stmt = $conn->prepare("UPDATE forms SET template = ? WHERE id = ?");
                        $stmt->execute([$cleanedTemplate, $form['id']]);
                        $updatedForms++;
                    }
                }
            }
            
            if ($updatedForms > 0) {
                $message .= "<p class='success'>✓ Adressfelder wurden aus {$updatedForms} Formularvorlagen entfernt.</p>";
            } else {
                $message .= "<p class='warning'>Keine Formularvorlagen wurden aktualisiert.</p>";
            }
        } catch (PDOException $e) {
            $message .= "<p class='error'>Fehler beim Aktualisieren der Formularvorlagen: " . $e->getMessage() . "</p>";
        }
        
        // 4. Remove any JS debug files we created
        $debugJsPath = "assets/js/address-debug.js";
        if (file_exists($debugJsPath)) {
            if (unlink($debugJsPath)) {
                $message .= "<p class='success'>✓ Debug-Skript {$debugJsPath} wurde gelöscht.</p>";
            }
        }
        
        $message .= "<p class='success'>✓ Bereinigung abgeschlossen. Sie können nun das Adressfeld manuell neu anlegen.</p>";
        
    } catch (PDOException $e) {
        $message .= "<p class='error'>Datenbankfehler: " . $e->getMessage() . "</p>";
    } catch (Exception $e) {
        $message .= "<p class='error'>Allgemeiner Fehler: " . $e->getMessage() . "</p>";
    }
}

// Show confirmation form if not confirmed yet
if (!isset($_POST['confirm_removal'])) {
    echo "<p>Dieses Skript wird alle Adressfelder aus der Datenbank entfernen und die dazugehörigen Elemente aus dem Bestellformular löschen.</p>";
    echo "<p class='warning'><strong>Achtung:</strong> Diese Aktion kann nicht rückgängig gemacht werden. Bitte stellen Sie sicher, dass Sie eine Sicherung Ihrer Datenbank haben.</p>";
    
    // Show address fields to be deleted
    try {
        $stmt = $conn->prepare("SELECT * FROM form_fields 
                               WHERE field_label LIKE '%adresse%' 
                               OR field_label LIKE '%Adresse%'
                               ORDER BY form_id, id");
        $stmt->execute();
        $addressFields = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        if (count($addressFields) > 0) {
            echo "<h3>Folgende Felder werden gelöscht:</h3>";
            echo "<ul>";
            foreach ($addressFields as $field) {
                echo "<li>ID: " . $field['id'] . ", Form-ID: " . $field['form_id'] . ", Label: " . htmlspecialchars($field['field_label']) . "</li>";
            }
            echo "</ul>";
        } else {
            echo "<p>Keine Adressfelder in der Datenbank gefunden.</p>";
        }
    } catch (PDOException $e) {
        echo "<p class='error'>Fehler beim Abrufen der Adressfelder: " . $e->getMessage() . "</p>";
    }
    
    echo "<form method='post' action=''>";
    echo "<button type='submit' name='confirm_removal' class='button'>Ja, Adressfelder entfernen</button> ";
    echo "<a href='index.php' style='margin-left: 15px;'>Abbrechen</a>";
    echo "</form>";
} else {
    // Show results
    echo $message;
    echo "<p><a href='index.php' class='button'>Zurück zur Startseite</a></p>";
}

echo "</body></html>";
?> 