<?php
// Datenbankverbindung herstellen
require_once('includes/db_connect.php');

try {
    echo "<h2>Datenbankaktualisierung (MySQL)</h2>";
    
    // 1. Prüfe auf product_id Spalte in order_forms Tabelle
    echo "<h3>1. Prüfe product_id in order_forms</h3>";
    
    // MySQL-Version für Spaltenprüfung
    $has_product_id = columnExists('order_forms', 'product_id');
    
    if (!$has_product_id) {
        // Spalte existiert nicht, also hinzufügen
        echo "Spalte wird hinzugefügt...<br>";
        
        $conn->exec("ALTER TABLE order_forms ADD COLUMN product_id INT DEFAULT NULL");
        // In MySQL können wir auch Foreign Key hinzufügen
        $conn->exec("ALTER TABLE order_forms ADD CONSTRAINT fk_product_id FOREIGN KEY (product_id) REFERENCES products(id) ON DELETE SET NULL");
        
        echo "<span style='color: green;'>Spalte product_id wurde erfolgreich hinzugefügt.</span><br>";
    } else {
        echo "<span style='color: blue;'>Spalte product_id existiert bereits.</span><br>";
    }
    
    // 2. Prüfe auf submission_date Spalte in order_submissions Tabelle
    echo "<h3>2. Prüfe submission_date in order_submissions</h3>";
    
    // MySQL-Version für Spaltenprüfung
    $has_submission_date = columnExists('order_submissions', 'submission_date');
    
    if (!$has_submission_date) {
        // Spalte existiert nicht, also hinzufügen
        echo "Spalte wird hinzugefügt...<br>";
        
        // MySQL erlaubt dynamische Standardwerte wie CURRENT_TIMESTAMP
        $conn->exec("ALTER TABLE order_submissions ADD COLUMN submission_date TIMESTAMP DEFAULT CURRENT_TIMESTAMP");
        
        echo "<span style='color: green;'>Spalte submission_date wurde erfolgreich hinzugefügt.</span><br>";
    } else {
        echo "<span style='color: blue;'>Spalte submission_date existiert bereits.</span><br>";
    }
    
    // 3. Prüfe auf quantity Spalte in order_submissions Tabelle
    echo "<h3>3. Prüfe auf quantity in order_submissions</h3>";
    
    // MySQL-Version für Spaltenprüfung
    $has_quantity = columnExists('order_submissions', 'quantity');
    
    if (!$has_quantity) {
        // Spalte existiert nicht, also hinzufügen
        echo "Spalte wird hinzugefügt...<br>";
        
        $conn->exec("ALTER TABLE order_submissions ADD COLUMN quantity INT DEFAULT 1");
        
        echo "<span style='color: green;'>Spalte quantity wurde erfolgreich hinzugefügt.</span><br>";
    } else {
        echo "<span style='color: blue;'>Spalte quantity existiert bereits.</span><br>";
    }
    
    // 4. Prüfe auf customer_data Spalte in order_submissions Tabelle
    echo "<h3>4. Prüfe auf customer_data in order_submissions</h3>";
    
    // MySQL-Version für Spaltenprüfung
    $has_customer_data = columnExists('order_submissions', 'customer_data');
    
    if (!$has_customer_data) {
        // Spalte existiert nicht, also hinzufügen
        echo "Spalte wird hinzugefügt...<br>";
        
        $conn->exec("ALTER TABLE order_submissions ADD COLUMN customer_data TEXT DEFAULT NULL");
        
        echo "<span style='color: green;'>Spalte customer_data wurde erfolgreich hinzugefügt.</span><br>";
    } else {
        echo "<span style='color: blue;'>Spalte customer_data existiert bereits.</span><br>";
    }
    
    // 5. Prüfe auf price Spalte in products Tabelle
    echo "<h3>5. Prüfe auf price in products</h3>";
    
    // MySQL-Version für Spaltenprüfung
    $has_price = columnExists('products', 'price');
    
    if (!$has_price) {
        // Spalte existiert nicht, also hinzufügen
        echo "Spalte wird hinzugefügt...<br>";
        
        $conn->exec("ALTER TABLE products ADD COLUMN price DECIMAL(10,2) DEFAULT 0.00");
        
        echo "<span style='color: green;'>Spalte price wurde erfolgreich hinzugefügt.</span><br>";
    } else {
        echo "<span style='color: blue;'>Spalte price existiert bereits.</span><br>";
    }
    
    // 6. Prüfe Tabellenstruktur der form_fields Tabelle
    echo "<h3>6. Prüfe Struktur der form_fields Tabelle</h3>";
    
    if (tableExists('form_fields')) {
        // Prüfe, ob die Tabelle das richtige Format hat
        echo "Struktur der Tabelle form_fields:<br>";
        
        $result = $conn->query("DESCRIBE form_fields");
        while ($row = $result->fetch(PDO::FETCH_ASSOC)) {
            echo "- {$row['Field']} ({$row['Type']})<br>";
        }
        
        // Prüfe speziell auf Adressfelder
        $stmt = $conn->prepare("SELECT id, field_label, field_type FROM form_fields WHERE field_label LIKE '%Adresse%'");
        $stmt->execute();
        $adressFields = $stmt->fetchAll();
        
        if (count($adressFields) > 0) {
            echo "<br>Gefundene Adressfelder:<br>";
            foreach ($adressFields as $field) {
                echo "ID: {$field['id']}, Label: {$field['field_label']}, Typ: {$field['field_type']}<br>";
                
                // Korrigiere den Feldtyp wenn nötig
                if ($field['field_type'] !== 'address') {
                    $updateStmt = $conn->prepare("UPDATE form_fields SET field_type = 'address' WHERE id = ?");
                    $updateStmt->execute([$field['id']]);
                    echo "<span style='color: green;'>Feldtyp für ID {$field['id']} zu 'address' korrigiert</span><br>";
                }
            }
        } else {
            echo "<span style='color: orange;'>Keine Adressfelder gefunden!</span><br>";
        }
    }
    
    echo "<h3>Datenbankaktualisierung abgeschlossen.</h3>";
    echo "<a href='index.php' style='display: inline-block; padding: 10px 15px; background: #8b6b4f; color: white; text-decoration: none; border-radius: 4px; margin-top: 15px;'>Zurück zur Startseite</a>";
    
} catch (PDOException $e) {
    echo "<div style='color: red; font-weight: bold;'>Fehler bei der Datenbankaktualisierung: " . $e->getMessage() . "</div>";
    echo "<pre>" . $e->getTraceAsString() . "</pre>";
}
?> 